searchData={"items":[{"type":"module","title":"Beacon","doc":"Beacon is a Content Management System for [Phoenix LiveView](https://github.com/phoenixframework/phoenix_live_view).\n\n* Rendering pages fast.\n* Reloading content at runtime.\n* Reduced resources usage and scalability.\n* Integration with existing Phoenix applications.\n\nYou can build virtually any type of website with Beacon, from a simple blog to a complex business site.\n\nFollowing are the main APIs provided by Beacon. You can find out more information on the module documentation of each one of those modules:\n\n* `Beacon.Config` - configuration of sites.\n* `Beacon.Router` - mount one or more sites into the router of your Phoenix application.\n* `Beacon.Lifecycle` - inject custom logic into Beacon lifecycle to change how pages are loaded an rendred, and more.\n* `Beacon.Content` - manage content as layouts, pages, page variants, snippets, and more.\n* `Beacon.MediaLibrary` - upload images, videos, and documents that can be used in your content.\n\nGet started with [your first site](https://hexdocs.pm/beacon/your-first-site.html) and check out the guides for more information.","ref":"Beacon.html"},{"type":"function","title":"Beacon.boot/1","doc":"Boot a site executing the initial data population and resources loading.\n\nIt will populate default content data and routes in the router table,\nenable PubSub events broadcasting, and load resource modules for layouts, pages, and others.\n\nThis function is called by the site supervisor when a site is started and should not be called directly most of the times,\nbut in some scenarions, you want to start Beacon and all related process like the Repo without actually booting the site,\nfor example to seed initial data and in tests.\n\nIn those scenarios you'd define the config `skip_boot?` to `true` in your site configuration,\nexecute everything you need and then call `Beacon.boot/1` to finally boot the site if necessary.\n\nNote that calling this function will update the running `site` config `skip_boot?` to `false` automatically after the site gets booted,\nso all PubSub events necessary for Beacon to work properly are broadcasted as expected.","ref":"Beacon.html#boot/1"},{"type":"function","title":"Beacon.start_link/1","doc":"Start `Beacon` and a supervisor for each site, which will load all layouts, pages, components, and so on.\n\nYou must include the `Beacon` supervisor on each application that you want it loaded. For a single Phoenix application\nthat would go in the `children` list on the file `lib/my_app/application.ex`. For Umbrella apps you can have\nmultiple apps running Beacon, suppose your project has 3 apps: core (regular app), blog (phoenix app), and marketing (phoenix app)\nand you want to load one Beacon instance on each Phoenix app, so you would include `Beacon` in the list of `children` applications\nin both blog and marketing applications with their own `:sites` configuration.\n\nNote that each Beacon instance may have multiple sites and each site loads in its own supervisor. That gives you the\nflexibility to plan your architecture from simple to complex environments. For example, you can have a single site\nserving all pages in a single Phoenix application or you can create a new site to isolate a landing page for a marketing\ncampaign that may receive too much traffic.","ref":"Beacon.html#start_link/1"},{"type":"function","title":"Options - Beacon.start_link/1","doc":"Each site in `:sites` may have its own configuration, see all available options at `Beacon.Config.new/1`.","ref":"Beacon.html#start_link/1-options"},{"type":"function","title":"Examples - Beacon.start_link/1","doc":"# config.exs or runtime.exs\n    config :my_app, Beacon,\n      sites: [\n        [site: :my_site, endpoint: MyAppWeb.Endpoint]\n      ]\n\n    # lib/my_app/application.ex\n    def start(_type, _args) do\n      children = [\n        MyApp.Repo,\n        {Phoenix.PubSub, name: MyApp.PubSub},\n        {Beacon, Application.fetch_env!(:my_app, Beacon)}, # <- added Beacon here\n        MyAppWeb.Endpoint\n      ]\n\n      opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n      Supervisor.start_link(children, opts)\n    end","ref":"Beacon.html#start_link/1-examples"},{"type":"module","title":"Heroicons","doc":"Provides precompiled icon compiles from [heroicons.com v2.1.5](heroicons.com).\n\nHeroicons are designed by [Steve Schoger](https://twitter.com/steveschoger)","ref":"Heroicons.html"},{"type":"module","title":"Usage - Heroicons","doc":"Hero icons come in four styles – outline (`24x24`), solid (`24x24`), mini (`20x20`) and micro(`16x16`).\n\nBy default, the icon components will use the outline style, but the `solid`,\n`mini` or micro attributes may be passed to select styling, for example:\n\n```heex\n \n \n \n \n```\n\nYou can also pass arbitrary HTML attributes to the components:\n\n ```heex\n \n \n```","ref":"Heroicons.html#module-usage"},{"type":"module","title":"Heroicons License Attribution - Heroicons","doc":"MIT License\n\nCopyright (c) 2020 Refactoring UI Inc.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"Heroicons.html#module-heroicons-license-attribution"},{"type":"function","title":"Heroicons.academic_cap/1","doc":"Renders the `academic_cap` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#academic_cap/1"},{"type":"function","title":"Examples - Heroicons.academic_cap/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#academic_cap/1-examples"},{"type":"function","title":"Attributes - Heroicons.academic_cap/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#academic_cap/1-attributes"},{"type":"function","title":"Heroicons.adjustments_horizontal/1","doc":"Renders the `adjustments_horizontal` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#adjustments_horizontal/1"},{"type":"function","title":"Examples - Heroicons.adjustments_horizontal/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#adjustments_horizontal/1-examples"},{"type":"function","title":"Attributes - Heroicons.adjustments_horizontal/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#adjustments_horizontal/1-attributes"},{"type":"function","title":"Heroicons.adjustments_vertical/1","doc":"Renders the `adjustments_vertical` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#adjustments_vertical/1"},{"type":"function","title":"Examples - Heroicons.adjustments_vertical/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#adjustments_vertical/1-examples"},{"type":"function","title":"Attributes - Heroicons.adjustments_vertical/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#adjustments_vertical/1-attributes"},{"type":"function","title":"Heroicons.archive_box/1","doc":"Renders the `archive_box` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#archive_box/1"},{"type":"function","title":"Examples - Heroicons.archive_box/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#archive_box/1-examples"},{"type":"function","title":"Attributes - Heroicons.archive_box/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#archive_box/1-attributes"},{"type":"function","title":"Heroicons.archive_box_arrow_down/1","doc":"Renders the `archive_box_arrow_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#archive_box_arrow_down/1"},{"type":"function","title":"Examples - Heroicons.archive_box_arrow_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#archive_box_arrow_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.archive_box_arrow_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#archive_box_arrow_down/1-attributes"},{"type":"function","title":"Heroicons.archive_box_x_mark/1","doc":"Renders the `archive_box_x_mark` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#archive_box_x_mark/1"},{"type":"function","title":"Examples - Heroicons.archive_box_x_mark/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#archive_box_x_mark/1-examples"},{"type":"function","title":"Attributes - Heroicons.archive_box_x_mark/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#archive_box_x_mark/1-attributes"},{"type":"function","title":"Heroicons.arrow_down/1","doc":"Renders the `arrow_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_down/1"},{"type":"function","title":"Examples - Heroicons.arrow_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_down/1-attributes"},{"type":"function","title":"Heroicons.arrow_down_circle/1","doc":"Renders the `arrow_down_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_down_circle/1"},{"type":"function","title":"Examples - Heroicons.arrow_down_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_down_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_down_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_down_circle/1-attributes"},{"type":"function","title":"Heroicons.arrow_down_left/1","doc":"Renders the `arrow_down_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_down_left/1"},{"type":"function","title":"Examples - Heroicons.arrow_down_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_down_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_down_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_down_left/1-attributes"},{"type":"function","title":"Heroicons.arrow_down_on_square/1","doc":"Renders the `arrow_down_on_square` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_down_on_square/1"},{"type":"function","title":"Examples - Heroicons.arrow_down_on_square/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_down_on_square/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_down_on_square/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_down_on_square/1-attributes"},{"type":"function","title":"Heroicons.arrow_down_on_square_stack/1","doc":"Renders the `arrow_down_on_square_stack` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_down_on_square_stack/1"},{"type":"function","title":"Examples - Heroicons.arrow_down_on_square_stack/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_down_on_square_stack/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_down_on_square_stack/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_down_on_square_stack/1-attributes"},{"type":"function","title":"Heroicons.arrow_down_right/1","doc":"Renders the `arrow_down_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_down_right/1"},{"type":"function","title":"Examples - Heroicons.arrow_down_right/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_down_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_down_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_down_right/1-attributes"},{"type":"function","title":"Heroicons.arrow_down_tray/1","doc":"Renders the `arrow_down_tray` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_down_tray/1"},{"type":"function","title":"Examples - Heroicons.arrow_down_tray/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_down_tray/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_down_tray/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_down_tray/1-attributes"},{"type":"function","title":"Heroicons.arrow_left/1","doc":"Renders the `arrow_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_left/1"},{"type":"function","title":"Examples - Heroicons.arrow_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_left/1-attributes"},{"type":"function","title":"Heroicons.arrow_left_circle/1","doc":"Renders the `arrow_left_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_left_circle/1"},{"type":"function","title":"Examples - Heroicons.arrow_left_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_left_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_left_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_left_circle/1-attributes"},{"type":"function","title":"Heroicons.arrow_left_end_on_rectangle/1","doc":"Renders the `arrow_left_end_on_rectangle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_left_end_on_rectangle/1"},{"type":"function","title":"Examples - Heroicons.arrow_left_end_on_rectangle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_left_end_on_rectangle/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_left_end_on_rectangle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_left_end_on_rectangle/1-attributes"},{"type":"function","title":"Heroicons.arrow_left_on_rectangle/1","doc":"Renders the `arrow_left_on_rectangle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid` or `mini`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_left_on_rectangle/1"},{"type":"function","title":"Examples - Heroicons.arrow_left_on_rectangle/1","doc":"```heex\n \n \n \n \n \n```","ref":"Heroicons.html#arrow_left_on_rectangle/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_left_on_rectangle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_left_on_rectangle/1-attributes"},{"type":"function","title":"Heroicons.arrow_left_start_on_rectangle/1","doc":"Renders the `arrow_left_start_on_rectangle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_left_start_on_rectangle/1"},{"type":"function","title":"Examples - Heroicons.arrow_left_start_on_rectangle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_left_start_on_rectangle/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_left_start_on_rectangle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_left_start_on_rectangle/1-attributes"},{"type":"function","title":"Heroicons.arrow_long_down/1","doc":"Renders the `arrow_long_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_long_down/1"},{"type":"function","title":"Examples - Heroicons.arrow_long_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_long_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_long_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_long_down/1-attributes"},{"type":"function","title":"Heroicons.arrow_long_left/1","doc":"Renders the `arrow_long_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_long_left/1"},{"type":"function","title":"Examples - Heroicons.arrow_long_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_long_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_long_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_long_left/1-attributes"},{"type":"function","title":"Heroicons.arrow_long_right/1","doc":"Renders the `arrow_long_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_long_right/1"},{"type":"function","title":"Examples - Heroicons.arrow_long_right/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_long_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_long_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_long_right/1-attributes"},{"type":"function","title":"Heroicons.arrow_long_up/1","doc":"Renders the `arrow_long_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_long_up/1"},{"type":"function","title":"Examples - Heroicons.arrow_long_up/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_long_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_long_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_long_up/1-attributes"},{"type":"function","title":"Heroicons.arrow_path/1","doc":"Renders the `arrow_path` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_path/1"},{"type":"function","title":"Examples - Heroicons.arrow_path/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_path/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_path/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_path/1-attributes"},{"type":"function","title":"Heroicons.arrow_path_rounded_square/1","doc":"Renders the `arrow_path_rounded_square` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_path_rounded_square/1"},{"type":"function","title":"Examples - Heroicons.arrow_path_rounded_square/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_path_rounded_square/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_path_rounded_square/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_path_rounded_square/1-attributes"},{"type":"function","title":"Heroicons.arrow_right/1","doc":"Renders the `arrow_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_right/1"},{"type":"function","title":"Examples - Heroicons.arrow_right/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_right/1-attributes"},{"type":"function","title":"Heroicons.arrow_right_circle/1","doc":"Renders the `arrow_right_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_right_circle/1"},{"type":"function","title":"Examples - Heroicons.arrow_right_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_right_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_right_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_right_circle/1-attributes"},{"type":"function","title":"Heroicons.arrow_right_end_on_rectangle/1","doc":"Renders the `arrow_right_end_on_rectangle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_right_end_on_rectangle/1"},{"type":"function","title":"Examples - Heroicons.arrow_right_end_on_rectangle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_right_end_on_rectangle/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_right_end_on_rectangle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_right_end_on_rectangle/1-attributes"},{"type":"function","title":"Heroicons.arrow_right_on_rectangle/1","doc":"Renders the `arrow_right_on_rectangle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid` or `mini`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_right_on_rectangle/1"},{"type":"function","title":"Examples - Heroicons.arrow_right_on_rectangle/1","doc":"```heex\n \n \n \n \n \n```","ref":"Heroicons.html#arrow_right_on_rectangle/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_right_on_rectangle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_right_on_rectangle/1-attributes"},{"type":"function","title":"Heroicons.arrow_right_start_on_rectangle/1","doc":"Renders the `arrow_right_start_on_rectangle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_right_start_on_rectangle/1"},{"type":"function","title":"Examples - Heroicons.arrow_right_start_on_rectangle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_right_start_on_rectangle/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_right_start_on_rectangle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_right_start_on_rectangle/1-attributes"},{"type":"function","title":"Heroicons.arrow_small_down/1","doc":"Renders the `arrow_small_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid` or `mini`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_small_down/1"},{"type":"function","title":"Examples - Heroicons.arrow_small_down/1","doc":"```heex\n \n \n \n \n \n```","ref":"Heroicons.html#arrow_small_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_small_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_small_down/1-attributes"},{"type":"function","title":"Heroicons.arrow_small_left/1","doc":"Renders the `arrow_small_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid` or `mini`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_small_left/1"},{"type":"function","title":"Examples - Heroicons.arrow_small_left/1","doc":"```heex\n \n \n \n \n \n```","ref":"Heroicons.html#arrow_small_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_small_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_small_left/1-attributes"},{"type":"function","title":"Heroicons.arrow_small_right/1","doc":"Renders the `arrow_small_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid` or `mini`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_small_right/1"},{"type":"function","title":"Examples - Heroicons.arrow_small_right/1","doc":"```heex\n \n \n \n \n \n```","ref":"Heroicons.html#arrow_small_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_small_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_small_right/1-attributes"},{"type":"function","title":"Heroicons.arrow_small_up/1","doc":"Renders the `arrow_small_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid` or `mini`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_small_up/1"},{"type":"function","title":"Examples - Heroicons.arrow_small_up/1","doc":"```heex\n \n \n \n \n \n```","ref":"Heroicons.html#arrow_small_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_small_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_small_up/1-attributes"},{"type":"function","title":"Heroicons.arrow_top_right_on_square/1","doc":"Renders the `arrow_top_right_on_square` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_top_right_on_square/1"},{"type":"function","title":"Examples - Heroicons.arrow_top_right_on_square/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_top_right_on_square/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_top_right_on_square/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_top_right_on_square/1-attributes"},{"type":"function","title":"Heroicons.arrow_trending_down/1","doc":"Renders the `arrow_trending_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_trending_down/1"},{"type":"function","title":"Examples - Heroicons.arrow_trending_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_trending_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_trending_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_trending_down/1-attributes"},{"type":"function","title":"Heroicons.arrow_trending_up/1","doc":"Renders the `arrow_trending_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_trending_up/1"},{"type":"function","title":"Examples - Heroicons.arrow_trending_up/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_trending_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_trending_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_trending_up/1-attributes"},{"type":"function","title":"Heroicons.arrow_turn_down_left/1","doc":"Renders the `arrow_turn_down_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_turn_down_left/1"},{"type":"function","title":"Examples - Heroicons.arrow_turn_down_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_turn_down_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_turn_down_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_turn_down_left/1-attributes"},{"type":"function","title":"Heroicons.arrow_turn_down_right/1","doc":"Renders the `arrow_turn_down_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_turn_down_right/1"},{"type":"function","title":"Examples - Heroicons.arrow_turn_down_right/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_turn_down_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_turn_down_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_turn_down_right/1-attributes"},{"type":"function","title":"Heroicons.arrow_turn_left_down/1","doc":"Renders the `arrow_turn_left_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_turn_left_down/1"},{"type":"function","title":"Examples - Heroicons.arrow_turn_left_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_turn_left_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_turn_left_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_turn_left_down/1-attributes"},{"type":"function","title":"Heroicons.arrow_turn_left_up/1","doc":"Renders the `arrow_turn_left_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_turn_left_up/1"},{"type":"function","title":"Examples - Heroicons.arrow_turn_left_up/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_turn_left_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_turn_left_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_turn_left_up/1-attributes"},{"type":"function","title":"Heroicons.arrow_turn_right_down/1","doc":"Renders the `arrow_turn_right_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_turn_right_down/1"},{"type":"function","title":"Examples - Heroicons.arrow_turn_right_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_turn_right_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_turn_right_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_turn_right_down/1-attributes"},{"type":"function","title":"Heroicons.arrow_turn_right_up/1","doc":"Renders the `arrow_turn_right_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_turn_right_up/1"},{"type":"function","title":"Examples - Heroicons.arrow_turn_right_up/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_turn_right_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_turn_right_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_turn_right_up/1-attributes"},{"type":"function","title":"Heroicons.arrow_turn_up_left/1","doc":"Renders the `arrow_turn_up_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_turn_up_left/1"},{"type":"function","title":"Examples - Heroicons.arrow_turn_up_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_turn_up_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_turn_up_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_turn_up_left/1-attributes"},{"type":"function","title":"Heroicons.arrow_turn_up_right/1","doc":"Renders the `arrow_turn_up_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_turn_up_right/1"},{"type":"function","title":"Examples - Heroicons.arrow_turn_up_right/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_turn_up_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_turn_up_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_turn_up_right/1-attributes"},{"type":"function","title":"Heroicons.arrow_up/1","doc":"Renders the `arrow_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_up/1"},{"type":"function","title":"Examples - Heroicons.arrow_up/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_up/1-attributes"},{"type":"function","title":"Heroicons.arrow_up_circle/1","doc":"Renders the `arrow_up_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_up_circle/1"},{"type":"function","title":"Examples - Heroicons.arrow_up_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_up_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_up_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_up_circle/1-attributes"},{"type":"function","title":"Heroicons.arrow_up_left/1","doc":"Renders the `arrow_up_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_up_left/1"},{"type":"function","title":"Examples - Heroicons.arrow_up_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_up_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_up_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_up_left/1-attributes"},{"type":"function","title":"Heroicons.arrow_up_on_square/1","doc":"Renders the `arrow_up_on_square` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_up_on_square/1"},{"type":"function","title":"Examples - Heroicons.arrow_up_on_square/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_up_on_square/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_up_on_square/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_up_on_square/1-attributes"},{"type":"function","title":"Heroicons.arrow_up_on_square_stack/1","doc":"Renders the `arrow_up_on_square_stack` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_up_on_square_stack/1"},{"type":"function","title":"Examples - Heroicons.arrow_up_on_square_stack/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_up_on_square_stack/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_up_on_square_stack/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_up_on_square_stack/1-attributes"},{"type":"function","title":"Heroicons.arrow_up_right/1","doc":"Renders the `arrow_up_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_up_right/1"},{"type":"function","title":"Examples - Heroicons.arrow_up_right/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_up_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_up_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_up_right/1-attributes"},{"type":"function","title":"Heroicons.arrow_up_tray/1","doc":"Renders the `arrow_up_tray` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_up_tray/1"},{"type":"function","title":"Examples - Heroicons.arrow_up_tray/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_up_tray/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_up_tray/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_up_tray/1-attributes"},{"type":"function","title":"Heroicons.arrow_uturn_down/1","doc":"Renders the `arrow_uturn_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_uturn_down/1"},{"type":"function","title":"Examples - Heroicons.arrow_uturn_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_uturn_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_uturn_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_uturn_down/1-attributes"},{"type":"function","title":"Heroicons.arrow_uturn_left/1","doc":"Renders the `arrow_uturn_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_uturn_left/1"},{"type":"function","title":"Examples - Heroicons.arrow_uturn_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_uturn_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_uturn_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_uturn_left/1-attributes"},{"type":"function","title":"Heroicons.arrow_uturn_right/1","doc":"Renders the `arrow_uturn_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_uturn_right/1"},{"type":"function","title":"Examples - Heroicons.arrow_uturn_right/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_uturn_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_uturn_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_uturn_right/1-attributes"},{"type":"function","title":"Heroicons.arrow_uturn_up/1","doc":"Renders the `arrow_uturn_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrow_uturn_up/1"},{"type":"function","title":"Examples - Heroicons.arrow_uturn_up/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrow_uturn_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrow_uturn_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrow_uturn_up/1-attributes"},{"type":"function","title":"Heroicons.arrows_pointing_in/1","doc":"Renders the `arrows_pointing_in` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrows_pointing_in/1"},{"type":"function","title":"Examples - Heroicons.arrows_pointing_in/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrows_pointing_in/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrows_pointing_in/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrows_pointing_in/1-attributes"},{"type":"function","title":"Heroicons.arrows_pointing_out/1","doc":"Renders the `arrows_pointing_out` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrows_pointing_out/1"},{"type":"function","title":"Examples - Heroicons.arrows_pointing_out/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrows_pointing_out/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrows_pointing_out/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrows_pointing_out/1-attributes"},{"type":"function","title":"Heroicons.arrows_right_left/1","doc":"Renders the `arrows_right_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrows_right_left/1"},{"type":"function","title":"Examples - Heroicons.arrows_right_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrows_right_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrows_right_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrows_right_left/1-attributes"},{"type":"function","title":"Heroicons.arrows_up_down/1","doc":"Renders the `arrows_up_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#arrows_up_down/1"},{"type":"function","title":"Examples - Heroicons.arrows_up_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#arrows_up_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.arrows_up_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#arrows_up_down/1-attributes"},{"type":"function","title":"Heroicons.at_symbol/1","doc":"Renders the `at_symbol` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#at_symbol/1"},{"type":"function","title":"Examples - Heroicons.at_symbol/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#at_symbol/1-examples"},{"type":"function","title":"Attributes - Heroicons.at_symbol/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#at_symbol/1-attributes"},{"type":"function","title":"Heroicons.backspace/1","doc":"Renders the `backspace` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#backspace/1"},{"type":"function","title":"Examples - Heroicons.backspace/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#backspace/1-examples"},{"type":"function","title":"Attributes - Heroicons.backspace/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#backspace/1-attributes"},{"type":"function","title":"Heroicons.backward/1","doc":"Renders the `backward` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#backward/1"},{"type":"function","title":"Examples - Heroicons.backward/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#backward/1-examples"},{"type":"function","title":"Attributes - Heroicons.backward/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#backward/1-attributes"},{"type":"function","title":"Heroicons.banknotes/1","doc":"Renders the `banknotes` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#banknotes/1"},{"type":"function","title":"Examples - Heroicons.banknotes/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#banknotes/1-examples"},{"type":"function","title":"Attributes - Heroicons.banknotes/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#banknotes/1-attributes"},{"type":"function","title":"Heroicons.bars_2/1","doc":"Renders the `bars_2` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bars_2/1"},{"type":"function","title":"Examples - Heroicons.bars_2/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bars_2/1-examples"},{"type":"function","title":"Attributes - Heroicons.bars_2/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bars_2/1-attributes"},{"type":"function","title":"Heroicons.bars_3/1","doc":"Renders the `bars_3` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bars_3/1"},{"type":"function","title":"Examples - Heroicons.bars_3/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bars_3/1-examples"},{"type":"function","title":"Attributes - Heroicons.bars_3/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bars_3/1-attributes"},{"type":"function","title":"Heroicons.bars_3_bottom_left/1","doc":"Renders the `bars_3_bottom_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bars_3_bottom_left/1"},{"type":"function","title":"Examples - Heroicons.bars_3_bottom_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bars_3_bottom_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.bars_3_bottom_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bars_3_bottom_left/1-attributes"},{"type":"function","title":"Heroicons.bars_3_bottom_right/1","doc":"Renders the `bars_3_bottom_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bars_3_bottom_right/1"},{"type":"function","title":"Examples - Heroicons.bars_3_bottom_right/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bars_3_bottom_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.bars_3_bottom_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bars_3_bottom_right/1-attributes"},{"type":"function","title":"Heroicons.bars_3_center_left/1","doc":"Renders the `bars_3_center_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bars_3_center_left/1"},{"type":"function","title":"Examples - Heroicons.bars_3_center_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bars_3_center_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.bars_3_center_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bars_3_center_left/1-attributes"},{"type":"function","title":"Heroicons.bars_4/1","doc":"Renders the `bars_4` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bars_4/1"},{"type":"function","title":"Examples - Heroicons.bars_4/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bars_4/1-examples"},{"type":"function","title":"Attributes - Heroicons.bars_4/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bars_4/1-attributes"},{"type":"function","title":"Heroicons.bars_arrow_down/1","doc":"Renders the `bars_arrow_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bars_arrow_down/1"},{"type":"function","title":"Examples - Heroicons.bars_arrow_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bars_arrow_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.bars_arrow_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bars_arrow_down/1-attributes"},{"type":"function","title":"Heroicons.bars_arrow_up/1","doc":"Renders the `bars_arrow_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bars_arrow_up/1"},{"type":"function","title":"Examples - Heroicons.bars_arrow_up/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bars_arrow_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.bars_arrow_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bars_arrow_up/1-attributes"},{"type":"function","title":"Heroicons.battery_0/1","doc":"Renders the `battery_0` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#battery_0/1"},{"type":"function","title":"Examples - Heroicons.battery_0/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#battery_0/1-examples"},{"type":"function","title":"Attributes - Heroicons.battery_0/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#battery_0/1-attributes"},{"type":"function","title":"Heroicons.battery_50/1","doc":"Renders the `battery_50` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#battery_50/1"},{"type":"function","title":"Examples - Heroicons.battery_50/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#battery_50/1-examples"},{"type":"function","title":"Attributes - Heroicons.battery_50/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#battery_50/1-attributes"},{"type":"function","title":"Heroicons.battery_100/1","doc":"Renders the `battery_100` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#battery_100/1"},{"type":"function","title":"Examples - Heroicons.battery_100/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#battery_100/1-examples"},{"type":"function","title":"Attributes - Heroicons.battery_100/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#battery_100/1-attributes"},{"type":"function","title":"Heroicons.beaker/1","doc":"Renders the `beaker` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#beaker/1"},{"type":"function","title":"Examples - Heroicons.beaker/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#beaker/1-examples"},{"type":"function","title":"Attributes - Heroicons.beaker/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#beaker/1-attributes"},{"type":"function","title":"Heroicons.bell/1","doc":"Renders the `bell` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bell/1"},{"type":"function","title":"Examples - Heroicons.bell/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bell/1-examples"},{"type":"function","title":"Attributes - Heroicons.bell/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bell/1-attributes"},{"type":"function","title":"Heroicons.bell_alert/1","doc":"Renders the `bell_alert` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bell_alert/1"},{"type":"function","title":"Examples - Heroicons.bell_alert/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bell_alert/1-examples"},{"type":"function","title":"Attributes - Heroicons.bell_alert/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bell_alert/1-attributes"},{"type":"function","title":"Heroicons.bell_slash/1","doc":"Renders the `bell_slash` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bell_slash/1"},{"type":"function","title":"Examples - Heroicons.bell_slash/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bell_slash/1-examples"},{"type":"function","title":"Attributes - Heroicons.bell_slash/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bell_slash/1-attributes"},{"type":"function","title":"Heroicons.bell_snooze/1","doc":"Renders the `bell_snooze` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bell_snooze/1"},{"type":"function","title":"Examples - Heroicons.bell_snooze/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bell_snooze/1-examples"},{"type":"function","title":"Attributes - Heroicons.bell_snooze/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bell_snooze/1-attributes"},{"type":"function","title":"Heroicons.bold/1","doc":"Renders the `bold` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bold/1"},{"type":"function","title":"Examples - Heroicons.bold/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bold/1-examples"},{"type":"function","title":"Attributes - Heroicons.bold/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bold/1-attributes"},{"type":"function","title":"Heroicons.bolt/1","doc":"Renders the `bolt` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bolt/1"},{"type":"function","title":"Examples - Heroicons.bolt/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bolt/1-examples"},{"type":"function","title":"Attributes - Heroicons.bolt/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bolt/1-attributes"},{"type":"function","title":"Heroicons.bolt_slash/1","doc":"Renders the `bolt_slash` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bolt_slash/1"},{"type":"function","title":"Examples - Heroicons.bolt_slash/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bolt_slash/1-examples"},{"type":"function","title":"Attributes - Heroicons.bolt_slash/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bolt_slash/1-attributes"},{"type":"function","title":"Heroicons.book_open/1","doc":"Renders the `book_open` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#book_open/1"},{"type":"function","title":"Examples - Heroicons.book_open/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#book_open/1-examples"},{"type":"function","title":"Attributes - Heroicons.book_open/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#book_open/1-attributes"},{"type":"function","title":"Heroicons.bookmark/1","doc":"Renders the `bookmark` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bookmark/1"},{"type":"function","title":"Examples - Heroicons.bookmark/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bookmark/1-examples"},{"type":"function","title":"Attributes - Heroicons.bookmark/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bookmark/1-attributes"},{"type":"function","title":"Heroicons.bookmark_slash/1","doc":"Renders the `bookmark_slash` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bookmark_slash/1"},{"type":"function","title":"Examples - Heroicons.bookmark_slash/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bookmark_slash/1-examples"},{"type":"function","title":"Attributes - Heroicons.bookmark_slash/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bookmark_slash/1-attributes"},{"type":"function","title":"Heroicons.bookmark_square/1","doc":"Renders the `bookmark_square` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bookmark_square/1"},{"type":"function","title":"Examples - Heroicons.bookmark_square/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bookmark_square/1-examples"},{"type":"function","title":"Attributes - Heroicons.bookmark_square/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bookmark_square/1-attributes"},{"type":"function","title":"Heroicons.briefcase/1","doc":"Renders the `briefcase` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#briefcase/1"},{"type":"function","title":"Examples - Heroicons.briefcase/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#briefcase/1-examples"},{"type":"function","title":"Attributes - Heroicons.briefcase/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#briefcase/1-attributes"},{"type":"function","title":"Heroicons.bug_ant/1","doc":"Renders the `bug_ant` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#bug_ant/1"},{"type":"function","title":"Examples - Heroicons.bug_ant/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#bug_ant/1-examples"},{"type":"function","title":"Attributes - Heroicons.bug_ant/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#bug_ant/1-attributes"},{"type":"function","title":"Heroicons.building_library/1","doc":"Renders the `building_library` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#building_library/1"},{"type":"function","title":"Examples - Heroicons.building_library/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#building_library/1-examples"},{"type":"function","title":"Attributes - Heroicons.building_library/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#building_library/1-attributes"},{"type":"function","title":"Heroicons.building_office/1","doc":"Renders the `building_office` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#building_office/1"},{"type":"function","title":"Examples - Heroicons.building_office/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#building_office/1-examples"},{"type":"function","title":"Attributes - Heroicons.building_office/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#building_office/1-attributes"},{"type":"function","title":"Heroicons.building_office_2/1","doc":"Renders the `building_office_2` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#building_office_2/1"},{"type":"function","title":"Examples - Heroicons.building_office_2/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#building_office_2/1-examples"},{"type":"function","title":"Attributes - Heroicons.building_office_2/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#building_office_2/1-attributes"},{"type":"function","title":"Heroicons.building_storefront/1","doc":"Renders the `building_storefront` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#building_storefront/1"},{"type":"function","title":"Examples - Heroicons.building_storefront/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#building_storefront/1-examples"},{"type":"function","title":"Attributes - Heroicons.building_storefront/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#building_storefront/1-attributes"},{"type":"function","title":"Heroicons.cake/1","doc":"Renders the `cake` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#cake/1"},{"type":"function","title":"Examples - Heroicons.cake/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#cake/1-examples"},{"type":"function","title":"Attributes - Heroicons.cake/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#cake/1-attributes"},{"type":"function","title":"Heroicons.calculator/1","doc":"Renders the `calculator` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#calculator/1"},{"type":"function","title":"Examples - Heroicons.calculator/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#calculator/1-examples"},{"type":"function","title":"Attributes - Heroicons.calculator/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#calculator/1-attributes"},{"type":"function","title":"Heroicons.calendar/1","doc":"Renders the `calendar` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#calendar/1"},{"type":"function","title":"Examples - Heroicons.calendar/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#calendar/1-examples"},{"type":"function","title":"Attributes - Heroicons.calendar/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#calendar/1-attributes"},{"type":"function","title":"Heroicons.calendar_date_range/1","doc":"Renders the `calendar_date_range` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#calendar_date_range/1"},{"type":"function","title":"Examples - Heroicons.calendar_date_range/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#calendar_date_range/1-examples"},{"type":"function","title":"Attributes - Heroicons.calendar_date_range/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#calendar_date_range/1-attributes"},{"type":"function","title":"Heroicons.calendar_days/1","doc":"Renders the `calendar_days` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#calendar_days/1"},{"type":"function","title":"Examples - Heroicons.calendar_days/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#calendar_days/1-examples"},{"type":"function","title":"Attributes - Heroicons.calendar_days/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#calendar_days/1-attributes"},{"type":"function","title":"Heroicons.camera/1","doc":"Renders the `camera` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#camera/1"},{"type":"function","title":"Examples - Heroicons.camera/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#camera/1-examples"},{"type":"function","title":"Attributes - Heroicons.camera/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#camera/1-attributes"},{"type":"function","title":"Heroicons.chart_bar/1","doc":"Renders the `chart_bar` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chart_bar/1"},{"type":"function","title":"Examples - Heroicons.chart_bar/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chart_bar/1-examples"},{"type":"function","title":"Attributes - Heroicons.chart_bar/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chart_bar/1-attributes"},{"type":"function","title":"Heroicons.chart_bar_square/1","doc":"Renders the `chart_bar_square` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chart_bar_square/1"},{"type":"function","title":"Examples - Heroicons.chart_bar_square/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chart_bar_square/1-examples"},{"type":"function","title":"Attributes - Heroicons.chart_bar_square/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chart_bar_square/1-attributes"},{"type":"function","title":"Heroicons.chart_pie/1","doc":"Renders the `chart_pie` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chart_pie/1"},{"type":"function","title":"Examples - Heroicons.chart_pie/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chart_pie/1-examples"},{"type":"function","title":"Attributes - Heroicons.chart_pie/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chart_pie/1-attributes"},{"type":"function","title":"Heroicons.chat_bubble_bottom_center/1","doc":"Renders the `chat_bubble_bottom_center` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chat_bubble_bottom_center/1"},{"type":"function","title":"Examples - Heroicons.chat_bubble_bottom_center/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chat_bubble_bottom_center/1-examples"},{"type":"function","title":"Attributes - Heroicons.chat_bubble_bottom_center/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chat_bubble_bottom_center/1-attributes"},{"type":"function","title":"Heroicons.chat_bubble_bottom_center_text/1","doc":"Renders the `chat_bubble_bottom_center_text` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chat_bubble_bottom_center_text/1"},{"type":"function","title":"Examples - Heroicons.chat_bubble_bottom_center_text/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chat_bubble_bottom_center_text/1-examples"},{"type":"function","title":"Attributes - Heroicons.chat_bubble_bottom_center_text/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chat_bubble_bottom_center_text/1-attributes"},{"type":"function","title":"Heroicons.chat_bubble_left/1","doc":"Renders the `chat_bubble_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chat_bubble_left/1"},{"type":"function","title":"Examples - Heroicons.chat_bubble_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chat_bubble_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.chat_bubble_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chat_bubble_left/1-attributes"},{"type":"function","title":"Heroicons.chat_bubble_left_ellipsis/1","doc":"Renders the `chat_bubble_left_ellipsis` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chat_bubble_left_ellipsis/1"},{"type":"function","title":"Examples - Heroicons.chat_bubble_left_ellipsis/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chat_bubble_left_ellipsis/1-examples"},{"type":"function","title":"Attributes - Heroicons.chat_bubble_left_ellipsis/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chat_bubble_left_ellipsis/1-attributes"},{"type":"function","title":"Heroicons.chat_bubble_left_right/1","doc":"Renders the `chat_bubble_left_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chat_bubble_left_right/1"},{"type":"function","title":"Examples - Heroicons.chat_bubble_left_right/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chat_bubble_left_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.chat_bubble_left_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chat_bubble_left_right/1-attributes"},{"type":"function","title":"Heroicons.chat_bubble_oval_left/1","doc":"Renders the `chat_bubble_oval_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chat_bubble_oval_left/1"},{"type":"function","title":"Examples - Heroicons.chat_bubble_oval_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chat_bubble_oval_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.chat_bubble_oval_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chat_bubble_oval_left/1-attributes"},{"type":"function","title":"Heroicons.chat_bubble_oval_left_ellipsis/1","doc":"Renders the `chat_bubble_oval_left_ellipsis` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chat_bubble_oval_left_ellipsis/1"},{"type":"function","title":"Examples - Heroicons.chat_bubble_oval_left_ellipsis/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chat_bubble_oval_left_ellipsis/1-examples"},{"type":"function","title":"Attributes - Heroicons.chat_bubble_oval_left_ellipsis/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chat_bubble_oval_left_ellipsis/1-attributes"},{"type":"function","title":"Heroicons.check/1","doc":"Renders the `check` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#check/1"},{"type":"function","title":"Examples - Heroicons.check/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#check/1-examples"},{"type":"function","title":"Attributes - Heroicons.check/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#check/1-attributes"},{"type":"function","title":"Heroicons.check_badge/1","doc":"Renders the `check_badge` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#check_badge/1"},{"type":"function","title":"Examples - Heroicons.check_badge/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#check_badge/1-examples"},{"type":"function","title":"Attributes - Heroicons.check_badge/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#check_badge/1-attributes"},{"type":"function","title":"Heroicons.check_circle/1","doc":"Renders the `check_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#check_circle/1"},{"type":"function","title":"Examples - Heroicons.check_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#check_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.check_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#check_circle/1-attributes"},{"type":"function","title":"Heroicons.chevron_double_down/1","doc":"Renders the `chevron_double_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chevron_double_down/1"},{"type":"function","title":"Examples - Heroicons.chevron_double_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chevron_double_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.chevron_double_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chevron_double_down/1-attributes"},{"type":"function","title":"Heroicons.chevron_double_left/1","doc":"Renders the `chevron_double_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chevron_double_left/1"},{"type":"function","title":"Examples - Heroicons.chevron_double_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chevron_double_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.chevron_double_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chevron_double_left/1-attributes"},{"type":"function","title":"Heroicons.chevron_double_right/1","doc":"Renders the `chevron_double_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chevron_double_right/1"},{"type":"function","title":"Examples - Heroicons.chevron_double_right/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chevron_double_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.chevron_double_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chevron_double_right/1-attributes"},{"type":"function","title":"Heroicons.chevron_double_up/1","doc":"Renders the `chevron_double_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chevron_double_up/1"},{"type":"function","title":"Examples - Heroicons.chevron_double_up/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chevron_double_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.chevron_double_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chevron_double_up/1-attributes"},{"type":"function","title":"Heroicons.chevron_down/1","doc":"Renders the `chevron_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chevron_down/1"},{"type":"function","title":"Examples - Heroicons.chevron_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chevron_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.chevron_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chevron_down/1-attributes"},{"type":"function","title":"Heroicons.chevron_left/1","doc":"Renders the `chevron_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chevron_left/1"},{"type":"function","title":"Examples - Heroicons.chevron_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chevron_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.chevron_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chevron_left/1-attributes"},{"type":"function","title":"Heroicons.chevron_right/1","doc":"Renders the `chevron_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chevron_right/1"},{"type":"function","title":"Examples - Heroicons.chevron_right/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chevron_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.chevron_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chevron_right/1-attributes"},{"type":"function","title":"Heroicons.chevron_up/1","doc":"Renders the `chevron_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chevron_up/1"},{"type":"function","title":"Examples - Heroicons.chevron_up/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chevron_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.chevron_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chevron_up/1-attributes"},{"type":"function","title":"Heroicons.chevron_up_down/1","doc":"Renders the `chevron_up_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#chevron_up_down/1"},{"type":"function","title":"Examples - Heroicons.chevron_up_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#chevron_up_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.chevron_up_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#chevron_up_down/1-attributes"},{"type":"function","title":"Heroicons.circle_stack/1","doc":"Renders the `circle_stack` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#circle_stack/1"},{"type":"function","title":"Examples - Heroicons.circle_stack/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#circle_stack/1-examples"},{"type":"function","title":"Attributes - Heroicons.circle_stack/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#circle_stack/1-attributes"},{"type":"function","title":"Heroicons.clipboard/1","doc":"Renders the `clipboard` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#clipboard/1"},{"type":"function","title":"Examples - Heroicons.clipboard/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#clipboard/1-examples"},{"type":"function","title":"Attributes - Heroicons.clipboard/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#clipboard/1-attributes"},{"type":"function","title":"Heroicons.clipboard_document/1","doc":"Renders the `clipboard_document` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#clipboard_document/1"},{"type":"function","title":"Examples - Heroicons.clipboard_document/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#clipboard_document/1-examples"},{"type":"function","title":"Attributes - Heroicons.clipboard_document/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#clipboard_document/1-attributes"},{"type":"function","title":"Heroicons.clipboard_document_check/1","doc":"Renders the `clipboard_document_check` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#clipboard_document_check/1"},{"type":"function","title":"Examples - Heroicons.clipboard_document_check/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#clipboard_document_check/1-examples"},{"type":"function","title":"Attributes - Heroicons.clipboard_document_check/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#clipboard_document_check/1-attributes"},{"type":"function","title":"Heroicons.clipboard_document_list/1","doc":"Renders the `clipboard_document_list` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#clipboard_document_list/1"},{"type":"function","title":"Examples - Heroicons.clipboard_document_list/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#clipboard_document_list/1-examples"},{"type":"function","title":"Attributes - Heroicons.clipboard_document_list/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#clipboard_document_list/1-attributes"},{"type":"function","title":"Heroicons.clock/1","doc":"Renders the `clock` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#clock/1"},{"type":"function","title":"Examples - Heroicons.clock/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#clock/1-examples"},{"type":"function","title":"Attributes - Heroicons.clock/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#clock/1-attributes"},{"type":"function","title":"Heroicons.cloud/1","doc":"Renders the `cloud` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#cloud/1"},{"type":"function","title":"Examples - Heroicons.cloud/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#cloud/1-examples"},{"type":"function","title":"Attributes - Heroicons.cloud/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#cloud/1-attributes"},{"type":"function","title":"Heroicons.cloud_arrow_down/1","doc":"Renders the `cloud_arrow_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#cloud_arrow_down/1"},{"type":"function","title":"Examples - Heroicons.cloud_arrow_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#cloud_arrow_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.cloud_arrow_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#cloud_arrow_down/1-attributes"},{"type":"function","title":"Heroicons.cloud_arrow_up/1","doc":"Renders the `cloud_arrow_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#cloud_arrow_up/1"},{"type":"function","title":"Examples - Heroicons.cloud_arrow_up/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#cloud_arrow_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.cloud_arrow_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#cloud_arrow_up/1-attributes"},{"type":"function","title":"Heroicons.code_bracket/1","doc":"Renders the `code_bracket` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#code_bracket/1"},{"type":"function","title":"Examples - Heroicons.code_bracket/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#code_bracket/1-examples"},{"type":"function","title":"Attributes - Heroicons.code_bracket/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#code_bracket/1-attributes"},{"type":"function","title":"Heroicons.code_bracket_square/1","doc":"Renders the `code_bracket_square` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#code_bracket_square/1"},{"type":"function","title":"Examples - Heroicons.code_bracket_square/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#code_bracket_square/1-examples"},{"type":"function","title":"Attributes - Heroicons.code_bracket_square/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#code_bracket_square/1-attributes"},{"type":"function","title":"Heroicons.cog/1","doc":"Renders the `cog` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#cog/1"},{"type":"function","title":"Examples - Heroicons.cog/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#cog/1-examples"},{"type":"function","title":"Attributes - Heroicons.cog/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#cog/1-attributes"},{"type":"function","title":"Heroicons.cog_6_tooth/1","doc":"Renders the `cog_6_tooth` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#cog_6_tooth/1"},{"type":"function","title":"Examples - Heroicons.cog_6_tooth/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#cog_6_tooth/1-examples"},{"type":"function","title":"Attributes - Heroicons.cog_6_tooth/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#cog_6_tooth/1-attributes"},{"type":"function","title":"Heroicons.cog_8_tooth/1","doc":"Renders the `cog_8_tooth` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#cog_8_tooth/1"},{"type":"function","title":"Examples - Heroicons.cog_8_tooth/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#cog_8_tooth/1-examples"},{"type":"function","title":"Attributes - Heroicons.cog_8_tooth/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#cog_8_tooth/1-attributes"},{"type":"function","title":"Heroicons.command_line/1","doc":"Renders the `command_line` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#command_line/1"},{"type":"function","title":"Examples - Heroicons.command_line/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#command_line/1-examples"},{"type":"function","title":"Attributes - Heroicons.command_line/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#command_line/1-attributes"},{"type":"function","title":"Heroicons.computer_desktop/1","doc":"Renders the `computer_desktop` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#computer_desktop/1"},{"type":"function","title":"Examples - Heroicons.computer_desktop/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#computer_desktop/1-examples"},{"type":"function","title":"Attributes - Heroicons.computer_desktop/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#computer_desktop/1-attributes"},{"type":"function","title":"Heroicons.cpu_chip/1","doc":"Renders the `cpu_chip` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#cpu_chip/1"},{"type":"function","title":"Examples - Heroicons.cpu_chip/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#cpu_chip/1-examples"},{"type":"function","title":"Attributes - Heroicons.cpu_chip/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#cpu_chip/1-attributes"},{"type":"function","title":"Heroicons.credit_card/1","doc":"Renders the `credit_card` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#credit_card/1"},{"type":"function","title":"Examples - Heroicons.credit_card/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#credit_card/1-examples"},{"type":"function","title":"Attributes - Heroicons.credit_card/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#credit_card/1-attributes"},{"type":"function","title":"Heroicons.cube/1","doc":"Renders the `cube` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#cube/1"},{"type":"function","title":"Examples - Heroicons.cube/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#cube/1-examples"},{"type":"function","title":"Attributes - Heroicons.cube/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#cube/1-attributes"},{"type":"function","title":"Heroicons.cube_transparent/1","doc":"Renders the `cube_transparent` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#cube_transparent/1"},{"type":"function","title":"Examples - Heroicons.cube_transparent/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#cube_transparent/1-examples"},{"type":"function","title":"Attributes - Heroicons.cube_transparent/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#cube_transparent/1-attributes"},{"type":"function","title":"Heroicons.currency_bangladeshi/1","doc":"Renders the `currency_bangladeshi` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#currency_bangladeshi/1"},{"type":"function","title":"Examples - Heroicons.currency_bangladeshi/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#currency_bangladeshi/1-examples"},{"type":"function","title":"Attributes - Heroicons.currency_bangladeshi/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#currency_bangladeshi/1-attributes"},{"type":"function","title":"Heroicons.currency_dollar/1","doc":"Renders the `currency_dollar` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#currency_dollar/1"},{"type":"function","title":"Examples - Heroicons.currency_dollar/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#currency_dollar/1-examples"},{"type":"function","title":"Attributes - Heroicons.currency_dollar/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#currency_dollar/1-attributes"},{"type":"function","title":"Heroicons.currency_euro/1","doc":"Renders the `currency_euro` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#currency_euro/1"},{"type":"function","title":"Examples - Heroicons.currency_euro/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#currency_euro/1-examples"},{"type":"function","title":"Attributes - Heroicons.currency_euro/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#currency_euro/1-attributes"},{"type":"function","title":"Heroicons.currency_pound/1","doc":"Renders the `currency_pound` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#currency_pound/1"},{"type":"function","title":"Examples - Heroicons.currency_pound/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#currency_pound/1-examples"},{"type":"function","title":"Attributes - Heroicons.currency_pound/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#currency_pound/1-attributes"},{"type":"function","title":"Heroicons.currency_rupee/1","doc":"Renders the `currency_rupee` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#currency_rupee/1"},{"type":"function","title":"Examples - Heroicons.currency_rupee/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#currency_rupee/1-examples"},{"type":"function","title":"Attributes - Heroicons.currency_rupee/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#currency_rupee/1-attributes"},{"type":"function","title":"Heroicons.currency_yen/1","doc":"Renders the `currency_yen` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#currency_yen/1"},{"type":"function","title":"Examples - Heroicons.currency_yen/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#currency_yen/1-examples"},{"type":"function","title":"Attributes - Heroicons.currency_yen/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#currency_yen/1-attributes"},{"type":"function","title":"Heroicons.cursor_arrow_rays/1","doc":"Renders the `cursor_arrow_rays` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#cursor_arrow_rays/1"},{"type":"function","title":"Examples - Heroicons.cursor_arrow_rays/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#cursor_arrow_rays/1-examples"},{"type":"function","title":"Attributes - Heroicons.cursor_arrow_rays/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#cursor_arrow_rays/1-attributes"},{"type":"function","title":"Heroicons.cursor_arrow_ripple/1","doc":"Renders the `cursor_arrow_ripple` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#cursor_arrow_ripple/1"},{"type":"function","title":"Examples - Heroicons.cursor_arrow_ripple/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#cursor_arrow_ripple/1-examples"},{"type":"function","title":"Attributes - Heroicons.cursor_arrow_ripple/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#cursor_arrow_ripple/1-attributes"},{"type":"function","title":"Heroicons.device_phone_mobile/1","doc":"Renders the `device_phone_mobile` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#device_phone_mobile/1"},{"type":"function","title":"Examples - Heroicons.device_phone_mobile/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#device_phone_mobile/1-examples"},{"type":"function","title":"Attributes - Heroicons.device_phone_mobile/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#device_phone_mobile/1-attributes"},{"type":"function","title":"Heroicons.device_tablet/1","doc":"Renders the `device_tablet` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#device_tablet/1"},{"type":"function","title":"Examples - Heroicons.device_tablet/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#device_tablet/1-examples"},{"type":"function","title":"Attributes - Heroicons.device_tablet/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#device_tablet/1-attributes"},{"type":"function","title":"Heroicons.divide/1","doc":"Renders the `divide` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#divide/1"},{"type":"function","title":"Examples - Heroicons.divide/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#divide/1-examples"},{"type":"function","title":"Attributes - Heroicons.divide/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#divide/1-attributes"},{"type":"function","title":"Heroicons.document/1","doc":"Renders the `document` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document/1"},{"type":"function","title":"Examples - Heroicons.document/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document/1-examples"},{"type":"function","title":"Attributes - Heroicons.document/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document/1-attributes"},{"type":"function","title":"Heroicons.document_arrow_down/1","doc":"Renders the `document_arrow_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_arrow_down/1"},{"type":"function","title":"Examples - Heroicons.document_arrow_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_arrow_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_arrow_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_arrow_down/1-attributes"},{"type":"function","title":"Heroicons.document_arrow_up/1","doc":"Renders the `document_arrow_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_arrow_up/1"},{"type":"function","title":"Examples - Heroicons.document_arrow_up/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_arrow_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_arrow_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_arrow_up/1-attributes"},{"type":"function","title":"Heroicons.document_chart_bar/1","doc":"Renders the `document_chart_bar` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_chart_bar/1"},{"type":"function","title":"Examples - Heroicons.document_chart_bar/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_chart_bar/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_chart_bar/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_chart_bar/1-attributes"},{"type":"function","title":"Heroicons.document_check/1","doc":"Renders the `document_check` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_check/1"},{"type":"function","title":"Examples - Heroicons.document_check/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_check/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_check/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_check/1-attributes"},{"type":"function","title":"Heroicons.document_currency_bangladeshi/1","doc":"Renders the `document_currency_bangladeshi` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_currency_bangladeshi/1"},{"type":"function","title":"Examples - Heroicons.document_currency_bangladeshi/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_currency_bangladeshi/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_currency_bangladeshi/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_currency_bangladeshi/1-attributes"},{"type":"function","title":"Heroicons.document_currency_dollar/1","doc":"Renders the `document_currency_dollar` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_currency_dollar/1"},{"type":"function","title":"Examples - Heroicons.document_currency_dollar/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_currency_dollar/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_currency_dollar/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_currency_dollar/1-attributes"},{"type":"function","title":"Heroicons.document_currency_euro/1","doc":"Renders the `document_currency_euro` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_currency_euro/1"},{"type":"function","title":"Examples - Heroicons.document_currency_euro/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_currency_euro/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_currency_euro/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_currency_euro/1-attributes"},{"type":"function","title":"Heroicons.document_currency_pound/1","doc":"Renders the `document_currency_pound` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_currency_pound/1"},{"type":"function","title":"Examples - Heroicons.document_currency_pound/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_currency_pound/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_currency_pound/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_currency_pound/1-attributes"},{"type":"function","title":"Heroicons.document_currency_rupee/1","doc":"Renders the `document_currency_rupee` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_currency_rupee/1"},{"type":"function","title":"Examples - Heroicons.document_currency_rupee/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_currency_rupee/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_currency_rupee/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_currency_rupee/1-attributes"},{"type":"function","title":"Heroicons.document_currency_yen/1","doc":"Renders the `document_currency_yen` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_currency_yen/1"},{"type":"function","title":"Examples - Heroicons.document_currency_yen/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_currency_yen/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_currency_yen/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_currency_yen/1-attributes"},{"type":"function","title":"Heroicons.document_duplicate/1","doc":"Renders the `document_duplicate` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_duplicate/1"},{"type":"function","title":"Examples - Heroicons.document_duplicate/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_duplicate/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_duplicate/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_duplicate/1-attributes"},{"type":"function","title":"Heroicons.document_magnifying_glass/1","doc":"Renders the `document_magnifying_glass` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_magnifying_glass/1"},{"type":"function","title":"Examples - Heroicons.document_magnifying_glass/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_magnifying_glass/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_magnifying_glass/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_magnifying_glass/1-attributes"},{"type":"function","title":"Heroicons.document_minus/1","doc":"Renders the `document_minus` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_minus/1"},{"type":"function","title":"Examples - Heroicons.document_minus/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_minus/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_minus/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_minus/1-attributes"},{"type":"function","title":"Heroicons.document_plus/1","doc":"Renders the `document_plus` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_plus/1"},{"type":"function","title":"Examples - Heroicons.document_plus/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_plus/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_plus/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_plus/1-attributes"},{"type":"function","title":"Heroicons.document_text/1","doc":"Renders the `document_text` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#document_text/1"},{"type":"function","title":"Examples - Heroicons.document_text/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#document_text/1-examples"},{"type":"function","title":"Attributes - Heroicons.document_text/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#document_text/1-attributes"},{"type":"function","title":"Heroicons.ellipsis_horizontal/1","doc":"Renders the `ellipsis_horizontal` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#ellipsis_horizontal/1"},{"type":"function","title":"Examples - Heroicons.ellipsis_horizontal/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#ellipsis_horizontal/1-examples"},{"type":"function","title":"Attributes - Heroicons.ellipsis_horizontal/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#ellipsis_horizontal/1-attributes"},{"type":"function","title":"Heroicons.ellipsis_horizontal_circle/1","doc":"Renders the `ellipsis_horizontal_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#ellipsis_horizontal_circle/1"},{"type":"function","title":"Examples - Heroicons.ellipsis_horizontal_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#ellipsis_horizontal_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.ellipsis_horizontal_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#ellipsis_horizontal_circle/1-attributes"},{"type":"function","title":"Heroicons.ellipsis_vertical/1","doc":"Renders the `ellipsis_vertical` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#ellipsis_vertical/1"},{"type":"function","title":"Examples - Heroicons.ellipsis_vertical/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#ellipsis_vertical/1-examples"},{"type":"function","title":"Attributes - Heroicons.ellipsis_vertical/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#ellipsis_vertical/1-attributes"},{"type":"function","title":"Heroicons.envelope/1","doc":"Renders the `envelope` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#envelope/1"},{"type":"function","title":"Examples - Heroicons.envelope/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#envelope/1-examples"},{"type":"function","title":"Attributes - Heroicons.envelope/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#envelope/1-attributes"},{"type":"function","title":"Heroicons.envelope_open/1","doc":"Renders the `envelope_open` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#envelope_open/1"},{"type":"function","title":"Examples - Heroicons.envelope_open/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#envelope_open/1-examples"},{"type":"function","title":"Attributes - Heroicons.envelope_open/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#envelope_open/1-attributes"},{"type":"function","title":"Heroicons.equals/1","doc":"Renders the `equals` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#equals/1"},{"type":"function","title":"Examples - Heroicons.equals/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#equals/1-examples"},{"type":"function","title":"Attributes - Heroicons.equals/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#equals/1-attributes"},{"type":"function","title":"Heroicons.exclamation_circle/1","doc":"Renders the `exclamation_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#exclamation_circle/1"},{"type":"function","title":"Examples - Heroicons.exclamation_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#exclamation_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.exclamation_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#exclamation_circle/1-attributes"},{"type":"function","title":"Heroicons.exclamation_triangle/1","doc":"Renders the `exclamation_triangle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#exclamation_triangle/1"},{"type":"function","title":"Examples - Heroicons.exclamation_triangle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#exclamation_triangle/1-examples"},{"type":"function","title":"Attributes - Heroicons.exclamation_triangle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#exclamation_triangle/1-attributes"},{"type":"function","title":"Heroicons.eye/1","doc":"Renders the `eye` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#eye/1"},{"type":"function","title":"Examples - Heroicons.eye/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#eye/1-examples"},{"type":"function","title":"Attributes - Heroicons.eye/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#eye/1-attributes"},{"type":"function","title":"Heroicons.eye_dropper/1","doc":"Renders the `eye_dropper` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#eye_dropper/1"},{"type":"function","title":"Examples - Heroicons.eye_dropper/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#eye_dropper/1-examples"},{"type":"function","title":"Attributes - Heroicons.eye_dropper/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#eye_dropper/1-attributes"},{"type":"function","title":"Heroicons.eye_slash/1","doc":"Renders the `eye_slash` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#eye_slash/1"},{"type":"function","title":"Examples - Heroicons.eye_slash/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#eye_slash/1-examples"},{"type":"function","title":"Attributes - Heroicons.eye_slash/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#eye_slash/1-attributes"},{"type":"function","title":"Heroicons.face_frown/1","doc":"Renders the `face_frown` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#face_frown/1"},{"type":"function","title":"Examples - Heroicons.face_frown/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#face_frown/1-examples"},{"type":"function","title":"Attributes - Heroicons.face_frown/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#face_frown/1-attributes"},{"type":"function","title":"Heroicons.face_smile/1","doc":"Renders the `face_smile` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#face_smile/1"},{"type":"function","title":"Examples - Heroicons.face_smile/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#face_smile/1-examples"},{"type":"function","title":"Attributes - Heroicons.face_smile/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#face_smile/1-attributes"},{"type":"function","title":"Heroicons.film/1","doc":"Renders the `film` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#film/1"},{"type":"function","title":"Examples - Heroicons.film/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#film/1-examples"},{"type":"function","title":"Attributes - Heroicons.film/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#film/1-attributes"},{"type":"function","title":"Heroicons.finger_print/1","doc":"Renders the `finger_print` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#finger_print/1"},{"type":"function","title":"Examples - Heroicons.finger_print/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#finger_print/1-examples"},{"type":"function","title":"Attributes - Heroicons.finger_print/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#finger_print/1-attributes"},{"type":"function","title":"Heroicons.fire/1","doc":"Renders the `fire` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#fire/1"},{"type":"function","title":"Examples - Heroicons.fire/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#fire/1-examples"},{"type":"function","title":"Attributes - Heroicons.fire/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#fire/1-attributes"},{"type":"function","title":"Heroicons.flag/1","doc":"Renders the `flag` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#flag/1"},{"type":"function","title":"Examples - Heroicons.flag/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#flag/1-examples"},{"type":"function","title":"Attributes - Heroicons.flag/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#flag/1-attributes"},{"type":"function","title":"Heroicons.folder/1","doc":"Renders the `folder` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#folder/1"},{"type":"function","title":"Examples - Heroicons.folder/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#folder/1-examples"},{"type":"function","title":"Attributes - Heroicons.folder/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#folder/1-attributes"},{"type":"function","title":"Heroicons.folder_arrow_down/1","doc":"Renders the `folder_arrow_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#folder_arrow_down/1"},{"type":"function","title":"Examples - Heroicons.folder_arrow_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#folder_arrow_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.folder_arrow_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#folder_arrow_down/1-attributes"},{"type":"function","title":"Heroicons.folder_minus/1","doc":"Renders the `folder_minus` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#folder_minus/1"},{"type":"function","title":"Examples - Heroicons.folder_minus/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#folder_minus/1-examples"},{"type":"function","title":"Attributes - Heroicons.folder_minus/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#folder_minus/1-attributes"},{"type":"function","title":"Heroicons.folder_open/1","doc":"Renders the `folder_open` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#folder_open/1"},{"type":"function","title":"Examples - Heroicons.folder_open/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#folder_open/1-examples"},{"type":"function","title":"Attributes - Heroicons.folder_open/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#folder_open/1-attributes"},{"type":"function","title":"Heroicons.folder_plus/1","doc":"Renders the `folder_plus` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#folder_plus/1"},{"type":"function","title":"Examples - Heroicons.folder_plus/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#folder_plus/1-examples"},{"type":"function","title":"Attributes - Heroicons.folder_plus/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#folder_plus/1-attributes"},{"type":"function","title":"Heroicons.forward/1","doc":"Renders the `forward` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#forward/1"},{"type":"function","title":"Examples - Heroicons.forward/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#forward/1-examples"},{"type":"function","title":"Attributes - Heroicons.forward/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#forward/1-attributes"},{"type":"function","title":"Heroicons.funnel/1","doc":"Renders the `funnel` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#funnel/1"},{"type":"function","title":"Examples - Heroicons.funnel/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#funnel/1-examples"},{"type":"function","title":"Attributes - Heroicons.funnel/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#funnel/1-attributes"},{"type":"function","title":"Heroicons.gif/1","doc":"Renders the `gif` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#gif/1"},{"type":"function","title":"Examples - Heroicons.gif/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#gif/1-examples"},{"type":"function","title":"Attributes - Heroicons.gif/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#gif/1-attributes"},{"type":"function","title":"Heroicons.gift/1","doc":"Renders the `gift` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#gift/1"},{"type":"function","title":"Examples - Heroicons.gift/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#gift/1-examples"},{"type":"function","title":"Attributes - Heroicons.gift/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#gift/1-attributes"},{"type":"function","title":"Heroicons.gift_top/1","doc":"Renders the `gift_top` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#gift_top/1"},{"type":"function","title":"Examples - Heroicons.gift_top/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#gift_top/1-examples"},{"type":"function","title":"Attributes - Heroicons.gift_top/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#gift_top/1-attributes"},{"type":"function","title":"Heroicons.globe_alt/1","doc":"Renders the `globe_alt` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#globe_alt/1"},{"type":"function","title":"Examples - Heroicons.globe_alt/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#globe_alt/1-examples"},{"type":"function","title":"Attributes - Heroicons.globe_alt/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#globe_alt/1-attributes"},{"type":"function","title":"Heroicons.globe_americas/1","doc":"Renders the `globe_americas` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#globe_americas/1"},{"type":"function","title":"Examples - Heroicons.globe_americas/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#globe_americas/1-examples"},{"type":"function","title":"Attributes - Heroicons.globe_americas/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#globe_americas/1-attributes"},{"type":"function","title":"Heroicons.globe_asia_australia/1","doc":"Renders the `globe_asia_australia` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#globe_asia_australia/1"},{"type":"function","title":"Examples - Heroicons.globe_asia_australia/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#globe_asia_australia/1-examples"},{"type":"function","title":"Attributes - Heroicons.globe_asia_australia/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#globe_asia_australia/1-attributes"},{"type":"function","title":"Heroicons.globe_europe_africa/1","doc":"Renders the `globe_europe_africa` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#globe_europe_africa/1"},{"type":"function","title":"Examples - Heroicons.globe_europe_africa/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#globe_europe_africa/1-examples"},{"type":"function","title":"Attributes - Heroicons.globe_europe_africa/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#globe_europe_africa/1-attributes"},{"type":"function","title":"Heroicons.h1/1","doc":"Renders the `h1` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#h1/1"},{"type":"function","title":"Examples - Heroicons.h1/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#h1/1-examples"},{"type":"function","title":"Attributes - Heroicons.h1/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#h1/1-attributes"},{"type":"function","title":"Heroicons.h2/1","doc":"Renders the `h2` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#h2/1"},{"type":"function","title":"Examples - Heroicons.h2/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#h2/1-examples"},{"type":"function","title":"Attributes - Heroicons.h2/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#h2/1-attributes"},{"type":"function","title":"Heroicons.h3/1","doc":"Renders the `h3` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#h3/1"},{"type":"function","title":"Examples - Heroicons.h3/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#h3/1-examples"},{"type":"function","title":"Attributes - Heroicons.h3/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#h3/1-attributes"},{"type":"function","title":"Heroicons.hand_raised/1","doc":"Renders the `hand_raised` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#hand_raised/1"},{"type":"function","title":"Examples - Heroicons.hand_raised/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#hand_raised/1-examples"},{"type":"function","title":"Attributes - Heroicons.hand_raised/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#hand_raised/1-attributes"},{"type":"function","title":"Heroicons.hand_thumb_down/1","doc":"Renders the `hand_thumb_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#hand_thumb_down/1"},{"type":"function","title":"Examples - Heroicons.hand_thumb_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#hand_thumb_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.hand_thumb_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#hand_thumb_down/1-attributes"},{"type":"function","title":"Heroicons.hand_thumb_up/1","doc":"Renders the `hand_thumb_up` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#hand_thumb_up/1"},{"type":"function","title":"Examples - Heroicons.hand_thumb_up/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#hand_thumb_up/1-examples"},{"type":"function","title":"Attributes - Heroicons.hand_thumb_up/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#hand_thumb_up/1-attributes"},{"type":"function","title":"Heroicons.hashtag/1","doc":"Renders the `hashtag` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#hashtag/1"},{"type":"function","title":"Examples - Heroicons.hashtag/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#hashtag/1-examples"},{"type":"function","title":"Attributes - Heroicons.hashtag/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#hashtag/1-attributes"},{"type":"function","title":"Heroicons.heart/1","doc":"Renders the `heart` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#heart/1"},{"type":"function","title":"Examples - Heroicons.heart/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#heart/1-examples"},{"type":"function","title":"Attributes - Heroicons.heart/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#heart/1-attributes"},{"type":"function","title":"Heroicons.home/1","doc":"Renders the `home` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#home/1"},{"type":"function","title":"Examples - Heroicons.home/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#home/1-examples"},{"type":"function","title":"Attributes - Heroicons.home/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#home/1-attributes"},{"type":"function","title":"Heroicons.home_modern/1","doc":"Renders the `home_modern` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#home_modern/1"},{"type":"function","title":"Examples - Heroicons.home_modern/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#home_modern/1-examples"},{"type":"function","title":"Attributes - Heroicons.home_modern/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#home_modern/1-attributes"},{"type":"function","title":"Heroicons.identification/1","doc":"Renders the `identification` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#identification/1"},{"type":"function","title":"Examples - Heroicons.identification/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#identification/1-examples"},{"type":"function","title":"Attributes - Heroicons.identification/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#identification/1-attributes"},{"type":"function","title":"Heroicons.inbox/1","doc":"Renders the `inbox` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#inbox/1"},{"type":"function","title":"Examples - Heroicons.inbox/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#inbox/1-examples"},{"type":"function","title":"Attributes - Heroicons.inbox/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#inbox/1-attributes"},{"type":"function","title":"Heroicons.inbox_arrow_down/1","doc":"Renders the `inbox_arrow_down` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#inbox_arrow_down/1"},{"type":"function","title":"Examples - Heroicons.inbox_arrow_down/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#inbox_arrow_down/1-examples"},{"type":"function","title":"Attributes - Heroicons.inbox_arrow_down/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#inbox_arrow_down/1-attributes"},{"type":"function","title":"Heroicons.inbox_stack/1","doc":"Renders the `inbox_stack` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#inbox_stack/1"},{"type":"function","title":"Examples - Heroicons.inbox_stack/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#inbox_stack/1-examples"},{"type":"function","title":"Attributes - Heroicons.inbox_stack/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#inbox_stack/1-attributes"},{"type":"function","title":"Heroicons.information_circle/1","doc":"Renders the `information_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#information_circle/1"},{"type":"function","title":"Examples - Heroicons.information_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#information_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.information_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#information_circle/1-attributes"},{"type":"function","title":"Heroicons.italic/1","doc":"Renders the `italic` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#italic/1"},{"type":"function","title":"Examples - Heroicons.italic/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#italic/1-examples"},{"type":"function","title":"Attributes - Heroicons.italic/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#italic/1-attributes"},{"type":"function","title":"Heroicons.key/1","doc":"Renders the `key` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#key/1"},{"type":"function","title":"Examples - Heroicons.key/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#key/1-examples"},{"type":"function","title":"Attributes - Heroicons.key/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#key/1-attributes"},{"type":"function","title":"Heroicons.language/1","doc":"Renders the `language` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#language/1"},{"type":"function","title":"Examples - Heroicons.language/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#language/1-examples"},{"type":"function","title":"Attributes - Heroicons.language/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#language/1-attributes"},{"type":"function","title":"Heroicons.lifebuoy/1","doc":"Renders the `lifebuoy` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#lifebuoy/1"},{"type":"function","title":"Examples - Heroicons.lifebuoy/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#lifebuoy/1-examples"},{"type":"function","title":"Attributes - Heroicons.lifebuoy/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#lifebuoy/1-attributes"},{"type":"function","title":"Heroicons.light_bulb/1","doc":"Renders the `light_bulb` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#light_bulb/1"},{"type":"function","title":"Examples - Heroicons.light_bulb/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#light_bulb/1-examples"},{"type":"function","title":"Attributes - Heroicons.light_bulb/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#light_bulb/1-attributes"},{"type":"function","title":"Heroicons.link/1","doc":"Renders the `link` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#link/1"},{"type":"function","title":"Examples - Heroicons.link/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#link/1-examples"},{"type":"function","title":"Attributes - Heroicons.link/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#link/1-attributes"},{"type":"function","title":"Heroicons.link_slash/1","doc":"Renders the `link_slash` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#link_slash/1"},{"type":"function","title":"Examples - Heroicons.link_slash/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#link_slash/1-examples"},{"type":"function","title":"Attributes - Heroicons.link_slash/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#link_slash/1-attributes"},{"type":"function","title":"Heroicons.list_bullet/1","doc":"Renders the `list_bullet` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#list_bullet/1"},{"type":"function","title":"Examples - Heroicons.list_bullet/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#list_bullet/1-examples"},{"type":"function","title":"Attributes - Heroicons.list_bullet/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#list_bullet/1-attributes"},{"type":"function","title":"Heroicons.lock_closed/1","doc":"Renders the `lock_closed` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#lock_closed/1"},{"type":"function","title":"Examples - Heroicons.lock_closed/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#lock_closed/1-examples"},{"type":"function","title":"Attributes - Heroicons.lock_closed/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#lock_closed/1-attributes"},{"type":"function","title":"Heroicons.lock_open/1","doc":"Renders the `lock_open` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#lock_open/1"},{"type":"function","title":"Examples - Heroicons.lock_open/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#lock_open/1-examples"},{"type":"function","title":"Attributes - Heroicons.lock_open/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#lock_open/1-attributes"},{"type":"function","title":"Heroicons.magnifying_glass/1","doc":"Renders the `magnifying_glass` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#magnifying_glass/1"},{"type":"function","title":"Examples - Heroicons.magnifying_glass/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#magnifying_glass/1-examples"},{"type":"function","title":"Attributes - Heroicons.magnifying_glass/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#magnifying_glass/1-attributes"},{"type":"function","title":"Heroicons.magnifying_glass_circle/1","doc":"Renders the `magnifying_glass_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#magnifying_glass_circle/1"},{"type":"function","title":"Examples - Heroicons.magnifying_glass_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#magnifying_glass_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.magnifying_glass_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#magnifying_glass_circle/1-attributes"},{"type":"function","title":"Heroicons.magnifying_glass_minus/1","doc":"Renders the `magnifying_glass_minus` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#magnifying_glass_minus/1"},{"type":"function","title":"Examples - Heroicons.magnifying_glass_minus/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#magnifying_glass_minus/1-examples"},{"type":"function","title":"Attributes - Heroicons.magnifying_glass_minus/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#magnifying_glass_minus/1-attributes"},{"type":"function","title":"Heroicons.magnifying_glass_plus/1","doc":"Renders the `magnifying_glass_plus` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#magnifying_glass_plus/1"},{"type":"function","title":"Examples - Heroicons.magnifying_glass_plus/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#magnifying_glass_plus/1-examples"},{"type":"function","title":"Attributes - Heroicons.magnifying_glass_plus/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#magnifying_glass_plus/1-attributes"},{"type":"function","title":"Heroicons.map/1","doc":"Renders the `map` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#map/1"},{"type":"function","title":"Examples - Heroicons.map/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#map/1-examples"},{"type":"function","title":"Attributes - Heroicons.map/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#map/1-attributes"},{"type":"function","title":"Heroicons.map_pin/1","doc":"Renders the `map_pin` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#map_pin/1"},{"type":"function","title":"Examples - Heroicons.map_pin/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#map_pin/1-examples"},{"type":"function","title":"Attributes - Heroicons.map_pin/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#map_pin/1-attributes"},{"type":"function","title":"Heroicons.megaphone/1","doc":"Renders the `megaphone` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#megaphone/1"},{"type":"function","title":"Examples - Heroicons.megaphone/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#megaphone/1-examples"},{"type":"function","title":"Attributes - Heroicons.megaphone/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#megaphone/1-attributes"},{"type":"function","title":"Heroicons.microphone/1","doc":"Renders the `microphone` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#microphone/1"},{"type":"function","title":"Examples - Heroicons.microphone/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#microphone/1-examples"},{"type":"function","title":"Attributes - Heroicons.microphone/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#microphone/1-attributes"},{"type":"function","title":"Heroicons.minus/1","doc":"Renders the `minus` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#minus/1"},{"type":"function","title":"Examples - Heroicons.minus/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#minus/1-examples"},{"type":"function","title":"Attributes - Heroicons.minus/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#minus/1-attributes"},{"type":"function","title":"Heroicons.minus_circle/1","doc":"Renders the `minus_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#minus_circle/1"},{"type":"function","title":"Examples - Heroicons.minus_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#minus_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.minus_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#minus_circle/1-attributes"},{"type":"function","title":"Heroicons.minus_small/1","doc":"Renders the `minus_small` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid` or `mini`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#minus_small/1"},{"type":"function","title":"Examples - Heroicons.minus_small/1","doc":"```heex\n \n \n \n \n \n```","ref":"Heroicons.html#minus_small/1-examples"},{"type":"function","title":"Attributes - Heroicons.minus_small/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#minus_small/1-attributes"},{"type":"function","title":"Heroicons.moon/1","doc":"Renders the `moon` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#moon/1"},{"type":"function","title":"Examples - Heroicons.moon/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#moon/1-examples"},{"type":"function","title":"Attributes - Heroicons.moon/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#moon/1-attributes"},{"type":"function","title":"Heroicons.musical_note/1","doc":"Renders the `musical_note` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#musical_note/1"},{"type":"function","title":"Examples - Heroicons.musical_note/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#musical_note/1-examples"},{"type":"function","title":"Attributes - Heroicons.musical_note/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#musical_note/1-attributes"},{"type":"function","title":"Heroicons.newspaper/1","doc":"Renders the `newspaper` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#newspaper/1"},{"type":"function","title":"Examples - Heroicons.newspaper/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#newspaper/1-examples"},{"type":"function","title":"Attributes - Heroicons.newspaper/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#newspaper/1-attributes"},{"type":"function","title":"Heroicons.no_symbol/1","doc":"Renders the `no_symbol` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#no_symbol/1"},{"type":"function","title":"Examples - Heroicons.no_symbol/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#no_symbol/1-examples"},{"type":"function","title":"Attributes - Heroicons.no_symbol/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#no_symbol/1-attributes"},{"type":"function","title":"Heroicons.numbered_list/1","doc":"Renders the `numbered_list` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#numbered_list/1"},{"type":"function","title":"Examples - Heroicons.numbered_list/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#numbered_list/1-examples"},{"type":"function","title":"Attributes - Heroicons.numbered_list/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#numbered_list/1-attributes"},{"type":"function","title":"Heroicons.paint_brush/1","doc":"Renders the `paint_brush` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#paint_brush/1"},{"type":"function","title":"Examples - Heroicons.paint_brush/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#paint_brush/1-examples"},{"type":"function","title":"Attributes - Heroicons.paint_brush/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#paint_brush/1-attributes"},{"type":"function","title":"Heroicons.paper_airplane/1","doc":"Renders the `paper_airplane` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#paper_airplane/1"},{"type":"function","title":"Examples - Heroicons.paper_airplane/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#paper_airplane/1-examples"},{"type":"function","title":"Attributes - Heroicons.paper_airplane/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#paper_airplane/1-attributes"},{"type":"function","title":"Heroicons.paper_clip/1","doc":"Renders the `paper_clip` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#paper_clip/1"},{"type":"function","title":"Examples - Heroicons.paper_clip/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#paper_clip/1-examples"},{"type":"function","title":"Attributes - Heroicons.paper_clip/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#paper_clip/1-attributes"},{"type":"function","title":"Heroicons.pause/1","doc":"Renders the `pause` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#pause/1"},{"type":"function","title":"Examples - Heroicons.pause/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#pause/1-examples"},{"type":"function","title":"Attributes - Heroicons.pause/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#pause/1-attributes"},{"type":"function","title":"Heroicons.pause_circle/1","doc":"Renders the `pause_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#pause_circle/1"},{"type":"function","title":"Examples - Heroicons.pause_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#pause_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.pause_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#pause_circle/1-attributes"},{"type":"function","title":"Heroicons.pencil/1","doc":"Renders the `pencil` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#pencil/1"},{"type":"function","title":"Examples - Heroicons.pencil/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#pencil/1-examples"},{"type":"function","title":"Attributes - Heroicons.pencil/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#pencil/1-attributes"},{"type":"function","title":"Heroicons.pencil_square/1","doc":"Renders the `pencil_square` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#pencil_square/1"},{"type":"function","title":"Examples - Heroicons.pencil_square/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#pencil_square/1-examples"},{"type":"function","title":"Attributes - Heroicons.pencil_square/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#pencil_square/1-attributes"},{"type":"function","title":"Heroicons.percent_badge/1","doc":"Renders the `percent_badge` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#percent_badge/1"},{"type":"function","title":"Examples - Heroicons.percent_badge/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#percent_badge/1-examples"},{"type":"function","title":"Attributes - Heroicons.percent_badge/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#percent_badge/1-attributes"},{"type":"function","title":"Heroicons.phone/1","doc":"Renders the `phone` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#phone/1"},{"type":"function","title":"Examples - Heroicons.phone/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#phone/1-examples"},{"type":"function","title":"Attributes - Heroicons.phone/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#phone/1-attributes"},{"type":"function","title":"Heroicons.phone_arrow_down_left/1","doc":"Renders the `phone_arrow_down_left` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#phone_arrow_down_left/1"},{"type":"function","title":"Examples - Heroicons.phone_arrow_down_left/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#phone_arrow_down_left/1-examples"},{"type":"function","title":"Attributes - Heroicons.phone_arrow_down_left/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#phone_arrow_down_left/1-attributes"},{"type":"function","title":"Heroicons.phone_arrow_up_right/1","doc":"Renders the `phone_arrow_up_right` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#phone_arrow_up_right/1"},{"type":"function","title":"Examples - Heroicons.phone_arrow_up_right/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#phone_arrow_up_right/1-examples"},{"type":"function","title":"Attributes - Heroicons.phone_arrow_up_right/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#phone_arrow_up_right/1-attributes"},{"type":"function","title":"Heroicons.phone_x_mark/1","doc":"Renders the `phone_x_mark` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#phone_x_mark/1"},{"type":"function","title":"Examples - Heroicons.phone_x_mark/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#phone_x_mark/1-examples"},{"type":"function","title":"Attributes - Heroicons.phone_x_mark/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#phone_x_mark/1-attributes"},{"type":"function","title":"Heroicons.photo/1","doc":"Renders the `photo` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#photo/1"},{"type":"function","title":"Examples - Heroicons.photo/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#photo/1-examples"},{"type":"function","title":"Attributes - Heroicons.photo/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#photo/1-attributes"},{"type":"function","title":"Heroicons.play/1","doc":"Renders the `play` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#play/1"},{"type":"function","title":"Examples - Heroicons.play/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#play/1-examples"},{"type":"function","title":"Attributes - Heroicons.play/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#play/1-attributes"},{"type":"function","title":"Heroicons.play_circle/1","doc":"Renders the `play_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#play_circle/1"},{"type":"function","title":"Examples - Heroicons.play_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#play_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.play_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#play_circle/1-attributes"},{"type":"function","title":"Heroicons.play_pause/1","doc":"Renders the `play_pause` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#play_pause/1"},{"type":"function","title":"Examples - Heroicons.play_pause/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#play_pause/1-examples"},{"type":"function","title":"Attributes - Heroicons.play_pause/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#play_pause/1-attributes"},{"type":"function","title":"Heroicons.plus/1","doc":"Renders the `plus` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#plus/1"},{"type":"function","title":"Examples - Heroicons.plus/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#plus/1-examples"},{"type":"function","title":"Attributes - Heroicons.plus/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#plus/1-attributes"},{"type":"function","title":"Heroicons.plus_circle/1","doc":"Renders the `plus_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#plus_circle/1"},{"type":"function","title":"Examples - Heroicons.plus_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#plus_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.plus_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#plus_circle/1-attributes"},{"type":"function","title":"Heroicons.plus_small/1","doc":"Renders the `plus_small` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid` or `mini`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#plus_small/1"},{"type":"function","title":"Examples - Heroicons.plus_small/1","doc":"```heex\n \n \n \n \n \n```","ref":"Heroicons.html#plus_small/1-examples"},{"type":"function","title":"Attributes - Heroicons.plus_small/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#plus_small/1-attributes"},{"type":"function","title":"Heroicons.power/1","doc":"Renders the `power` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#power/1"},{"type":"function","title":"Examples - Heroicons.power/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#power/1-examples"},{"type":"function","title":"Attributes - Heroicons.power/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#power/1-attributes"},{"type":"function","title":"Heroicons.presentation_chart_bar/1","doc":"Renders the `presentation_chart_bar` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#presentation_chart_bar/1"},{"type":"function","title":"Examples - Heroicons.presentation_chart_bar/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#presentation_chart_bar/1-examples"},{"type":"function","title":"Attributes - Heroicons.presentation_chart_bar/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#presentation_chart_bar/1-attributes"},{"type":"function","title":"Heroicons.presentation_chart_line/1","doc":"Renders the `presentation_chart_line` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#presentation_chart_line/1"},{"type":"function","title":"Examples - Heroicons.presentation_chart_line/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#presentation_chart_line/1-examples"},{"type":"function","title":"Attributes - Heroicons.presentation_chart_line/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#presentation_chart_line/1-attributes"},{"type":"function","title":"Heroicons.printer/1","doc":"Renders the `printer` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#printer/1"},{"type":"function","title":"Examples - Heroicons.printer/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#printer/1-examples"},{"type":"function","title":"Attributes - Heroicons.printer/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#printer/1-attributes"},{"type":"function","title":"Heroicons.puzzle_piece/1","doc":"Renders the `puzzle_piece` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#puzzle_piece/1"},{"type":"function","title":"Examples - Heroicons.puzzle_piece/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#puzzle_piece/1-examples"},{"type":"function","title":"Attributes - Heroicons.puzzle_piece/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#puzzle_piece/1-attributes"},{"type":"function","title":"Heroicons.qr_code/1","doc":"Renders the `qr_code` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#qr_code/1"},{"type":"function","title":"Examples - Heroicons.qr_code/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#qr_code/1-examples"},{"type":"function","title":"Attributes - Heroicons.qr_code/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#qr_code/1-attributes"},{"type":"function","title":"Heroicons.question_mark_circle/1","doc":"Renders the `question_mark_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#question_mark_circle/1"},{"type":"function","title":"Examples - Heroicons.question_mark_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#question_mark_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.question_mark_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#question_mark_circle/1-attributes"},{"type":"function","title":"Heroicons.queue_list/1","doc":"Renders the `queue_list` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#queue_list/1"},{"type":"function","title":"Examples - Heroicons.queue_list/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#queue_list/1-examples"},{"type":"function","title":"Attributes - Heroicons.queue_list/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#queue_list/1-attributes"},{"type":"function","title":"Heroicons.radio/1","doc":"Renders the `radio` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#radio/1"},{"type":"function","title":"Examples - Heroicons.radio/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#radio/1-examples"},{"type":"function","title":"Attributes - Heroicons.radio/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#radio/1-attributes"},{"type":"function","title":"Heroicons.receipt_percent/1","doc":"Renders the `receipt_percent` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#receipt_percent/1"},{"type":"function","title":"Examples - Heroicons.receipt_percent/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#receipt_percent/1-examples"},{"type":"function","title":"Attributes - Heroicons.receipt_percent/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#receipt_percent/1-attributes"},{"type":"function","title":"Heroicons.receipt_refund/1","doc":"Renders the `receipt_refund` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#receipt_refund/1"},{"type":"function","title":"Examples - Heroicons.receipt_refund/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#receipt_refund/1-examples"},{"type":"function","title":"Attributes - Heroicons.receipt_refund/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#receipt_refund/1-attributes"},{"type":"function","title":"Heroicons.rectangle_group/1","doc":"Renders the `rectangle_group` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#rectangle_group/1"},{"type":"function","title":"Examples - Heroicons.rectangle_group/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#rectangle_group/1-examples"},{"type":"function","title":"Attributes - Heroicons.rectangle_group/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#rectangle_group/1-attributes"},{"type":"function","title":"Heroicons.rectangle_stack/1","doc":"Renders the `rectangle_stack` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#rectangle_stack/1"},{"type":"function","title":"Examples - Heroicons.rectangle_stack/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#rectangle_stack/1-examples"},{"type":"function","title":"Attributes - Heroicons.rectangle_stack/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#rectangle_stack/1-attributes"},{"type":"function","title":"Heroicons.rocket_launch/1","doc":"Renders the `rocket_launch` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#rocket_launch/1"},{"type":"function","title":"Examples - Heroicons.rocket_launch/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#rocket_launch/1-examples"},{"type":"function","title":"Attributes - Heroicons.rocket_launch/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#rocket_launch/1-attributes"},{"type":"function","title":"Heroicons.rss/1","doc":"Renders the `rss` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#rss/1"},{"type":"function","title":"Examples - Heroicons.rss/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#rss/1-examples"},{"type":"function","title":"Attributes - Heroicons.rss/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#rss/1-attributes"},{"type":"function","title":"Heroicons.scale/1","doc":"Renders the `scale` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#scale/1"},{"type":"function","title":"Examples - Heroicons.scale/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#scale/1-examples"},{"type":"function","title":"Attributes - Heroicons.scale/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#scale/1-attributes"},{"type":"function","title":"Heroicons.scissors/1","doc":"Renders the `scissors` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#scissors/1"},{"type":"function","title":"Examples - Heroicons.scissors/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#scissors/1-examples"},{"type":"function","title":"Attributes - Heroicons.scissors/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#scissors/1-attributes"},{"type":"function","title":"Heroicons.server/1","doc":"Renders the `server` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#server/1"},{"type":"function","title":"Examples - Heroicons.server/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#server/1-examples"},{"type":"function","title":"Attributes - Heroicons.server/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#server/1-attributes"},{"type":"function","title":"Heroicons.server_stack/1","doc":"Renders the `server_stack` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#server_stack/1"},{"type":"function","title":"Examples - Heroicons.server_stack/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#server_stack/1-examples"},{"type":"function","title":"Attributes - Heroicons.server_stack/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#server_stack/1-attributes"},{"type":"function","title":"Heroicons.share/1","doc":"Renders the `share` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#share/1"},{"type":"function","title":"Examples - Heroicons.share/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#share/1-examples"},{"type":"function","title":"Attributes - Heroicons.share/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#share/1-attributes"},{"type":"function","title":"Heroicons.shield_check/1","doc":"Renders the `shield_check` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#shield_check/1"},{"type":"function","title":"Examples - Heroicons.shield_check/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#shield_check/1-examples"},{"type":"function","title":"Attributes - Heroicons.shield_check/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#shield_check/1-attributes"},{"type":"function","title":"Heroicons.shield_exclamation/1","doc":"Renders the `shield_exclamation` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#shield_exclamation/1"},{"type":"function","title":"Examples - Heroicons.shield_exclamation/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#shield_exclamation/1-examples"},{"type":"function","title":"Attributes - Heroicons.shield_exclamation/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#shield_exclamation/1-attributes"},{"type":"function","title":"Heroicons.shopping_bag/1","doc":"Renders the `shopping_bag` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#shopping_bag/1"},{"type":"function","title":"Examples - Heroicons.shopping_bag/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#shopping_bag/1-examples"},{"type":"function","title":"Attributes - Heroicons.shopping_bag/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#shopping_bag/1-attributes"},{"type":"function","title":"Heroicons.shopping_cart/1","doc":"Renders the `shopping_cart` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#shopping_cart/1"},{"type":"function","title":"Examples - Heroicons.shopping_cart/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#shopping_cart/1-examples"},{"type":"function","title":"Attributes - Heroicons.shopping_cart/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#shopping_cart/1-attributes"},{"type":"function","title":"Heroicons.signal/1","doc":"Renders the `signal` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#signal/1"},{"type":"function","title":"Examples - Heroicons.signal/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#signal/1-examples"},{"type":"function","title":"Attributes - Heroicons.signal/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#signal/1-attributes"},{"type":"function","title":"Heroicons.signal_slash/1","doc":"Renders the `signal_slash` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#signal_slash/1"},{"type":"function","title":"Examples - Heroicons.signal_slash/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#signal_slash/1-examples"},{"type":"function","title":"Attributes - Heroicons.signal_slash/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#signal_slash/1-attributes"},{"type":"function","title":"Heroicons.slash/1","doc":"Renders the `slash` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#slash/1"},{"type":"function","title":"Examples - Heroicons.slash/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#slash/1-examples"},{"type":"function","title":"Attributes - Heroicons.slash/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#slash/1-attributes"},{"type":"function","title":"Heroicons.sparkles/1","doc":"Renders the `sparkles` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#sparkles/1"},{"type":"function","title":"Examples - Heroicons.sparkles/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#sparkles/1-examples"},{"type":"function","title":"Attributes - Heroicons.sparkles/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#sparkles/1-attributes"},{"type":"function","title":"Heroicons.speaker_wave/1","doc":"Renders the `speaker_wave` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#speaker_wave/1"},{"type":"function","title":"Examples - Heroicons.speaker_wave/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#speaker_wave/1-examples"},{"type":"function","title":"Attributes - Heroicons.speaker_wave/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#speaker_wave/1-attributes"},{"type":"function","title":"Heroicons.speaker_x_mark/1","doc":"Renders the `speaker_x_mark` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#speaker_x_mark/1"},{"type":"function","title":"Examples - Heroicons.speaker_x_mark/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#speaker_x_mark/1-examples"},{"type":"function","title":"Attributes - Heroicons.speaker_x_mark/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#speaker_x_mark/1-attributes"},{"type":"function","title":"Heroicons.square_2_stack/1","doc":"Renders the `square_2_stack` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#square_2_stack/1"},{"type":"function","title":"Examples - Heroicons.square_2_stack/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#square_2_stack/1-examples"},{"type":"function","title":"Attributes - Heroicons.square_2_stack/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#square_2_stack/1-attributes"},{"type":"function","title":"Heroicons.square_3_stack_3d/1","doc":"Renders the `square_3_stack_3d` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#square_3_stack_3d/1"},{"type":"function","title":"Examples - Heroicons.square_3_stack_3d/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#square_3_stack_3d/1-examples"},{"type":"function","title":"Attributes - Heroicons.square_3_stack_3d/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#square_3_stack_3d/1-attributes"},{"type":"function","title":"Heroicons.squares_2x2/1","doc":"Renders the `squares_2x2` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#squares_2x2/1"},{"type":"function","title":"Examples - Heroicons.squares_2x2/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#squares_2x2/1-examples"},{"type":"function","title":"Attributes - Heroicons.squares_2x2/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#squares_2x2/1-attributes"},{"type":"function","title":"Heroicons.squares_plus/1","doc":"Renders the `squares_plus` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#squares_plus/1"},{"type":"function","title":"Examples - Heroicons.squares_plus/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#squares_plus/1-examples"},{"type":"function","title":"Attributes - Heroicons.squares_plus/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#squares_plus/1-attributes"},{"type":"function","title":"Heroicons.star/1","doc":"Renders the `star` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#star/1"},{"type":"function","title":"Examples - Heroicons.star/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#star/1-examples"},{"type":"function","title":"Attributes - Heroicons.star/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#star/1-attributes"},{"type":"function","title":"Heroicons.stop/1","doc":"Renders the `stop` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#stop/1"},{"type":"function","title":"Examples - Heroicons.stop/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#stop/1-examples"},{"type":"function","title":"Attributes - Heroicons.stop/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#stop/1-attributes"},{"type":"function","title":"Heroicons.stop_circle/1","doc":"Renders the `stop_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#stop_circle/1"},{"type":"function","title":"Examples - Heroicons.stop_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#stop_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.stop_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#stop_circle/1-attributes"},{"type":"function","title":"Heroicons.strikethrough/1","doc":"Renders the `strikethrough` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#strikethrough/1"},{"type":"function","title":"Examples - Heroicons.strikethrough/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#strikethrough/1-examples"},{"type":"function","title":"Attributes - Heroicons.strikethrough/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#strikethrough/1-attributes"},{"type":"function","title":"Heroicons.sun/1","doc":"Renders the `sun` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#sun/1"},{"type":"function","title":"Examples - Heroicons.sun/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#sun/1-examples"},{"type":"function","title":"Attributes - Heroicons.sun/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#sun/1-attributes"},{"type":"function","title":"Heroicons.swatch/1","doc":"Renders the `swatch` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#swatch/1"},{"type":"function","title":"Examples - Heroicons.swatch/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#swatch/1-examples"},{"type":"function","title":"Attributes - Heroicons.swatch/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#swatch/1-attributes"},{"type":"function","title":"Heroicons.table_cells/1","doc":"Renders the `table_cells` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#table_cells/1"},{"type":"function","title":"Examples - Heroicons.table_cells/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#table_cells/1-examples"},{"type":"function","title":"Attributes - Heroicons.table_cells/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#table_cells/1-attributes"},{"type":"function","title":"Heroicons.tag/1","doc":"Renders the `tag` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#tag/1"},{"type":"function","title":"Examples - Heroicons.tag/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#tag/1-examples"},{"type":"function","title":"Attributes - Heroicons.tag/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#tag/1-attributes"},{"type":"function","title":"Heroicons.ticket/1","doc":"Renders the `ticket` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#ticket/1"},{"type":"function","title":"Examples - Heroicons.ticket/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#ticket/1-examples"},{"type":"function","title":"Attributes - Heroicons.ticket/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#ticket/1-attributes"},{"type":"function","title":"Heroicons.trash/1","doc":"Renders the `trash` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#trash/1"},{"type":"function","title":"Examples - Heroicons.trash/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#trash/1-examples"},{"type":"function","title":"Attributes - Heroicons.trash/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#trash/1-attributes"},{"type":"function","title":"Heroicons.trophy/1","doc":"Renders the `trophy` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#trophy/1"},{"type":"function","title":"Examples - Heroicons.trophy/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#trophy/1-examples"},{"type":"function","title":"Attributes - Heroicons.trophy/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#trophy/1-attributes"},{"type":"function","title":"Heroicons.truck/1","doc":"Renders the `truck` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#truck/1"},{"type":"function","title":"Examples - Heroicons.truck/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#truck/1-examples"},{"type":"function","title":"Attributes - Heroicons.truck/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#truck/1-attributes"},{"type":"function","title":"Heroicons.tv/1","doc":"Renders the `tv` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#tv/1"},{"type":"function","title":"Examples - Heroicons.tv/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#tv/1-examples"},{"type":"function","title":"Attributes - Heroicons.tv/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#tv/1-attributes"},{"type":"function","title":"Heroicons.underline/1","doc":"Renders the `underline` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#underline/1"},{"type":"function","title":"Examples - Heroicons.underline/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#underline/1-examples"},{"type":"function","title":"Attributes - Heroicons.underline/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#underline/1-attributes"},{"type":"function","title":"Heroicons.user/1","doc":"Renders the `user` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#user/1"},{"type":"function","title":"Examples - Heroicons.user/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#user/1-examples"},{"type":"function","title":"Attributes - Heroicons.user/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#user/1-attributes"},{"type":"function","title":"Heroicons.user_circle/1","doc":"Renders the `user_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#user_circle/1"},{"type":"function","title":"Examples - Heroicons.user_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#user_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.user_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#user_circle/1-attributes"},{"type":"function","title":"Heroicons.user_group/1","doc":"Renders the `user_group` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#user_group/1"},{"type":"function","title":"Examples - Heroicons.user_group/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#user_group/1-examples"},{"type":"function","title":"Attributes - Heroicons.user_group/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#user_group/1-attributes"},{"type":"function","title":"Heroicons.user_minus/1","doc":"Renders the `user_minus` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#user_minus/1"},{"type":"function","title":"Examples - Heroicons.user_minus/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#user_minus/1-examples"},{"type":"function","title":"Attributes - Heroicons.user_minus/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#user_minus/1-attributes"},{"type":"function","title":"Heroicons.user_plus/1","doc":"Renders the `user_plus` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#user_plus/1"},{"type":"function","title":"Examples - Heroicons.user_plus/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#user_plus/1-examples"},{"type":"function","title":"Attributes - Heroicons.user_plus/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#user_plus/1-attributes"},{"type":"function","title":"Heroicons.users/1","doc":"Renders the `users` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#users/1"},{"type":"function","title":"Examples - Heroicons.users/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#users/1-examples"},{"type":"function","title":"Attributes - Heroicons.users/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#users/1-attributes"},{"type":"function","title":"Heroicons.variable/1","doc":"Renders the `variable` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#variable/1"},{"type":"function","title":"Examples - Heroicons.variable/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#variable/1-examples"},{"type":"function","title":"Attributes - Heroicons.variable/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#variable/1-attributes"},{"type":"function","title":"Heroicons.video_camera/1","doc":"Renders the `video_camera` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#video_camera/1"},{"type":"function","title":"Examples - Heroicons.video_camera/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#video_camera/1-examples"},{"type":"function","title":"Attributes - Heroicons.video_camera/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#video_camera/1-attributes"},{"type":"function","title":"Heroicons.video_camera_slash/1","doc":"Renders the `video_camera_slash` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#video_camera_slash/1"},{"type":"function","title":"Examples - Heroicons.video_camera_slash/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#video_camera_slash/1-examples"},{"type":"function","title":"Attributes - Heroicons.video_camera_slash/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#video_camera_slash/1-attributes"},{"type":"function","title":"Heroicons.view_columns/1","doc":"Renders the `view_columns` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#view_columns/1"},{"type":"function","title":"Examples - Heroicons.view_columns/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#view_columns/1-examples"},{"type":"function","title":"Attributes - Heroicons.view_columns/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#view_columns/1-attributes"},{"type":"function","title":"Heroicons.viewfinder_circle/1","doc":"Renders the `viewfinder_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#viewfinder_circle/1"},{"type":"function","title":"Examples - Heroicons.viewfinder_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#viewfinder_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.viewfinder_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#viewfinder_circle/1-attributes"},{"type":"function","title":"Heroicons.wallet/1","doc":"Renders the `wallet` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#wallet/1"},{"type":"function","title":"Examples - Heroicons.wallet/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#wallet/1-examples"},{"type":"function","title":"Attributes - Heroicons.wallet/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#wallet/1-attributes"},{"type":"function","title":"Heroicons.wifi/1","doc":"Renders the `wifi` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#wifi/1"},{"type":"function","title":"Examples - Heroicons.wifi/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#wifi/1-examples"},{"type":"function","title":"Attributes - Heroicons.wifi/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#wifi/1-attributes"},{"type":"function","title":"Heroicons.window/1","doc":"Renders the `window` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#window/1"},{"type":"function","title":"Examples - Heroicons.window/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#window/1-examples"},{"type":"function","title":"Attributes - Heroicons.window/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#window/1-attributes"},{"type":"function","title":"Heroicons.wrench/1","doc":"Renders the `wrench` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#wrench/1"},{"type":"function","title":"Examples - Heroicons.wrench/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#wrench/1-examples"},{"type":"function","title":"Attributes - Heroicons.wrench/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#wrench/1-attributes"},{"type":"function","title":"Heroicons.wrench_screwdriver/1","doc":"Renders the `wrench_screwdriver` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#wrench_screwdriver/1"},{"type":"function","title":"Examples - Heroicons.wrench_screwdriver/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#wrench_screwdriver/1-examples"},{"type":"function","title":"Attributes - Heroicons.wrench_screwdriver/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#wrench_screwdriver/1-attributes"},{"type":"function","title":"Heroicons.x_circle/1","doc":"Renders the `x_circle` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#x_circle/1"},{"type":"function","title":"Examples - Heroicons.x_circle/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#x_circle/1-examples"},{"type":"function","title":"Attributes - Heroicons.x_circle/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#x_circle/1-attributes"},{"type":"function","title":"Heroicons.x_mark/1","doc":"Renders the `x_mark` icon.\n\nBy default, the outlined (24x24) component is used, but the `solid`, `mini` or `micro`\nattributes can be provided for alternative styles.\n\nYou may also pass arbitrary HTML attributes to be applied to the svg tag.","ref":"Heroicons.html#x_mark/1"},{"type":"function","title":"Examples - Heroicons.x_mark/1","doc":"```heex\n \n \n \n \n \n \n```","ref":"Heroicons.html#x_mark/1-examples"},{"type":"function","title":"Attributes - Heroicons.x_mark/1","doc":"* `outline` (`:boolean`) - Defaults to `true`.\n* `solid` (`:boolean`) - Defaults to `false`.\n* `mini` (`:boolean`) - Defaults to `false`.\n* `micro` (`:boolean`) - Defaults to `false`.\n* Global attributes are accepted. the arbitrary HTML attributes for the svg container. Supports all globals plus: `[\"fill\", \"stroke\", \"stroke-width\"]`.","ref":"Heroicons.html#x_mark/1-attributes"},{"type":"task","title":"mix beacon.install","doc":"Generates beacon necessary configurations.\n\nBefore running this command, make sure you commited all your changes to git,\nbeacuse it generates new files and modifies existing ones.\n\n    $ mix beacon.install --site blog --path /blog\n\nThe argument `site` defines the name of your beacon site and is\nused to generate the necessary configuration files.","ref":"Mix.Tasks.Beacon.Install.html"},{"type":"task","title":"Arguments - mix beacon.install","doc":"* `--site` (required) - The name of your beacon site\n  * `--path` (optional) - Route prefix to mount your site","ref":"Mix.Tasks.Beacon.Install.html#module-arguments"},{"type":"module","title":"Beacon.Migration","doc":"Functions which can be called in an Ecto migration for Beacon installation and upgrades.","ref":"Beacon.Migration.html"},{"type":"module","title":"Usage - Beacon.Migration","doc":"To install Beacon, you'll need to generate an `Ecto.Migration` that wraps calls to `Beacon.Migration`:\n\n```\n$ mix ecto.gen.migration create_beacon_tables\n```\n\nOpen the generated migration in your editor and either call or delegate to `up/1` and `down/1`:\n\n```elixir\ndefmodule MyApp.Repo.Migrations.CreateBeaconTables do\n  use Ecto.Migration\n  def up, do: Beacon.Migration.up()\n  def down, do: Beacon.Migration.down()\nend\n```\n\nThen, run the migrations for your app to create the necessary Beacon tables in your database:\n\n```\n$ mix ecto.migrate\n```\n\nBy calling `up()` with no arguments, this will execute all migration steps from the initial version to\nthe latest version.  As new versions are released, you may need to repeat this process, by first\ngenerating a new migration:\n\n```\n$ mix ecto.gen.migration upgrade_beacon_tables_to_v2\n```\n\nThen in the generated migration, you could simply call `up()` again, because the migrations are\nidempotent, but you can be safer and more efficient by specifying the migration version to execute:\n\n```elixir\n defmodule MyApp.Repo.Migrations.UpgradeBeaconTables do\n  use Ecto.Migration\n  def up, do: Beacon.Migration.up(version: 2)\n  def down, do: Beacon.Migration.down(version: 2)\nend\n```\n\nNow this migration will update to v2, but if rolled back, will only roll back the v2 changes,\nleaving v1 tables in-place.\n\nTo see this step within the larger context of installing Beacon, check out the [your first site](your-first-site.html) guide.","ref":"Beacon.Migration.html#module-usage"},{"type":"function","title":"Beacon.Migration.down/1","doc":"Downgrades Beacon database schemas.\n\nIf a specific version number is provided, Beacon will only downgrade to that version (inclusive).\nOtherwise, it will completely uninstall Beacon from your app's database.","ref":"Beacon.Migration.html#down/1"},{"type":"function","title":"Example - Beacon.Migration.down/1","doc":"Run all migrations from current version down to the first:\n\n    Beacon.Migration.down()\n\nRun migrations down to and including a specified version:\n\n    Beacon.Migration.down(version: 2)","ref":"Beacon.Migration.html#down/1-example"},{"type":"function","title":"Beacon.Migration.up/1","doc":"Upgrades Beacon database schemas.\n\nIf a specific version number is provided, Beacon will only upgrade to that version.\nOtherwise, it will bring you fully up-to-date with the current version.","ref":"Beacon.Migration.html#up/1"},{"type":"function","title":"Example - Beacon.Migration.up/1","doc":"Run all migrations up to the current version:\n\n    Beacon.Migration.up()\n\nRun migrations up to a specified version:\n\n    Beacon.Migration.down(version: 2)","ref":"Beacon.Migration.html#up/1-example"},{"type":"module","title":"Beacon.Router","doc":"Controls pages routing and provides helpers to mount sites in your application router and generate links to pages.\n\n    defmodule MyAppWeb.Router do\n      use Phoenix.Router\n      use Beacon.Router\n\n      scope \"/\", MyAppWeb do\n        pipe_through :browser\n        beacon_site \"/blog\", site: :blog\n      end\n    end","ref":"Beacon.Router.html"},{"type":"module","title":"Helpers - Beacon.Router","doc":"A `~p` sigil is provided to generate links to pages taking the `scope` and site `prefix` into account.\n\nUsing that sigil in a template in the `:blog` site defined above would result in the following links:\n\n```\n~p\"/contact\" => \"/blog/contact\"\n~p\"/posts/#{@post}\" => \"/blog/posts/my-post\"\n```\n\nIn this example `post` is a `Beacon.Content.Page` that implements the `Phoenix.Param` protocol to resolve the page path.","ref":"Beacon.Router.html#module-helpers"},{"type":"module","title":"Path - Beacon.Router","doc":"The full path of the site is calculated resolving the `scope` prefix plus the site `prefix`.\n\nThe simplest scenario is mounting a site at the root of your application:\n\n    scope \"/\", MyAppWeb do\n      pipe_through :browser\n      beacon_site \"/\", site: :my_site\n    end\n\nIn this case the site `:my_site` will be available at `https://yourapp.com/`\n\nBy mixing prefixes you have the flexibility to mount sites in different paths,\nfor example both declarations below will mount the site at `https://yourapp.com/blog`:\n\n    scope \"/blog\", MyAppWeb do\n      pipe_through :browser\n      beacon_site \"/\", site: :blog\n    end\n\n    scope \"/\", MyAppWeb do\n      pipe_through :browser\n      beacon_site \"/blog\", site: :blog\n    end\n\nThere's no difference between the two approaches, but that is important to group and organize your routes and sites,\nfor example a scope might be served through a different pipeline:application\n\n    scope \"/marketing\", MyAppWeb do\n      pipe_through :browser_analytics\n      beacon_site \"/super-campaign\", site: :marketing_super_campaign\n      beacon_site \"/\", site: :marketing\n    end\n\nNote in the last example that `/super-campaign` is defined _before_ `/` and there's an important reason for that: router precedence.","ref":"Beacon.Router.html#module-path"},{"type":"module","title":"Route Precedence - Beacon.Router","doc":"Beacon pages are defined dynamically so it doesn't know which pages are availale when the router is compiled,\nwhich means that any route after the `prefix` may match a published page. For example `/contact` may be a valid\npage published under the mounted `beacon_site \"/, site: :marketing` site.\n\nEssentially it mounts a catch-all route like `/*` so if we had inverted the routes below we would end with:application\n\n    /*\n    /super-campaign\n\nThe second route would never match since the first one would match all requests.\n\nAs a rule of thumb, put all specific routes first.","ref":"Beacon.Router.html#module-route-precedence"},{"type":"macro","title":"Beacon.Router.beacon_site/2","doc":"Mounts a site in the `prefix` in your host application router.","ref":"Beacon.Router.html#beacon_site/2"},{"type":"macro","title":"Options - Beacon.Router.beacon_site/2","doc":"* `:site` (required) `t:Beacon.Types.Site.t/0` - register your site with a unique name.\n    Note that the name has to match the one used in your site configuration in `application.ex`.\n    See the module doc and `Beacon.Config` for more info.","ref":"Beacon.Router.html#beacon_site/2-options"},{"type":"module","title":"Beacon.Content","doc":"The building blocks for composing web pages: Layouts, Pages, Components, Stylesheets, and Snippets.","ref":"Beacon.Content.html"},{"type":"module","title":"Templates - Beacon.Content","doc":"Layout and Pages work together as pages require a layout to display its content,\nthe minimal template for a layout that can exist is the following:\n\n```heex\n<%= @inner_content %>\n```\n\nAnd pages templates can be written in [HEEx](https://hexdocs.pm/phoenix_live_view/assigns-eex.html)\nor [Markdown](https://docs.github.com/en/get-started/writing-on-github/getting-started-with-writing-and-formatting-on-github/basic-writing-and-formatting-syntax) formats.","ref":"Beacon.Content.html#module-templates"},{"type":"module","title":"Meta Tags - Beacon.Content","doc":"Meta Tags can are defined in 3 levels:\n\n  * Site - fixed meta tags displayed on all pages, see `default_site_meta_tags/0`\n  * Layouts - applies to all pages used by the template.\n  * Page - only applies to the specific page.","ref":"Beacon.Content.html#module-meta-tags"},{"type":"function","title":"Beacon.Content.change_component/2","doc":"Returns an `%Ecto.Changeset{}` for tracking component changes.","ref":"Beacon.Content.html#change_component/2"},{"type":"function","title":"Example - Beacon.Content.change_component/2","doc":"iex> change_component(component, %{name: \"Header\"})\n    %Ecto.Changeset{data: %Component{}}","ref":"Beacon.Content.html#change_component/2-example"},{"type":"function","title":"Beacon.Content.change_component_attr/3","doc":"Returns an `%Ecto.Changeset{}` for tracking component_attr changes.","ref":"Beacon.Content.html#change_component_attr/3"},{"type":"function","title":"Example - Beacon.Content.change_component_attr/3","doc":"iex> change_component_attr(component_attr, %{name: \"Header\"})\n    %Ecto.Changeset{data: %ComponentAttr{}}\n\n    iex> change_component_attr(component_attr, %{name: \"Header\"}, [\"sites\", [\"pages\"]])\n    %Ecto.Changeset{data: %ComponentAttr{}}","ref":"Beacon.Content.html#change_component_attr/3-example"},{"type":"function","title":"Beacon.Content.change_component_slot/3","doc":"Returns an `%Ecto.Changeset{}` for tracking slot changes.","ref":"Beacon.Content.html#change_component_slot/3"},{"type":"function","title":"Example - Beacon.Content.change_component_slot/3","doc":"iex> change_component_slot(component_slot, %{name: \"slot_a\"}, [\"slot_name_1])\n    %Ecto.Changeset{data: %ComponentSlot{}}","ref":"Beacon.Content.html#change_component_slot/3-example"},{"type":"function","title":"Beacon.Content.change_error_page/2","doc":"Returns an `%Ecto.Changeset{}` for tracking error page changes.","ref":"Beacon.Content.html#change_error_page/2"},{"type":"function","title":"Example - Beacon.Content.change_error_page/2","doc":"iex> change_error_page(error_page, %{status: 404})\n    %Ecto.Changeset{data: %ErrorPage{}}","ref":"Beacon.Content.html#change_error_page/2-example"},{"type":"function","title":"Beacon.Content.change_event_handler/2","doc":"Returns an `%Ecto.Changeset{}` for tracking event handler changes.","ref":"Beacon.Content.html#change_event_handler/2"},{"type":"function","title":"Example - Beacon.Content.change_event_handler/2","doc":"iex> change_event_handler(event_handler, %{name: \"form-submit\"})\n    %Ecto.Changeset{data: %EventHandler{}}","ref":"Beacon.Content.html#change_event_handler/2-example"},{"type":"function","title":"Beacon.Content.change_layout/2","doc":"Returns an `%Ecto.Changeset{}` for tracking layout changes.","ref":"Beacon.Content.html#change_layout/2"},{"type":"function","title":"Example - Beacon.Content.change_layout/2","doc":"iex> change_layout(layout, %{title: \"New Home\"})\n    %Ecto.Changeset{data: %Layout{}}","ref":"Beacon.Content.html#change_layout/2-example"},{"type":"function","title":"Beacon.Content.change_live_data_assign/2","doc":"Returns an `%Ecto.Changeset{}` for tracking LiveDataAssign changes.","ref":"Beacon.Content.html#change_live_data_assign/2"},{"type":"function","title":"Example - Beacon.Content.change_live_data_assign/2","doc":"iex> change_live_data_assign(live_data_assign, %{format: :elixir, value: \"Enum.random(1..100)\"})\n    %Ecto.Changeset{data: %LiveDataAssign{}}","ref":"Beacon.Content.html#change_live_data_assign/2-example"},{"type":"function","title":"Beacon.Content.change_live_data_path/2","doc":"Returns an `%Ecto.Changeset{}` for tracking LiveData `:path` changes.","ref":"Beacon.Content.html#change_live_data_path/2"},{"type":"function","title":"Example - Beacon.Content.change_live_data_path/2","doc":"iex> change_live_data(live_data, %{path: \"/foo/:bar_id\"})\n    %Ecto.Changeset{data: %LiveData{}}","ref":"Beacon.Content.html#change_live_data_path/2-example"},{"type":"function","title":"Beacon.Content.change_page/2","doc":"Returns an `%Ecto.Changeset{}` for tracking page changes.","ref":"Beacon.Content.html#change_page/2"},{"type":"function","title":"Example - Beacon.Content.change_page/2","doc":"iex> change_page(page, %{title: \"My Campaign\"})\n    %Ecto.Changeset{data: %Page{}}","ref":"Beacon.Content.html#change_page/2-example"},{"type":"function","title":"Beacon.Content.change_page_variant/2","doc":"Returns an `%Ecto.Changeset{}` for tracking variant changes.","ref":"Beacon.Content.html#change_page_variant/2"},{"type":"function","title":"Example - Beacon.Content.change_page_variant/2","doc":"iex> change_page_variant(page_variant, %{name: \"Variant A\"})\n    %Ecto.Changeset{data: %PageVariant{}}","ref":"Beacon.Content.html#change_page_variant/2-example"},{"type":"function","title":"Beacon.Content.change_slot_attr/3","doc":"Returns an `%Ecto.Changeset{}` for tracking slot_attr changes.","ref":"Beacon.Content.html#change_slot_attr/3"},{"type":"function","title":"Example - Beacon.Content.change_slot_attr/3","doc":"iex> change_slot_attr(slot_attr, %{name: \"Header\"}, [])\n    %Ecto.Changeset{data: %ComponentSlotAttr{}}","ref":"Beacon.Content.html#change_slot_attr/3-example"},{"type":"function","title":"Beacon.Content.component_categories/0","doc":"Returns a list of all existing component categories.","ref":"Beacon.Content.html#component_categories/0"},{"type":"function","title":"Beacon.Content.count_components/2","doc":"Counts the total number of components based on the amount of pages.","ref":"Beacon.Content.html#count_components/2"},{"type":"function","title":"Options - Beacon.Content.count_components/2","doc":"* `:query` - filter rows count by query. Defaults to `nil`, doesn't filter query.","ref":"Beacon.Content.html#count_components/2-options"},{"type":"function","title":"Beacon.Content.count_layouts/2","doc":"Counts the total number of layouts based on the amount of pages.","ref":"Beacon.Content.html#count_layouts/2"},{"type":"function","title":"Options - Beacon.Content.count_layouts/2","doc":"* `:query` - filter rows count by query. Defaults to `nil`, doesn't filter query.","ref":"Beacon.Content.html#count_layouts/2-options"},{"type":"function","title":"Beacon.Content.count_pages/2","doc":"Counts the total number of pages based on the amount of pages.","ref":"Beacon.Content.html#count_pages/2"},{"type":"function","title":"Options - Beacon.Content.count_pages/2","doc":"* `:query` - filter rows count by query","ref":"Beacon.Content.html#count_pages/2-options"},{"type":"function","title":"Beacon.Content.create_assign_for_live_data/2","doc":"Creates a new LiveDataAssign.","ref":"Beacon.Content.html#create_assign_for_live_data/2"},{"type":"function","title":"Beacon.Content.create_component/1","doc":"Creates a component.\n\nReturns `{:ok, component}` if successful, otherwise `{:error, changeset}`.","ref":"Beacon.Content.html#create_component/1"},{"type":"function","title":"Example - Beacon.Content.create_component/1","doc":"iex> create_component(attrs)\n    {:ok, %Component{}}","ref":"Beacon.Content.html#create_component/1-example"},{"type":"function","title":"Beacon.Content.create_component!/1","doc":"Creates a component, raising an error if unsuccessful.\n\nReturns the new component if successful, otherwise raises a `RuntimeError`.","ref":"Beacon.Content.html#create_component!/1"},{"type":"function","title":"Beacon.Content.create_error_page/1","doc":"Creates a new error page.","ref":"Beacon.Content.html#create_error_page/1"},{"type":"function","title":"Beacon.Content.create_error_page!/1","doc":"Creates a new error page, raising if the operation fails.","ref":"Beacon.Content.html#create_error_page!/1"},{"type":"function","title":"Beacon.Content.create_event_handler/1","doc":"Creates a new event handler.","ref":"Beacon.Content.html#create_event_handler/1"},{"type":"function","title":"Beacon.Content.create_layout/1","doc":"Creates a layout.","ref":"Beacon.Content.html#create_layout/1"},{"type":"function","title":"Example - Beacon.Content.create_layout/1","doc":"iex> create_layout(%{title: \"Home\"})\n    {:ok, %Layout{}}","ref":"Beacon.Content.html#create_layout/1-example"},{"type":"function","title":"Beacon.Content.create_layout!/1","doc":"Creates a layout.","ref":"Beacon.Content.html#create_layout!/1"},{"type":"function","title":"Beacon.Content.create_live_data/1","doc":"Creates a new LiveData for scoping live data to pages.\n\nReturns `{:ok, live_data}` if successful, otherwise `{:error, changeset}`","ref":"Beacon.Content.html#create_live_data/1"},{"type":"function","title":"Beacon.Content.create_live_data!/1","doc":"Creates a new LiveData for scoping live data to pages, raising an error if unsuccessful.\n\nReturns the new LiveData if successful, otherwise raises a `RuntimeError`.","ref":"Beacon.Content.html#create_live_data!/1"},{"type":"function","title":"Beacon.Content.create_page/1","doc":"Creates a new page that's not published.","ref":"Beacon.Content.html#create_page/1"},{"type":"function","title":"Example - Beacon.Content.create_page/1","doc":"iex> create_page(%{\"title\" => \"My New Page\"})\n    {:ok, %Page{}}\n\n`attrs` may contain the following keys:\n\n  * `path` - String.t()\n  * `title` - String.t()\n  * `description` - String.t()\n  * `template` - String.t()\n  * `meta_tags` - list(map()) eg: `[%{\"property\" => \"og:title\", \"content\" => \"My New Site\"}]`\n\nSee `Beacon.Content.Page` for more info.\n\nThe created page is not published automatically,\nyou can make as much changes you need and when the page\nis ready to be published you can call `publish_page/1`\n\nIt will insert a `created` event into the page timeline,\nand no snapshot is created.","ref":"Beacon.Content.html#create_page/1-example"},{"type":"function","title":"Beacon.Content.create_page!/1","doc":"Creates a page.\n\nRaises an error if unsuccessful.","ref":"Beacon.Content.html#create_page!/1"},{"type":"function","title":"Beacon.Content.create_slot_attr/3","doc":"Creates a slot attr.","ref":"Beacon.Content.html#create_slot_attr/3"},{"type":"function","title":"Example - Beacon.Content.create_slot_attr/3","doc":"iex> create_slot_attr(site, attrs)\n    {:ok, %ComponentSlotAttr{}}","ref":"Beacon.Content.html#create_slot_attr/3-example"},{"type":"function","title":"Beacon.Content.create_slot_for_component/2","doc":"Creates a new component slot and returns the component with updated `:slots` association.","ref":"Beacon.Content.html#create_slot_for_component/2"},{"type":"function","title":"Beacon.Content.create_snippet_helper/1","doc":"Creates a snippet helper.\n\nReturns `{:ok, helper}` if successful, otherwise `{:error, changeset}`","ref":"Beacon.Content.html#create_snippet_helper/1"},{"type":"function","title":"Beacon.Content.create_snippet_helper!/1","doc":"Creates a snippet helper, raising an error if unsuccessful.\n\nReturns the new helper if successful, otherwise raises a `RuntimeError`.","ref":"Beacon.Content.html#create_snippet_helper!/1"},{"type":"function","title":"Beacon.Content.create_stylesheet/1","doc":"Creates a stylesheet.\n\nReturns `{:ok, stylesheet}` if successful, otherwise `{:error, changeset}`.","ref":"Beacon.Content.html#create_stylesheet/1"},{"type":"function","title":"Example - Beacon.Content.create_stylesheet/1","doc":"iex >create_stylesheet(%{\n      site: :my_site,\n      name: \"override\",\n      content: ~S|\n      @media (min-width: 768px) {\n        .md:text-red-400 {\n          color: red;\n        }\n      }\n      |\n    })\n    {:ok, %Stylesheet{}}\n\nNote that escape characters must be preserved, so you should use `~S` to avoid issues.","ref":"Beacon.Content.html#create_stylesheet/1-example"},{"type":"function","title":"Beacon.Content.create_stylesheet!/1","doc":"Creates a stylesheet, raising an error if unsuccessful.\n\nReturns the new stylesheet if successful, otherwise raises a `RuntimeError`.","ref":"Beacon.Content.html#create_stylesheet!/1"},{"type":"function","title":"Example - Beacon.Content.create_stylesheet!/1","doc":"iex >create_stylesheet!(%{\n      site: :my_site,\n      name: \"override\",\n      content: ~S|\n      @media (min-width: 768px) {\n        .md:text-red-400 {\n          color: red;\n        }\n      }\n      |\n    })\n    %Stylesheet{}\n\nNote that escape characters must be preserved, so you should use `~S` to avoid issues.","ref":"Beacon.Content.html#create_stylesheet!/1-example"},{"type":"function","title":"Beacon.Content.create_variant_for_page/2","doc":"Creates a new page variant and returns the page with updated `:variants` association.","ref":"Beacon.Content.html#create_variant_for_page/2"},{"type":"function","title":"Beacon.Content.default_error_pages/0","doc":"Returns attr data to load the default error_pages into new sites.","ref":"Beacon.Content.html#default_error_pages/0"},{"type":"function","title":"Beacon.Content.default_layout/0","doc":"Returns a map of attrs to load the default layout into new sites.","ref":"Beacon.Content.html#default_layout/0"},{"type":"function","title":"Beacon.Content.default_site_meta_tags/0","doc":"Returns the list of meta tags that are applied to all pages by default.\n\nThese meta tags can be overwritten or extended on a Layout or Page level.","ref":"Beacon.Content.html#default_site_meta_tags/0"},{"type":"function","title":"Beacon.Content.delete_error_page/1","doc":"Deletes an error page.","ref":"Beacon.Content.html#delete_error_page/1"},{"type":"function","title":"Beacon.Content.delete_event_handler/1","doc":"Deletes an event handler.","ref":"Beacon.Content.html#delete_event_handler/1"},{"type":"function","title":"Beacon.Content.delete_live_data/1","doc":"Deletes LiveData.","ref":"Beacon.Content.html#delete_live_data/1"},{"type":"function","title":"Beacon.Content.delete_live_data_assign/2","doc":"Deletes LiveDataAssign.","ref":"Beacon.Content.html#delete_live_data_assign/2"},{"type":"function","title":"Beacon.Content.delete_slot_attr/2","doc":"Deletes a slot attr.","ref":"Beacon.Content.html#delete_slot_attr/2"},{"type":"function","title":"Beacon.Content.delete_slot_from_component/2","doc":"Deletes a component slot and returns the component with updated slots association.","ref":"Beacon.Content.html#delete_slot_from_component/2"},{"type":"function","title":"Beacon.Content.delete_variant_from_page/2","doc":"Deletes a page variant and returns the page with updated `:variants` association.","ref":"Beacon.Content.html#delete_variant_from_page/2"},{"type":"function","title":"Beacon.Content.get_component_by/3","doc":"Gets a single component by `clauses`.","ref":"Beacon.Content.html#get_component_by/3"},{"type":"function","title":"Example - Beacon.Content.get_component_by/3","doc":"iex> get_component_by(site, name: \"header\")\n    %Component{}","ref":"Beacon.Content.html#get_component_by/3-example"},{"type":"function","title":"Beacon.Content.get_error_page/2","doc":"Returns the error page for a given site and status code, or `nil` if no matching error page exists.","ref":"Beacon.Content.html#get_error_page/2"},{"type":"function","title":"Beacon.Content.get_latest_layout_event/2","doc":"Returns the latest layout event.\n\nUseful to find the status of a layout.","ref":"Beacon.Content.html#get_latest_layout_event/2"},{"type":"function","title":"Example - Beacon.Content.get_latest_layout_event/2","doc":"iex> get_latest_layout_event(:my_site, layout_id)\n    %LayoutEvent{event: :published}","ref":"Beacon.Content.html#get_latest_layout_event/2-example"},{"type":"function","title":"Beacon.Content.get_latest_page_event/2","doc":"Returns the latest page event.\n\nUseful to find the status of a page.","ref":"Beacon.Content.html#get_latest_page_event/2"},{"type":"function","title":"Example - Beacon.Content.get_latest_page_event/2","doc":"iex> get_latest_page_event(:my_site, page_id)\n    %PageEvent{event: :published}","ref":"Beacon.Content.html#get_latest_page_event/2-example"},{"type":"function","title":"Beacon.Content.get_layout/2","doc":"Gets a single layout by `id`.","ref":"Beacon.Content.html#get_layout/2"},{"type":"function","title":"Example - Beacon.Content.get_layout/2","doc":"iex> get_layout(:my_site, \"fd70e5fe-9bd8-41ed-94eb-5459c9bb05fc\")\n    %Layout{}","ref":"Beacon.Content.html#get_layout/2-example"},{"type":"function","title":"Beacon.Content.get_layout!/2","doc":"Same as `get_layout/2` but raises an error if no result is found.","ref":"Beacon.Content.html#get_layout!/2"},{"type":"function","title":"Beacon.Content.get_layout_by/3","doc":"Gets a single layout by `clauses`.","ref":"Beacon.Content.html#get_layout_by/3"},{"type":"function","title":"Example - Beacon.Content.get_layout_by/3","doc":"iex> get_layout_by(site, title: \"blog\")\n    %Layout{}","ref":"Beacon.Content.html#get_layout_by/3-example"},{"type":"function","title":"Beacon.Content.get_live_data_by/3","doc":"Gets a single live data by `clauses`.","ref":"Beacon.Content.html#get_live_data_by/3"},{"type":"function","title":"Example - Beacon.Content.get_live_data_by/3","doc":"iex> get_live_data_by(site, id: \"cba9ee2e-d40e-48af-9704-1237e4c23bde\")\n    %LiveData{}\n\n    iex> get_live_data_by(site, path: \"/blog\")\n    %LiveData{}","ref":"Beacon.Content.html#get_live_data_by/3-example"},{"type":"function","title":"Beacon.Content.get_page/3","doc":"Gets a single page by `id`.","ref":"Beacon.Content.html#get_page/3"},{"type":"function","title":"Options - Beacon.Content.get_page/3","doc":"* `:preloads` - a list of preloads to load.","ref":"Beacon.Content.html#get_page/3-options"},{"type":"function","title":"Examples - Beacon.Content.get_page/3","doc":"iex> get_page(:my_site, \"dba8a99e-311a-4806-af04-dd968c7e5dae\")\n    %Page{}\n\n    iex> get_page(:my_site, \"dba8a99e-311a-4806-af04-dd968c7e5dae\", preloads: [:layout])\n    %Page{layout: %Layout{}}","ref":"Beacon.Content.html#get_page/3-examples"},{"type":"function","title":"Beacon.Content.get_page!/3","doc":"Same as `get_page/3` but raises an error if no result is found.","ref":"Beacon.Content.html#get_page!/3"},{"type":"function","title":"Beacon.Content.get_page_by/3","doc":"Gets a single page by `clauses`.","ref":"Beacon.Content.html#get_page_by/3"},{"type":"function","title":"Example - Beacon.Content.get_page_by/3","doc":"iex> get_page_by(site, path: \"/contact\")\n    %Page{}","ref":"Beacon.Content.html#get_page_by/3-example"},{"type":"function","title":"Beacon.Content.get_published_layout/2","doc":"Get latest published layout.\n\nThis operation is cached.","ref":"Beacon.Content.html#get_published_layout/2"},{"type":"function","title":"Beacon.Content.get_published_page/2","doc":"Get latest published page.\n\nThis operation is cached.","ref":"Beacon.Content.html#get_published_page/2"},{"type":"function","title":"Beacon.Content.get_stylesheet_by/3","doc":"Gets a single stylesheet by `clauses`.","ref":"Beacon.Content.html#get_stylesheet_by/3"},{"type":"function","title":"Example - Beacon.Content.get_stylesheet_by/3","doc":"iex> get_stylesheet_by(site, name: \"main\")\n    %Stylesheet{}","ref":"Beacon.Content.html#get_stylesheet_by/3-example"},{"type":"function","title":"Beacon.Content.list_components/2","doc":"List components.","ref":"Beacon.Content.html#list_components/2"},{"type":"function","title":"Options - Beacon.Content.list_components/2","doc":"* `:per_page` - limit how many records are returned, or pass `:infinity` to return all records. Defaults to 20.\n  * `:page` - returns records from a specfic page. Defaults to 1.\n  * `:query` - search components by title. Defaults to `nil`, doesn't filter query.\n  * `:preloads` - a list of preloads to load.\n  * `:sort` - column in which the result will be ordered by. Defaults to `:name`.","ref":"Beacon.Content.html#list_components/2-options"},{"type":"function","title":"Beacon.Content.list_components_by_name/2","doc":"List components by `name`.","ref":"Beacon.Content.html#list_components_by_name/2"},{"type":"function","title":"Example - Beacon.Content.list_components_by_name/2","doc":"iex> list_components_by_name(site, \"header\")\n    [%Component{name: \"header\"}]","ref":"Beacon.Content.html#list_components_by_name/2-example"},{"type":"function","title":"Beacon.Content.list_error_pages/2","doc":"Lists all error pages for a given site.","ref":"Beacon.Content.html#list_error_pages/2"},{"type":"function","title":"Options - Beacon.Content.list_error_pages/2","doc":"* `:per_page` - limit how many records are returned, or pass `:infinity` to return all records.\n  * `:preloads` - a list of preloads to load.","ref":"Beacon.Content.html#list_error_pages/2-options"},{"type":"function","title":"Beacon.Content.list_error_pages_by/3","doc":"Lists all error pages for a given site, filtered by `clauses`.\n\nCurrently the only acceptable clause is `:layout_id`.\nSee `list_error_pages/2` for a list of acceptable `opts`.","ref":"Beacon.Content.html#list_error_pages_by/3"},{"type":"function","title":"Beacon.Content.list_event_handlers/1","doc":"Lists all event handlers for a given Beacon site.","ref":"Beacon.Content.html#list_event_handlers/1"},{"type":"function","title":"Beacon.Content.list_layout_events/2","doc":"Returns all layout events with associated snapshot if available.","ref":"Beacon.Content.html#list_layout_events/2"},{"type":"function","title":"Example - Beacon.Content.list_layout_events/2","doc":"iex> list_layout_events(:my_site, layout_id)\n    [\n      %LayoutEvent{event: :created, snapshot: nil},\n      %LayoutEvent{event: :published, snapshot: %LayoutSnapshot{}}\n    ]","ref":"Beacon.Content.html#list_layout_events/2-example"},{"type":"function","title":"Beacon.Content.list_layouts/2","doc":"List layouts.","ref":"Beacon.Content.html#list_layouts/2"},{"type":"function","title":"Options - Beacon.Content.list_layouts/2","doc":"* `:per_page` - limit how many records are returned, or pass `:infinity` to return all records. Defaults to 20.\n  * `:page` - returns records from a specfic page. Defaults to 1.\n  * `:query` - search layouts by title. Defaults to `nil`, doesn't filter query.\n  * `:preloads` - a list of preloads to load.\n  * `:sort` - column in which the result will be ordered by. Defaults to `:title`.\n    Allowed values: `:title`, `:template`, `:meta_tags`, `:resource_links`, `:inserted_at`, `:updated_at`.","ref":"Beacon.Content.html#list_layouts/2-options"},{"type":"function","title":"Beacon.Content.list_page_events/2","doc":"Returns all page events with associated snapshot if available.","ref":"Beacon.Content.html#list_page_events/2"},{"type":"function","title":"Example - Beacon.Content.list_page_events/2","doc":"iex> list_page_events(:my_site, page_id)\n    [\n      %PageEvent{event: :created, snapshot: nil},\n      %PageEvent{event: :published, snapshot: %PageSnapshot{}}\n    ]","ref":"Beacon.Content.html#list_page_events/2-example"},{"type":"function","title":"Beacon.Content.list_pages/2","doc":"List pages.","ref":"Beacon.Content.html#list_pages/2"},{"type":"function","title":"Options - Beacon.Content.list_pages/2","doc":"* `:per_page` - limit how many records are returned, or pass `:infinity` to return all records. Defaults to 20.\n  * `:page` - returns records from a specfic page. Defaults to 1.\n  * `:query` - search pages by path or title.\n  * `:preloads` - a list of preloads to load.\n  * `:sort` - column in which the result will be ordered by. Defaults to `:path`.\n    Allowed values: `:path`, `:title`, `:description`, `:template`, `:meta_tags`, `:raw_schema`, `:format`, `:inserted_at`, `:updated_at`.","ref":"Beacon.Content.html#list_pages/2-options"},{"type":"function","title":"Beacon.Content.list_published_layouts/1","doc":"Returns all published layouts for `site`.\n\nLayouts are extracted from the latest published `Beacon.Content.LayoutSnapshot`.","ref":"Beacon.Content.html#list_published_layouts/1"},{"type":"function","title":"Beacon.Content.list_published_pages/2","doc":"Lists and search all published pages for `site`.\n\nNote that unpublished pages are not returned even if it was once published before, only the latest snapshot is considered.","ref":"Beacon.Content.html#list_published_pages/2"},{"type":"function","title":"Options - Beacon.Content.list_published_pages/2","doc":"* `:per_page` - limit how many records are returned, or pass `:infinity` to return all records. Defaults to 20.\n  * `:page` - returns records from a specfic page. Defaults to 1.\n  * `:search` - search by either one or more fields or dynamic query function.\n                Available fields: `path`, `title`, `format`, `extra`. Defaults to `nil` (do not apply search filter).\n  * `:sort` - column in which the result will be ordered by. Defaults to `:title`.","ref":"Beacon.Content.html#list_published_pages/2-options"},{"type":"function","title":"Examples - Beacon.Content.list_published_pages/2","doc":"iex> list_published_pages(:my_site, search: %{path: \"/home\", title: \"Home Page\"})\n    [%Page{}]\n\n    iex> list_published_pages(:my_site, search: %{extra: %{\"tags\" => \"press\"}})\n    [%Page{}]\n\n    iex> list_published_pages(:my_site, search: fn -> dynamic([q], fragment(\"extra->>'tags' ilike 'year-20%'\")) end)\n    [%Page{}]","ref":"Beacon.Content.html#list_published_pages/2-examples"},{"type":"function","title":"Beacon.Content.list_snippet_helpers/1","doc":"Returns the list of snippet helpers for a `site`.","ref":"Beacon.Content.html#list_snippet_helpers/1"},{"type":"function","title":"Example - Beacon.Content.list_snippet_helpers/1","doc":"iex> list_snippet_helpers()\n    [%SnippetHelper{}, ...]","ref":"Beacon.Content.html#list_snippet_helpers/1-example"},{"type":"function","title":"Beacon.Content.list_stylesheets/1","doc":"Returns the list of stylesheets for `site`.","ref":"Beacon.Content.html#list_stylesheets/1"},{"type":"function","title":"Example - Beacon.Content.list_stylesheets/1","doc":"iex> list_stylesheets()\n    [%Stylesheet{}, ...]","ref":"Beacon.Content.html#list_stylesheets/1-example"},{"type":"function","title":"Beacon.Content.live_data_assign_formats/0","doc":"Returns a list of all existing LiveDataAssign formats.","ref":"Beacon.Content.html#live_data_assign_formats/0"},{"type":"function","title":"Beacon.Content.live_data_for_site/2","doc":"Query LiveData for a given site.","ref":"Beacon.Content.html#live_data_for_site/2"},{"type":"function","title":"Options - Beacon.Content.live_data_for_site/2","doc":"* `:per_page` - limit how many records are returned, or pass `:infinity` to return all records.\n  * `:query` - search records by path.\n  * `:select` - returns only the given field(s)\n  * `:preload` - include given association(s) (defaults to `:assigns`)","ref":"Beacon.Content.html#live_data_for_site/2-options"},{"type":"function","title":"Beacon.Content.publish_layout/1","doc":"Publishes `layout` and reload resources to render the updated layout and pages.\n\nEvent + snapshot\n\nThis operation is serialized.","ref":"Beacon.Content.html#publish_layout/1"},{"type":"function","title":"Beacon.Content.publish_layout/2","doc":"Same as `publish_layout/2` but accepts a `site` and `layout_id` with which to lookup the layout.","ref":"Beacon.Content.html#publish_layout/2"},{"type":"function","title":"Beacon.Content.publish_page/1","doc":"Publish `page`.\n\nA new snapshot is automatically created to store the page data,\nwhich is used whenever the site or the page is reloaded. So you\ncan keep editing the page as needed without impacting the published page.\n\nThis operation is serialized.","ref":"Beacon.Content.html#publish_page/1"},{"type":"function","title":"Beacon.Content.publish_page/2","doc":"Same as `publish_page/1` but accepts a `site` and `page_id` with which to lookup the page.","ref":"Beacon.Content.html#publish_page/2"},{"type":"function","title":"Beacon.Content.publish_pages/1","doc":"Publish multiple `pages`.\n\nSimilar to `publish_page/1` but defers loading dependent resources\nas late as possible making the process faster.","ref":"Beacon.Content.html#publish_pages/1"},{"type":"function","title":"Beacon.Content.put_page_extra/2","doc":"Given a map of fields, stores this map as `:extra` fields in a `Page`.\n\nAny existing `:extra` data for that Page will be overwritten!","ref":"Beacon.Content.html#put_page_extra/2"},{"type":"function","title":"Beacon.Content.render_snippet/2","doc":"Renders a snippet `template` with the given `assigns`.\n\nSnippets are small pieces of string with interpolated assigns.\n\nThink of it as small templates.","ref":"Beacon.Content.html#render_snippet/2"},{"type":"function","title":"Examples - Beacon.Content.render_snippet/2","doc":"iex> Beacon.Content.render_snippet(\"title is {{ page.title }}\", %{page: %{title: \"home\"}})\n    {:ok, \"title is home\"}\n\nSnippets use the [Liquid](https://shopify.github.io/liquid/) template under the hood,\nwhich means that all [filters](https://shopify.github.io/liquid/basics/introduction/#filters) are available for use, eg:\n\n    iex> Beacon.Content.render_snippet(\"{{ 'title' | capitalize }}\", assigns)\n    {:ok, \"Title\"}\n\nIn situations where the Liquid filters are not enough, you can create helpers\nto process the template using regular Elixir.\n\nIn the next example a `author_name` is created to simulate a query to fetch the author's name:\n\n    iex> page = Beacon.Content.create_page(%{site: \"my_site\", extra: %{\"author_id\": 1}})\n    iex> Beacon.Content.create_snippet_helper(%{site: \"my_site\", name: \"author_name\", body: ~S\"\"\"\n    ...> author_id = get_in(assigns, [\"page\", \"extra\", \"author_id\"])\n    ...> MyApp.fetch_author_name(author_id)\n    ...> \"\"\"\n    iex> Beacon.Snippet.render(\"Author is {{ helper 'author_name' }}\", %{page: page})\n    {:ok, \"Author is Anon\"}\n\nNote that the `:page` assigns is made available as `assigns[\"page\"]` (String.t) due to how Solid works.\n\nSnippets can be used in:\n\n  * Meta Tag value\n  * Page Schema (structured Schema.org tags)\n  * Page Title\n\nAllowed assigns:\n\n  * :page (map)\n  * :live_data (map)","ref":"Beacon.Content.html#render_snippet/2-examples"},{"type":"function","title":"Beacon.Content.unpublish_page/1","doc":"Unpublish `page`.\n\nNote that page will be removed from your site\nand it will return error 404 for new requests.","ref":"Beacon.Content.html#unpublish_page/1"},{"type":"function","title":"Beacon.Content.update_component/2","doc":"Updates a component.\n\n    iex> update_component(component, %{name: \"new_component\"})\n    {:ok, %Component{}}","ref":"Beacon.Content.html#update_component/2"},{"type":"function","title":"Beacon.Content.update_error_page/2","doc":"Updates an error page.","ref":"Beacon.Content.html#update_error_page/2"},{"type":"function","title":"Beacon.Content.update_event_handler/2","doc":"Updates an event handler with the given attrs.","ref":"Beacon.Content.html#update_event_handler/2"},{"type":"function","title":"Beacon.Content.update_layout/2","doc":"Updates a layout.","ref":"Beacon.Content.html#update_layout/2"},{"type":"function","title":"Example - Beacon.Content.update_layout/2","doc":"iex> update_layout(layout, %{title: \"New Home\"})\n    {:ok, %Layout{}}","ref":"Beacon.Content.html#update_layout/2-example"},{"type":"function","title":"Beacon.Content.update_live_data_assign/3","doc":"Updates LiveDataAssign.\n\n    iex> update_live_data_assign(live_data_assign, :my_site, %{code: \"true\"})\n    {:ok, %LiveDataAssign{}}","ref":"Beacon.Content.html#update_live_data_assign/3"},{"type":"function","title":"Beacon.Content.update_live_data_path/2","doc":"Updates LiveDataPath.\n\n    iex> update_live_data_path(live_data, \"/foo/bar/:baz_id\")\n    {:ok, %LiveData{}}","ref":"Beacon.Content.html#update_live_data_path/2"},{"type":"function","title":"Beacon.Content.update_page/2","doc":"Updates a page.","ref":"Beacon.Content.html#update_page/2"},{"type":"function","title":"Example - Beacon.Content.update_page/2","doc":"iex> update_page(page, %{title: \"New Home\"})\n    {:ok, %Page{}}","ref":"Beacon.Content.html#update_page/2-example"},{"type":"function","title":"Beacon.Content.update_slot_attr/4","doc":"Updates a slot attr.\n\n    iex> update_slot(slot_attr, %{name: \"new_slot\"})\n    {:ok, %ComponentSlotAttr{}}","ref":"Beacon.Content.html#update_slot_attr/4"},{"type":"function","title":"Beacon.Content.update_slot_for_component/4","doc":"Updates a component slot and returns the component with updated `:slots` association.","ref":"Beacon.Content.html#update_slot_for_component/4"},{"type":"function","title":"Beacon.Content.update_stylesheet/2","doc":"Updates a stylesheet.","ref":"Beacon.Content.html#update_stylesheet/2"},{"type":"function","title":"Example - Beacon.Content.update_stylesheet/2","doc":"iex> update_stylesheet(stylesheet, %{name: new_value})\n    {:ok, %Stylesheet{}}","ref":"Beacon.Content.html#update_stylesheet/2-example"},{"type":"function","title":"Beacon.Content.update_variant_for_page/3","doc":"Updates a page variant and returns the page with updated `:variants` association.","ref":"Beacon.Content.html#update_variant_for_page/3"},{"type":"function","title":"Beacon.Content.validate_page/3","doc":"Validate `page` with the given `params`.\n\nAll `Beacon.Content.PageField` are validated","ref":"Beacon.Content.html#validate_page/3"},{"type":"module","title":"Beacon.Content.Component","doc":"Beacon's representation of [Phoenix Components](https://hexdocs.pm/phoenix_live_view/Phoenix.Component.html),\nwhich can be used and re-used in your pages and layouts.\n\n> #### Do not create or edit components manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.Component.html"},{"type":"function","title":"Beacon.Content.Component.categories/0","doc":"","ref":"Beacon.Content.Component.html#categories/0"},{"type":"type","title":"Beacon.Content.Component.t/0","doc":"","ref":"Beacon.Content.Component.html#t:t/0"},{"type":"module","title":"Beacon.Content.ComponentAttr","doc":"Beacon's representation of Phoenix's [Component attributes](https://hexdocs.pm/phoenix_live_view/Phoenix.Component.html#module-attributes).\n\nComponentAttrs don't exist on their own, but always belong to a `Beacon.Content.Component`.\n\n> #### Do not create or edit component attrs manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.ComponentAttr.html"},{"type":"type","title":"Beacon.Content.ComponentAttr.t/0","doc":"","ref":"Beacon.Content.ComponentAttr.html#t:t/0"},{"type":"module","title":"Beacon.Content.ComponentSlot","doc":"Beacon's representation of Phoenix's [Slots](https://hexdocs.pm/phoenix_live_view/Phoenix.Component.html#module-slots).\n\nComponentSlots don't exist on their own, but always belong to a `Beacon.Content.Component`.\n\n> #### Do not create or edit component slots manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.ComponentSlot.html"},{"type":"type","title":"Beacon.Content.ComponentSlot.t/0","doc":"","ref":"Beacon.Content.ComponentSlot.html#t:t/0"},{"type":"module","title":"Beacon.Content.ComponentSlotAttr","doc":"Beacon's representation of Phoenix's [Slot attributes](https://hexdocs.pm/phoenix_live_view/Phoenix.Component.html#module-slot-attributes).\n\nComponentSlotAttrs don't exist on their own, but always belong to a `Beacon.Content.ComponentSlot`, which in turn\nbelongs to a `Beacon.Content.Component`.\n\n> #### Do not create or edit component slot attrs manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.ComponentSlotAttr.html"},{"type":"type","title":"Beacon.Content.ComponentSlotAttr.t/0","doc":"","ref":"Beacon.Content.ComponentSlotAttr.html#t:t/0"},{"type":"module","title":"Beacon.Content.ErrorPage","doc":"Stores a template which can be rendered for error responses.\n\nAn ErrorPage contains four main fields:\n\n  * `:status` - the status code for which this ErrorPage is to be used\n  * `:template` - the template to be rendered\n  * `:site` - the Beacon site which should use this page\n  * `:layout_id` - the ID of the Beacon Layout which is used for rendering\n\n> #### Do not create or edit ErrorPages manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.ErrorPage.html"},{"type":"function","title":"Beacon.Content.ErrorPage.valid_statuses/0","doc":"","ref":"Beacon.Content.ErrorPage.html#valid_statuses/0"},{"type":"type","title":"Beacon.Content.ErrorPage.error_status/0","doc":"","ref":"Beacon.Content.ErrorPage.html#t:error_status/0"},{"type":"type","title":"Beacon.Content.ErrorPage.t/0","doc":"","ref":"Beacon.Content.ErrorPage.html#t:t/0"},{"type":"module","title":"Beacon.Content.EventHandler","doc":"Beacon's representation of a LiveView [handle_event/3](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html#c:handle_event/3).\n\nThis is the Elixir code which will receive form submission or on-click events.\n\n> #### Do not create or edit page event handlers manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.EventHandler.html"},{"type":"type","title":"Beacon.Content.EventHandler.t/0","doc":"","ref":"Beacon.Content.EventHandler.html#t:t/0"},{"type":"module","title":"Beacon.Content.Layout","doc":"The wrapper content for a `Beacon.Content.Page`.\n\n> #### Do not create or layouts pages manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.Layout.html"},{"type":"function","title":"Beacon.Content.Layout.version/0","doc":"Current data structure version.\n\nBump when schema changes.","ref":"Beacon.Content.Layout.html#version/0"},{"type":"type","title":"Beacon.Content.Layout.t/0","doc":"","ref":"Beacon.Content.Layout.html#t:t/0"},{"type":"module","title":"Beacon.Content.LayoutEvent","doc":"Represents a point in time when a `Beacon.Content.Layout` was created or published.\n\nAt that time, a `Beacon.Content.LayoutSnapshot` is created and stored with the LayoutEvent.\n\n> #### Do not create or edit layout events manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.LayoutEvent.html"},{"type":"type","title":"Beacon.Content.LayoutEvent.t/0","doc":"","ref":"Beacon.Content.LayoutEvent.html#t:t/0"},{"type":"module","title":"Beacon.Content.LayoutSnapshot","doc":"Represents the template of a `Beacon.Content.Layout` at a specific moment in time.\n\nLayoutSnapshots don't exist on their own, but are created as part of a `Beacon.Content.LayoutEvent`\nwhenever a Layout is created or published.\n\n> #### Do not create or edit layout snapshots manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.LayoutSnapshot.html"},{"type":"type","title":"Beacon.Content.LayoutSnapshot.t/0","doc":"","ref":"Beacon.Content.LayoutSnapshot.html#t:t/0"},{"type":"module","title":"Beacon.Content.LiveData","doc":"Scopes `Beacon.Content.LiveDataAssign`s to `Beacon.Content.Page`s via site and path.\n\n> #### Do not create or edit live data manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.LiveData.html"},{"type":"function","title":"Beacon.Content.LiveData.changeset/2","doc":"","ref":"Beacon.Content.LiveData.html#changeset/2"},{"type":"function","title":"Beacon.Content.LiveData.path_changeset/2","doc":"","ref":"Beacon.Content.LiveData.html#path_changeset/2"},{"type":"type","title":"Beacon.Content.LiveData.t/0","doc":"","ref":"Beacon.Content.LiveData.html#t:t/0"},{"type":"module","title":"Beacon.Content.LiveDataAssign","doc":"Dynamic key/value assigns to be used by `Beacon.Content.Page` templates and updated with `Beacon.Content.EventHandler`s.\n\nLiveDataAssigns don't exist on their own, but exist as part of a `Beacon.Content.LiveData` struct.\n\n> #### Do not create or edit live data manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.LiveDataAssign.html"},{"type":"function","title":"Beacon.Content.LiveDataAssign.changeset/2","doc":"","ref":"Beacon.Content.LiveDataAssign.html#changeset/2"},{"type":"function","title":"Beacon.Content.LiveDataAssign.formats/0","doc":"","ref":"Beacon.Content.LiveDataAssign.html#formats/0"},{"type":"type","title":"Beacon.Content.LiveDataAssign.t/0","doc":"","ref":"Beacon.Content.LiveDataAssign.html#t:t/0"},{"type":"module","title":"Beacon.Content.Page","doc":"Pages are the central piece of content in Beacon used to render templates with meta tags, components, and other resources.\n\nPages are rendered as a LiveView handled by Beacon.\n\nPages can be extended with custom fields, see `Beacon.Content.PageField`","ref":"Beacon.Content.Page.html"},{"type":"module","title":"SEO - Beacon.Content.Page","doc":"Meta Tags\n\nRaw Schema\n\n> #### Do not create or edit pages manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.Page.html#module-seo"},{"type":"function","title":"Beacon.Content.Page.version/0","doc":"Current data structure version.\n\nBump when schema changes.","ref":"Beacon.Content.Page.html#version/0"},{"type":"type","title":"Beacon.Content.Page.t/0","doc":"","ref":"Beacon.Content.Page.html#t:t/0"},{"type":"module","title":"Beacon.Content.PageEvent","doc":"Represents a point in time when a `Beacon.Content.Page` was created, published, or unpublished.\n\nAt that time, a `Beacon.Content.PageSnapshot` is created and stored with the PageEvent.\n\n> #### Do not create or edit page events manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.PageEvent.html"},{"type":"type","title":"Beacon.Content.PageEvent.event/0","doc":"The event name. Can be one of :created, :published, :unpublished","ref":"Beacon.Content.PageEvent.html#t:event/0"},{"type":"type","title":"Beacon.Content.PageEvent.t/0","doc":"","ref":"Beacon.Content.PageEvent.html#t:t/0"},{"type":"module","title":"Beacon.Content.PageSnapshot","doc":"Represents the template of a `Beacon.Content.Page` at a specific moment in time.\n\nPageSnapshots don't exist on their own, but are created as part of a `Beacon.Content.PageEvent`\nwhenever a Page is created, published, or unpublished.\n\n> #### Do not create or edit page snapshots manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.PageSnapshot.html"},{"type":"type","title":"Beacon.Content.PageSnapshot.t/0","doc":"","ref":"Beacon.Content.PageSnapshot.html#t:t/0"},{"type":"module","title":"Beacon.Content.PageVariant","doc":"Stores an alternate template which can be randomly rendered as a replacement for a Page's standard template.\n\nA PageVariant contains three main fields:\n\n  * `:name` - a brief description of what change(s) the variant template provides\n  * `:weight` - the percentage of page renders which should use this template (0 - 100)\n  * `:template` - the template which should be rendered whenever this variant is used\n\n> #### Do not create or edit page variants manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.PageVariant.html"},{"type":"type","title":"Beacon.Content.PageVariant.t/0","doc":"","ref":"Beacon.Content.PageVariant.html#t:t/0"},{"type":"module","title":"Beacon.Content.Snippets.Helper","doc":"Snippet Helpers are blocks of custom Elixir code which can be called from\nmeta tags and various other page fields.\n\nIn addition to being scoped by `:site`, it stores a `:name` with which to call it\nand a `:body` with the code block to run.\n\nSee `Beacon.Content.render_snippet/2` for an example of usage.\n\n> #### Do not create or edit snippet helpers manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.Snippets.Helper.html"},{"type":"type","title":"Beacon.Content.Snippets.Helper.t/0","doc":"","ref":"Beacon.Content.Snippets.Helper.html#t:t/0"},{"type":"module","title":"Beacon.Content.Stylesheet","doc":"Stores CSS content to use when rendering pages with Beacon.\n\n> #### Do not create or edit page snapshots manually {: .warning}\n>\n> Use the public functions in `Beacon.Content` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.Content.Stylesheet.html"},{"type":"type","title":"Beacon.Content.Stylesheet.t/0","doc":"","ref":"Beacon.Content.Stylesheet.html#t:t/0"},{"type":"module","title":"Beacon.Template","doc":"Template for layouts, pages, and any other resource that display HTML/HEEx.\n\nTemplates are defined as [Phoenix.LiveView.Rendered](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.Rendered.html) structs,\nwhich holds nested static literal strings and also dynamic content for the LiveView engine.\n\nTemplate engines that do not support dynamic content can make use of the `:static` field to store its contents.","ref":"Beacon.Template.html"},{"type":"type","title":"Beacon.Template.ast/0","doc":"The AST representation of a `t:Phoenix.LiveView.Rendered.t/0` struct.","ref":"Beacon.Template.html#t:ast/0"},{"type":"type","title":"Beacon.Template.t/0","doc":"","ref":"Beacon.Template.html#t:t/0"},{"type":"module","title":"Beacon.Template.HEEx","doc":"Handles loading and compilation of HEEx templates.","ref":"Beacon.Template.HEEx.html"},{"type":"function","title":"Beacon.Template.HEEx.compile/4","doc":"Compile `template` returning its AST.","ref":"Beacon.Template.HEEx.html#compile/4"},{"type":"function","title":"Beacon.Template.HEEx.compile!/4","doc":"","ref":"Beacon.Template.HEEx.html#compile!/4"},{"type":"function","title":"Beacon.Template.HEEx.render/3","doc":"Renders the HEEx `template` with `assigns`.\n\n> #### Use only to render isolated templates {: .warning}\n>\n> This function should not be used to render Page Templates,\n> its purpose is only to render isolated pieces of templates.","ref":"Beacon.Template.HEEx.html#render/3"},{"type":"function","title":"Example - Beacon.Template.HEEx.render/3","doc":"iex> Beacon.Template.HEEx.render(:my_site, ~S|<.link patch=\"/contact\" replace={true}><%= @text %></.link>|, %{text: \"Book Meeting\"})\n    \" Book Meeting \"","ref":"Beacon.Template.HEEx.html#render/3-example"},{"type":"module","title":"Beacon.Template.Markdown","doc":"GitHub Flavored Markdown\n\nUses https://github.com/leandrocp/mdex to convert Markdown to HTML","ref":"Beacon.Template.Markdown.html"},{"type":"function","title":"Beacon.Template.Markdown.convert_to_html/3","doc":"Convert a markdown `template` into HTML using [mdex](https://hex.pm/packages/mdex)","ref":"Beacon.Template.Markdown.html#convert_to_html/3"},{"type":"function","title":"Options - Beacon.Template.Markdown.convert_to_html/3","doc":"* `:syntax_highlight_theme` (default `\"onedark\"`) - see https://hexdocs.pm/mdex/MDEx.html#to_html/2 for more info.","ref":"Beacon.Template.Markdown.html#convert_to_html/3-options"},{"type":"module","title":"Beacon.MediaLibrary","doc":"Provides functions to upload and serve assets.","ref":"Beacon.MediaLibrary.html"},{"type":"function","title":"Beacon.MediaLibrary.change_asset/2","doc":"Returns an `%Ecto.Changeset{}` for tracking asset changes.","ref":"Beacon.MediaLibrary.html#change_asset/2"},{"type":"function","title":"Examples - Beacon.MediaLibrary.change_asset/2","doc":"iex> change_asset(asset)\n    %Ecto.Changeset{data: %Asset{}}","ref":"Beacon.MediaLibrary.html#change_asset/2-examples"},{"type":"function","title":"Beacon.MediaLibrary.change_derivation/2","doc":"Returns an `%Ecto.Changeset{}` for updating an Asset's `:usage_tag` and/or `:source_id`.","ref":"Beacon.MediaLibrary.html#change_derivation/2"},{"type":"function","title":"Examples - Beacon.MediaLibrary.change_derivation/2","doc":"iex> change_asset(asset)\n    %Ecto.Changeset{data: %Asset{}}","ref":"Beacon.MediaLibrary.html#change_derivation/2-examples"},{"type":"function","title":"Beacon.MediaLibrary.count_assets/2","doc":"Counts the total number of assets based on the amount of pages.","ref":"Beacon.MediaLibrary.html#count_assets/2"},{"type":"function","title":"Options - Beacon.MediaLibrary.count_assets/2","doc":"* `:query` - filter rows count by query. Defaults to `nil`, doesn't filter query.","ref":"Beacon.MediaLibrary.html#count_assets/2-options"},{"type":"function","title":"Beacon.MediaLibrary.get_asset_by/2","doc":"Gets a single asset by `clauses`.","ref":"Beacon.MediaLibrary.html#get_asset_by/2"},{"type":"function","title":"Examples - Beacon.MediaLibrary.get_asset_by/2","doc":"iex> get_asset_by(site, file_name: \"logo.webp\")\n    %Asset{}","ref":"Beacon.MediaLibrary.html#get_asset_by/2-examples"},{"type":"function","title":"Beacon.MediaLibrary.is_image?/1","doc":"Returns true if the given Asset is an image.\n\nAccepted filetypes are `.jpg .jpeg .png .gif .bmp .tif .tiff .webp`","ref":"Beacon.MediaLibrary.html#is_image?/1"},{"type":"function","title":"Beacon.MediaLibrary.list_assets/2","doc":"Returns the list of all uploaded assets of `site`.","ref":"Beacon.MediaLibrary.html#list_assets/2"},{"type":"function","title":"Options - Beacon.MediaLibrary.list_assets/2","doc":"* `:per_page` - limit how many records are returned, or pass `:infinity` to return all records. Defaults to 20.\n  * `:page` - returns records from a specfic page. Defaults to 1.\n  * `:query` - search assets by file name. Defaults to `nil`, doesn't filter query.\n  * `:preloads` - a list of preloads to load. Defaults to `[:thumbnail]`.\n  * `:sort` - column in which the result will be ordered by. Defaults to `:file_name`.\n    Allowed values: `:file_name`, `:media_type`, `:inserted_at`, `:updated_at`.","ref":"Beacon.MediaLibrary.html#list_assets/2-options"},{"type":"function","title":"Beacon.MediaLibrary.save_asset/1","doc":"This functions runs only the local persistence step of `upload/1`.","ref":"Beacon.MediaLibrary.html#save_asset/1"},{"type":"function","title":"Beacon.MediaLibrary.save_asset!/1","doc":"Same as `save_asset/1` but raises an error if unsuccessful.","ref":"Beacon.MediaLibrary.html#save_asset!/1"},{"type":"function","title":"Beacon.MediaLibrary.search/2","doc":"Search assets by file name.","ref":"Beacon.MediaLibrary.html#search/2"},{"type":"function","title":"Beacon.MediaLibrary.send_to_cdns/1","doc":"This functions runs only the external upload step of `upload/1`.","ref":"Beacon.MediaLibrary.html#send_to_cdns/1"},{"type":"function","title":"Beacon.MediaLibrary.soft_delete/1","doc":"Soft deletes a asset.","ref":"Beacon.MediaLibrary.html#soft_delete/1"},{"type":"function","title":"Examples - Beacon.MediaLibrary.soft_delete/1","doc":"iex> soft_delete(asset)\n    {:ok, %Asset{}}","ref":"Beacon.MediaLibrary.html#soft_delete/1-examples"},{"type":"function","title":"Beacon.MediaLibrary.srcset_for_image/2","doc":"For a given asset and list of acceptable usage tags, returns a [srcset](https://developer.mozilla.org/en-US/docs/Web/API/HTMLImageElement/srcset) for use in templates.","ref":"Beacon.MediaLibrary.html#srcset_for_image/2"},{"type":"function","title":"Beacon.MediaLibrary.upload/1","doc":"Uploads a given `UploadMetadata` and runs the `:upload_asset` lifecycle.\n\nRuns multiple steps:\n\n  * Upload to external service (see: `Beacon.MediaLibrary.Provider`)\n  * Persist the metadata to the local database\n  * Run the `:upload_asset` lifecycle (see: `t:Beacon.Config.lifecycle_stage/0`)","ref":"Beacon.MediaLibrary.html#upload/1"},{"type":"function","title":"Beacon.MediaLibrary.url_for/1","doc":"Returns a URL for a given asset.\n\nIf multiple URLs exist due to various providers, only the first will be returned.","ref":"Beacon.MediaLibrary.html#url_for/1"},{"type":"function","title":"Beacon.MediaLibrary.url_for/2","doc":"Uses the given `provider` to determine the URL for a given asset.","ref":"Beacon.MediaLibrary.html#url_for/2"},{"type":"function","title":"Beacon.MediaLibrary.urls_for/1","doc":"Returns a list of all URLs to the given Asset.\n\nThe number of URLs depends on how many providers are configured for the media type.","ref":"Beacon.MediaLibrary.html#urls_for/1"},{"type":"module","title":"Beacon.MediaLibrary.Asset","doc":"Assets are the images, videos, and any other media type uploaded and served by the Media Library.\n\n> #### Do not create or edit assets manually {: .warning}\n>\n> Use the public functions in `Beacon.MediaLibrary` instead.\n> The functions in that module guarantee that all dependencies\n> are created correctly and all processes are updated.\n> Manipulating data manually will most likely result\n> in inconsistent behavior and crashes.","ref":"Beacon.MediaLibrary.Asset.html"},{"type":"type","title":"Beacon.MediaLibrary.Asset.t/0","doc":"","ref":"Beacon.MediaLibrary.Asset.html#t:t/0"},{"type":"module","title":"Beacon.MediaLibrary.Provider","doc":"Connects to an external service to store and serve assets in the Media Library.\n\nBy default, Beacon comes with 2 providers:\n\n  * `Beacon.MediaLibrary.Provider.Repo` - Store assets in the database.\n  * `Beacon.MediaLibrary.Provider.S3` - Store assets in an S3 bucket.\n\n`Repo` is enabled by default for all media types since a database connection is already\navailable, and caching is used to reduce overload on the database. But you can switch to `S3`\nusing the `Beacon.MediaLibrary.Provider.S3` provider or create your own provider.\n\nSee `Beacon.Config` for more info.","ref":"Beacon.MediaLibrary.Provider.html"},{"type":"module","title":"Beacon.MediaLibrary.Provider.Repo","doc":"Store assets in the database.\n\nFiles are stored as binaries (BLOB)","ref":"Beacon.MediaLibrary.Provider.Repo.html"},{"type":"module","title":"Beacon.MediaLibrary.Provider.S3","doc":"Store assets in S3 using the `ex_aws` library.\n\nAll files are stored in the same bucket under the same level.","ref":"Beacon.MediaLibrary.Provider.S3.html"},{"type":"module","title":"Beacon.MediaLibrary.UploadMetadata","doc":"Metadata passed to page rendering lifecycle.","ref":"Beacon.MediaLibrary.UploadMetadata.html"},{"type":"type","title":"Beacon.MediaLibrary.UploadMetadata.t/0","doc":"","ref":"Beacon.MediaLibrary.UploadMetadata.html#t:t/0"},{"type":"behaviour","title":"Beacon.RuntimeCSS","doc":"Compiles the CSS for a site using the compiler defined in `t:Beacon.Config.css_compiler/0`\n\nBeacon supports Tailwind by default implemented by `Beacon.RuntimeCSS.TailwindCompiler`,\nyou can use that module as template to implement any ther CSS engine as needed.","ref":"Beacon.RuntimeCSS.html"},{"type":"function","title":"Beacon.RuntimeCSS.asset_url/1","doc":"Returns the URL to fetch the CSS config used to generate the site stylesheet.","ref":"Beacon.RuntimeCSS.html#asset_url/1"},{"type":"callback","title":"Beacon.RuntimeCSS.compile/1","doc":"Executes the compilation to generate the CSS for the site using the provided `:css_compiler` in `Beacon.Config`.","ref":"Beacon.RuntimeCSS.html#c:compile/1"},{"type":"callback","title":"Beacon.RuntimeCSS.config/1","doc":"Returns the CSS compiler config.\n\nFor Tailwind that would be the content of the tailwind config file,\nor return an empty string `\"\"` if the provided engine doesn't have a config file.","ref":"Beacon.RuntimeCSS.html#c:config/1"},{"type":"module","title":"Beacon.RuntimeCSS.TailwindCompiler","doc":"Tailwind compiler for runtime CSS, used on all sites.\n\nThe default configuration is fetched from `Path.join(Application.app_dir(:beacon, \"priv\"), \"tailwind.config.js\")`,\nyou can see the actual file at https://github.com/BeaconCMS/beacon/blob/main/priv/tailwind.config.js\n\nThat's the file used by default if no value is provided in the site configuration `t:Beacon.Config.tailwind_config/0`\n\nYou can use any of the [available options from Tailwind CSS](https://tailwindcss.com/docs/configuration) but\nyou must bundle the file if using Plugins or requiring any external module, see the [Tailwind Setup guide](https://hexdocs.pm/beacon/tailwind-setup.html)\nfor more info and examples.","ref":"Beacon.RuntimeCSS.TailwindCompiler.html"},{"type":"module","title":"Beacon.Web.BeaconAssigns","doc":"Read-only container of Beacon assigns related to the current page.\n\nAvailable as `@beacon`\n\nThis data can be accessed in page templates, event handlers, and other parts of your site\nto read information about the current page as the current site, path and query params,\npath and title.\n\nMore fields may be added in the future.","ref":"Beacon.Web.BeaconAssigns.html"},{"type":"module","title":"Examples - Beacon.Web.BeaconAssigns","doc":"In a template:\n\n     <%= @beacon.page.title %> \n\nIn a event handler:\n\n    pages = Beacon.Content.list_published_pages(@beacon.site)","ref":"Beacon.Web.BeaconAssigns.html#module-examples"},{"type":"type","title":"Beacon.Web.BeaconAssigns.t/0","doc":"","ref":"Beacon.Web.BeaconAssigns.html#t:t/0"},{"type":"module","title":"Beacon.Config","doc":"Configuration for sites.\n\nEach site is started with this configuration and its values are stored in a registry that can be fetched at runtime\nor updated with `update_value/3`.\n\nSee `new/1` for available options and examples.","ref":"Beacon.Config.html"},{"type":"function","title":"Beacon.Config.config_for_media_type/2","doc":"From a `Beacon.Config`, fetch the asset config for a given media type, raising when unsuccessful.","ref":"Beacon.Config.html#config_for_media_type/2"},{"type":"function","title":"Example - Beacon.Config.config_for_media_type/2","doc":"iex> beacon_config = Beacon.Config.fetch!(:some_site)\n    iex> jpeg_config = config_for_media_type(beacon_config, \"image/jpeg\")","ref":"Beacon.Config.html#config_for_media_type/2-example"},{"type":"function","title":"Beacon.Config.fetch!/1","doc":"Returns the `Beacon.Config` for `site`.","ref":"Beacon.Config.html#fetch!/1"},{"type":"function","title":"Beacon.Config.get_media_type_config/2","doc":"Searches a config option for the given media type.\n\nFor config options based on media type, such as `:assets` and `:extra_asset_fields`,\nthis function will check for the presence of `media_type`, returning the config for\nthat specific type, or `nil` if the type is not present.","ref":"Beacon.Config.html#get_media_type_config/2"},{"type":"function","title":"Examples - Beacon.Config.get_media_type_config/2","doc":"iex> beacon_config = Beacon.Config.fetch!(:some_site)\n    iex> jpeg_config = config_for_media_type(beacon_config.assets, \"image/jpeg\")\n\n    iex> beacon_config = Beacon.Config.fetch!(:some_site)\n    iex> webp_config = config_for_media_type(beacon_config.extra_asset_fields, \"image/webp\")\n\n    iex> beacon_config = Beacon.Config.fetch!(:some_site)\n    iex> nil = config_for_media_type(beacon_config.assets, \"invalid/foo\")","ref":"Beacon.Config.html#get_media_type_config/2-examples"},{"type":"function","title":"Beacon.Config.new/1","doc":"Build a new `%Beacon.Config{}` instance to hold the entire configuration for each site.","ref":"Beacon.Config.html#new/1"},{"type":"function","title":"Options - Beacon.Config.new/1","doc":"* `:site` - `t:Beacon.Types.Site.t/0` (required)\n\n  * `:endpoint` - `t:endpoint/0` (required)\n\n  * `:router` - `t:router/0` (required)\n\n  * `:repo` - `t:repo/0` (required)\n\n  * `:skip_boot?` - `t:skip_boot?/0` (optional). Defaults to `false`.\n\n  * `css_compiler` - `t:css_compiler/0` (optional). Defaults to `Beacon.RuntimeCSS.TailwindCompiler`.\n\n  * `:tailwind_config` - `t:tailwind_config/0` (optional). Defaults to `Path.join(Application.app_dir(:beacon, \"priv\"), \"tailwind.config.bundle.js\")`.\n\n  * `:live_socket_path` - `t:live_socket_path/0` (optional). Defaults to `\"/live\"`.\n\n  * `:safe_code_check` - `t:safe_code_check/0` (optional). Defaults to `false`.\n\n  * `:template_formats` - `t:template_formats/0` (optional).\n\n      Defaults to:\n\n            [\n              {:heex, \"HEEx (HTML)\"},\n              {:markdown, \"Markdown (GitHub Flavored version)\"}\n            ]\n\n  Note that the default config is merged with your config.\n\n  * `lifecycle` - `t:lifecycle/0` (optional).\n\n  Note that the default config is merged with your config.\n\n  * `:extra_page_fields` - `t:extra_page_fields/0` (optional). Defaults to `[]`.\n\n  * `:extra_asset_fields` - `t:extra_asset_fields/0` (optional). Defaults to `[]`.\n\n  * `:default_meta_tags` - `t:default_meta_tags/0` (optional). Defaults to `%{}`.","ref":"Beacon.Config.html#new/1-options"},{"type":"function","title":"Example - Beacon.Config.new/1","doc":"iex> Beacon.Config.new(\n      site: :my_site,\n      endpoint: MyAppWeb.Endpoint,\n      router: MyAppWeb.Router,\n      repo: MyApp.Repo,\n      tailwind_config: Path.join(Application.app_dir(:my_app, \"priv\"), \"tailwind.config.js\"),\n      template_formats: [\n        {:custom_format, \"My Custom Format\"}\n      ],\n      lifecycle: [\n        load_template: [\n          {:custom_format,\n           [\n             validate: fn template, _metadata -> MyEngine.validate(template) end\n           ]}\n        ],\n        render_template: [\n          {:custom_format,\n           [\n             assigns: fn %Phoenix.LiveView.Rendered{static: template} , %{assigns: assigns} -> MyEngine.parse_to_html(template, assigns) end\n           ]}\n        ],\n        after_publish_page: [\n          notify_admin: fn page -> {:cont, MyApp.Admin.send_email(page)} end\n        ]\n      ]\n    )\n    %Beacon.Config{\n      site: :my_site,\n      endpoint: MyAppWeb.Endpoint,\n      router: MyAppWeb.Router,\n      repo: MyApp.Repo,\n      skip_boot?: false,\n      css_compiler: Beacon.RuntimeCSS.TailwindCompiler,\n      tailwind_config: \"/my_app/priv/tailwind.config.js\",\n      live_socket_path: \"/live\",\n      safe_code_check: false,\n      template_formats: [\n        heex: \"HEEx (HTML)\",\n        markdown: \"Markdown (GitHub Flavored version)\",\n        custom_format: \"My Custom Format\"\n      ],\n      media_types: [\"image/jpeg\", \"image/gif\", \"image/png\", \"image/webp\"],\n      assets:[\n        {\"image/*\", [providers: [Beacon.MediaLibrary.Provider.Repo], validations: [&SomeModule.some_function/2]]},\n      ],\n      lifecycle: [\n        load_template: [\n          heex: [],\n          markdown: [\n            convert_to_html: &Beacon.Template.Markdown.convert_to_html/2,\n          ],\n          custom_format: [\n            validate: #Function<41.3316493/2 in :erl_eval.expr/6>\n          ]\n        ],\n        render_template: [\n          heex: [],\n          markdown: [],\n          custom_format: [\n            assigns: #Function<41.3316493/2 in :erl_eval.expr/6>\n          ]\n        ],\n        after_create_page: [],\n        after_update_page: [],\n        after_publish_page: [\n          notify_admin: #Function<42.3316493/1 in :erl_eval.expr/6>\n        ],\n        upload_asset: [],\n      ],\n      extra_page_fields: [],\n      extra_asset_fields: [],\n      default_meta_tags: []\n    }","ref":"Beacon.Config.html#new/1-example"},{"type":"function","title":"Beacon.Config.update_value/3","doc":"Updates `key` with `value` for the `site` configuration, at runtime.","ref":"Beacon.Config.html#update_value/3"},{"type":"type","title":"Beacon.Config.allowed_media_accept_types/0","doc":"Register specific media types allowed for upload. Catchalls are not allowed.","ref":"Beacon.Config.html#t:allowed_media_accept_types/0"},{"type":"type","title":"Beacon.Config.css_compiler/0","doc":"A module that implements `Beacon.RuntimeCSS`.","ref":"Beacon.Config.html#t:css_compiler/0"},{"type":"type","title":"Beacon.Config.default_meta_tags/0","doc":"Default meta tags added to new pages.","ref":"Beacon.Config.html#t:default_meta_tags/0"},{"type":"type","title":"Beacon.Config.endpoint/0","doc":"Host application Endpoint module.","ref":"Beacon.Config.html#t:endpoint/0"},{"type":"type","title":"Beacon.Config.extra_asset_field/0","doc":"Add extra fields to pages.","ref":"Beacon.Config.html#t:extra_asset_field/0"},{"type":"type","title":"Beacon.Config.extra_asset_fields/0","doc":"Add extra fields to pages.","ref":"Beacon.Config.html#t:extra_asset_fields/0"},{"type":"type","title":"Beacon.Config.extra_page_fields/0","doc":"Add extra fields to pages.","ref":"Beacon.Config.html#t:extra_page_fields/0"},{"type":"type","title":"Beacon.Config.lifecycle/0","doc":"Attach steps into Beacon's internal life-cycle stages to inject custom functionality.","ref":"Beacon.Config.html#t:lifecycle/0"},{"type":"type","title":"Beacon.Config.lifecycle_stage/0","doc":"Life-cycle stages.","ref":"Beacon.Config.html#t:lifecycle_stage/0"},{"type":"type","title":"Beacon.Config.live_socket_path/0","doc":"Path of a LiveView socket where Beacon should connect to.","ref":"Beacon.Config.html#t:live_socket_path/0"},{"type":"type","title":"Beacon.Config.media_type_config/0","doc":"Individual media type configs","ref":"Beacon.Config.html#t:media_type_config/0"},{"type":"type","title":"Beacon.Config.media_type_configs/0","doc":"Register providers and validations for media types. Catchalls are allowed.","ref":"Beacon.Config.html#t:media_type_configs/0"},{"type":"type","title":"Beacon.Config.option/0","doc":"","ref":"Beacon.Config.html#t:option/0"},{"type":"type","title":"Beacon.Config.repo/0","doc":"Host application Repo module.","ref":"Beacon.Config.html#t:repo/0"},{"type":"type","title":"Beacon.Config.router/0","doc":"Host application Router module.","ref":"Beacon.Config.html#t:router/0"},{"type":"type","title":"Beacon.Config.safe_code_check/0","doc":"Check safety of Elixir code using https://github.com/TheFirstAvenger/safe_code","ref":"Beacon.Config.html#t:safe_code_check/0"},{"type":"type","title":"Beacon.Config.skip_boot?/0","doc":"Disables site booting.\n\nDisables inserting default content data and routes, loading modules, and broadcasting events that trigger actions in Beacon lifecycle.\n\nSee `Beacon.boot/1` for more info.","ref":"Beacon.Config.html#t:skip_boot?/0"},{"type":"type","title":"Beacon.Config.t/0","doc":"","ref":"Beacon.Config.html#t:t/0"},{"type":"type","title":"Beacon.Config.tailwind_config/0","doc":"Path to a custom tailwind config.","ref":"Beacon.Config.html#t:tailwind_config/0"},{"type":"type","title":"Example - Beacon.Config.tailwind_config/0","doc":"# use the config file `priv/tailwind.config.js` in your app named `my_app`\n    Path.join(Application.app_dir(:my_app, \"priv\"), \"tailwind.config.js\")\n\nSee `Beacon.RuntimeCSS.TailwindCompiler` for more info.","ref":"Beacon.Config.html#t:tailwind_config/0-example"},{"type":"type","title":"Beacon.Config.template_formats/0","doc":"Register formats to handle templates, eg: `[{:heex, \"HEEx (HTML)\"}]`.\n\nBeacon provides two formats built-in, HEEx and Markdown, but you can register your own\nas long as you also implement the life-cycle stages `:load_template` and `:render_template`.\n\nThe description is used on user interfaces as Beacon Admin.","ref":"Beacon.Config.html#t:template_formats/0"},{"type":"behaviour","title":"Beacon.Content.PageField","doc":"Custom page fields for pages.\n\nEach `Beacon.Content.Page` have a default set of fields that\nfits most cases for building pages for your sites,\nbut in some cases you need custom data to either help manage\nthose page in Beacon Admin or to display such data.\n\nFor example, you can add a field to store each blog post illustration,\nor a field to include tags, and so on.\n\nEach page field will be:\n\n  * stored in the `page.extra` map field\n  * displayed in Beacon LiveAdmin\n  * validated when the pages is saved or published","ref":"Beacon.Content.PageField.html"},{"type":"behaviour","title":"Example - Beacon.Content.PageField","doc":"defmodule MyApp.TagsField do\n      use Phoenix.Component\n      import Beacon.Web.CoreComponents\n      import Ecto.Changeset\n\n      @behaviour Beacon.Content.PageField\n\n      @impl true\n      def name, do: :tags\n\n      @impl true\n      def type, do: :string\n\n      @impl true\n      def render(assigns) do\n        ~H\"\"\"\n        <.input type=\"text\" label=\"Tags\" field={@field} />\n        \"\"\"\n      end\n\n      @impl true\n      def changeset(data, attrs, _metadata) do\n        data\n        |> cast(attrs, [:tags])\n        |> validate_required([:tags])\n      end\n    end","ref":"Beacon.Content.PageField.html#module-example"},{"type":"callback","title":"Beacon.Content.PageField.changeset/3","doc":"Changeset used to validate and save data.","ref":"Beacon.Content.PageField.html#c:changeset/3"},{"type":"callback","title":"Beacon.Content.PageField.default/0","doc":"Default value for field. Defaults to `nil`.","ref":"Beacon.Content.PageField.html#c:default/0"},{"type":"callback","title":"Beacon.Content.PageField.name/0","doc":"Field identifier. Must be unique per site.","ref":"Beacon.Content.PageField.html#c:name/0"},{"type":"callback","title":"Beacon.Content.PageField.render/1","doc":"Template to render the field on LiveAdmin.","ref":"Beacon.Content.PageField.html#c:render/1"},{"type":"function","title":"Beacon.Content.PageField.render_field/3","doc":"","ref":"Beacon.Content.PageField.html#render_field/3"},{"type":"callback","title":"Beacon.Content.PageField.type/0","doc":"Field type. Can be any value supported by Ecto Schema.","ref":"Beacon.Content.PageField.html#c:type/0"},{"type":"behaviour","title":"Beacon.Lifecycle","doc":"Beacon is open for extensibility by allowing users to inject custom steps into its internal lifecycle.\n\nYou can add or overwrite those steps in `t:Beacon.Config.lifecycle/0`.\n\nEach one of these functions will be called in specific places inside Beacon's lifecycle,\nexecuting the steps defined in the site config.\n\nSee each function doc for more info and also `Beacon.Config`.","ref":"Beacon.Lifecycle.html"},{"type":"function","title":"Beacon.Lifecycle.execute/5","doc":"Initializes a `Beacon.Lifecycle` with given `lifecycle_name` and `resource`, runs all steps\nfor each lifecycle stage, and returns the Lifecycle with result stored in its `:output` key.\n\nExpects a `provider` which implements callbacks for validation before and after execution,\nas well as the logic for parsing contextual metadata.","ref":"Beacon.Lifecycle.html#execute/5"},{"type":"function","title":"Options - Beacon.Lifecycle.execute/5","doc":"* `:sub_key` - The name of a specific lifecycle stage to execute.  If provided, all other stages\n    will be skipped.  Defaults to `nil`, which runs all stages.\n  * `context` - Metadata to insert into the Lifecycle for use during execution.  Defaults to `nil`.","ref":"Beacon.Lifecycle.html#execute/5-options"},{"type":"function","title":"Beacon.Lifecycle.execute_steps/1","doc":"Runs all steps in a given Lifecycle.","ref":"Beacon.Lifecycle.html#execute_steps/1"},{"type":"callback","title":"Beacon.Lifecycle.put_metadata/3","doc":"Logic to put metadata from a given context into a `Beacon.Lifecycle`.  The `Beacon.Config` will\nalso be available here if needed.","ref":"Beacon.Lifecycle.html#c:put_metadata/3"},{"type":"function","title":"Beacon.Lifecycle.put_metadata/4","doc":"This function delegates to the `put_metadata/3` callback implemented by the `provider` module.\n\nIf the callback is not implemented, this will be a no-op.","ref":"Beacon.Lifecycle.html#put_metadata/4"},{"type":"function","title":"Beacon.Lifecycle.put_steps/3","doc":"Fetches the steps for a given Lifecycle from the provided `Beacon.Config` and puts those\nsteps into the Lifecycle.\n\nA `sub_key` may be provided to only consider the steps for a single lifecycle stage","ref":"Beacon.Lifecycle.html#put_steps/3"},{"type":"callback","title":"Beacon.Lifecycle.validate_input!/3","doc":"Logic to validate that a given `Beacon.Lifecycle` was initialized properly, according to the given\n`Beacon.Config`.  A sub-key may be provided if only one lifecycle stage is to be validated, otherwise\n`nil` is expected for the third argument.","ref":"Beacon.Lifecycle.html#c:validate_input!/3"},{"type":"function","title":"Beacon.Lifecycle.validate_input!/4","doc":"This function delegates to the `validate_input!/3` callback implemented by the `provider` module.\n\nIf the callback is not implemented, this will be a no-op.","ref":"Beacon.Lifecycle.html#validate_input!/4"},{"type":"callback","title":"Beacon.Lifecycle.validate_output!/3","doc":"After executing all the steps of a `Beacon.Lifecycle`, it is passed here to validate that the output\nis as-expected.  The `Beacon.Config` will also be available here if needed.","ref":"Beacon.Lifecycle.html#c:validate_output!/3"},{"type":"function","title":"Beacon.Lifecycle.validate_output!/4","doc":"This function delegates to the `validate_output!/3` callback implemented by the `provider` module.\n\nIf the callback is not implemented, this will be a no-op.","ref":"Beacon.Lifecycle.html#validate_output!/4"},{"type":"type","title":"Beacon.Lifecycle.t/0","doc":"","ref":"Beacon.Lifecycle.html#t:t/0"},{"type":"behaviour","title":"Beacon.MediaLibrary.AssetField","doc":"Custom asset fields for assets.\n\nEach `Beacon.MediaLibrary.Asset` has a default set of fields that\nfits most cases for assets for your sites,\nbut in some cases you need custom data to either help manage\nthose assets in Beacon Admin or to display such data.\n\nEach asset field will be:\n\n  * stored in the `asset.extra` map field\n  * displayed in Beacon Admin\n  * validated when the assets are saved or published","ref":"Beacon.MediaLibrary.AssetField.html"},{"type":"behaviour","title":"Example - Beacon.MediaLibrary.AssetField","doc":"defmodule MyApp.AltTextField do\n      use Phoenix.Component\n      import Beacon.Web.CoreComponents\n      import Ecto.Changeset\n\n      @behaviour Beacon.MediaLibrary.AssetField\n\n      @impl true\n      def name, do: :alt\n\n      @impl true\n      def type, do: :string\n\n      @impl true\n      def render_input(assigns) do\n        ~H\"\"\"\n        <.input type=\"text\" label=\"Alt Text\" field={@field} />\n        \"\"\"\n      end\n\n      @impl true\n      def render_show(assigns) do\n        ~H\"\"\"\n        <.input type=\"text\" label=\"Alt Text\" value={@value} />\n        \"\"\"\n      end\n\n      @impl true\n      def changeset(data, attrs) do\n        data\n        |> cast(attrs, [:alt])\n        |> validate_required([:alt])\n      end\n    end","ref":"Beacon.MediaLibrary.AssetField.html#module-example"},{"type":"callback","title":"Beacon.MediaLibrary.AssetField.changeset/3","doc":"Changeset used to validate and save data.","ref":"Beacon.MediaLibrary.AssetField.html#c:changeset/3"},{"type":"callback","title":"Beacon.MediaLibrary.AssetField.default/0","doc":"Default value for field. Defaults to `nil`.","ref":"Beacon.MediaLibrary.AssetField.html#c:default/0"},{"type":"callback","title":"Beacon.MediaLibrary.AssetField.name/0","doc":"Field identifier. Must be unique per site.","ref":"Beacon.MediaLibrary.AssetField.html#c:name/0"},{"type":"callback","title":"Beacon.MediaLibrary.AssetField.render_input/1","doc":"Template to render the form field on Admin.","ref":"Beacon.MediaLibrary.AssetField.html#c:render_input/1"},{"type":"callback","title":"Beacon.MediaLibrary.AssetField.render_show/1","doc":"Template to render the show field on Admin.","ref":"Beacon.MediaLibrary.AssetField.html#c:render_show/1"},{"type":"callback","title":"Beacon.MediaLibrary.AssetField.type/0","doc":"Field type. Can be any value supported by Ecto Schema.","ref":"Beacon.MediaLibrary.AssetField.html#c:type/0"},{"type":"module","title":"Beacon.Template.LoadMetadata","doc":"Metadata passed to page loading lifecycle.","ref":"Beacon.Template.LoadMetadata.html"},{"type":"type","title":"Beacon.Template.LoadMetadata.t/0","doc":"","ref":"Beacon.Template.LoadMetadata.html#t:t/0"},{"type":"module","title":"Beacon.Template.RenderMetadata","doc":"Metadata passed to page rendering lifecycle.","ref":"Beacon.Template.RenderMetadata.html"},{"type":"type","title":"Beacon.Template.RenderMetadata.t/0","doc":"","ref":"Beacon.Template.RenderMetadata.html#t:t/0"},{"type":"module","title":"Beacon.Types.JsonArrayMap","doc":"Convert between json and map enforcing the data shape as array of objects/maps.","ref":"Beacon.Types.JsonArrayMap.html"},{"type":"function","title":"Beacon.Types.JsonArrayMap.embed_as/1","doc":"","ref":"Beacon.Types.JsonArrayMap.html#embed_as/1"},{"type":"function","title":"Beacon.Types.JsonArrayMap.equal?/2","doc":"","ref":"Beacon.Types.JsonArrayMap.html#equal?/2"},{"type":"type","title":"Beacon.Types.JsonArrayMap.t/0","doc":"List of maps","ref":"Beacon.Types.JsonArrayMap.html#t:t/0"},{"type":"module","title":"Beacon.Types.Site","doc":"Sites are identified as atoms and stored as string in the database.","ref":"Beacon.Types.Site.html"},{"type":"function","title":"Beacon.Types.Site.embed_as/1","doc":"","ref":"Beacon.Types.Site.html#embed_as/1"},{"type":"function","title":"Beacon.Types.Site.equal?/2","doc":"","ref":"Beacon.Types.Site.html#equal?/2"},{"type":"function","title":"Beacon.Types.Site.valid?/1","doc":"Returns `true` if `site` is valid, otherwise returns `false`.\n\nA site is valid if it's a atom with no special characters, except `_`.","ref":"Beacon.Types.Site.html#valid?/1"},{"type":"function","title":"Examples - Beacon.Types.Site.valid?/1","doc":"iex> valid?(:my_site)\n    true\n\n    iex> valid?(:\"my-site!\")\n    false","ref":"Beacon.Types.Site.html#valid?/1-examples"},{"type":"function","title":"Beacon.Types.Site.valid_name?/1","doc":"","ref":"Beacon.Types.Site.html#valid_name?/1"},{"type":"function","title":"Beacon.Types.Site.valid_path?/1","doc":"","ref":"Beacon.Types.Site.html#valid_path?/1"},{"type":"type","title":"Beacon.Types.Site.t/0","doc":"Atom to identify a site, eg: `:my_site`","ref":"Beacon.Types.Site.html#t:t/0"},{"type":"exception","title":"Beacon.ConfigError","doc":"Raised when some option in `Beacon.Config` is invalid.\n\nIf you are seeing this error, check `application.ex` where your site's config is defined.\nDescription and examples of each allowed configuration option can be found in `Beacon.Config.new/1`","ref":"Beacon.ConfigError.html"},{"type":"exception","title":"Beacon.LoaderError","doc":"Raised when Beacon attempts to load content into memory unsuccessfully.\n\nThere are several causes that can lead to this error, so if you're seeing it, be sure to read the\nfull error message for any additional information or steps to take.  If a LoaderError is crashing\nyour app on startup, it could indicate a problem in your `Beacon.Config`","ref":"Beacon.LoaderError.html"},{"type":"exception","title":"Beacon.ParserError","doc":"Raised when Beacon's Markdown engine attempts to convert Markdown to HTML unsuccessfully.\n\nThis error can be triggered by layouts, pages, and any other resource that display HTML.\nIf you're seeing it, ensure that your template formats are correct. The full error message\nwill have details on where to look.","ref":"Beacon.ParserError.html"},{"type":"exception","title":"Beacon.RuntimeError","doc":"Raised when Beacon attempts to read content from memory unsuccessfully.\n\nIf you see this error consistently, check the message to see if `handle_event` is mentioned.\nIf so, this can indicate that pages on your site are sending events (e.g. button clicks,\nform submissions) to an event handler which hasn't been implemented, or that the event name\ndoes not match your handler.","ref":"Beacon.RuntimeError.html"},{"type":"exception","title":"Beacon.SnippetError","doc":"Raised when Beacon attempts to render a `Beacon.Content.Snippets.Helper` unsuccessfully.\n\nIf you're seeing this error, check for typos in your helpers' `:body`.","ref":"Beacon.SnippetError.html"},{"type":"type","title":"Beacon.SnippetError.t/0","doc":"","ref":"Beacon.SnippetError.html#t:t/0"},{"type":"exception","title":"Beacon.Web.NotFoundError","doc":"Raised when Beacon attempts to serve a page or asset on an invalid path.\n\nIf you're seeing this error, it means some of your users are using the wrong URL.\nTo some extent, this is unavoidable, but consistently seeing this error with the same path\ncan indicate that somewhere in your page content, you are creating invalid links.","ref":"Beacon.Web.NotFoundError.html"},{"type":"exception","title":"Beacon.Web.ServerError","doc":"Raised when a `Beacon.Content.EventHandler` returns an invalid response.\n\nIf you're seeing this error, check the code in your site's event handlers, and\nensure that each one returns `{:noreply, socket}`.","ref":"Beacon.Web.ServerError.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.1.0-rc.2 (2024-09-20) - Changelog","doc":"","ref":"changelog.html#0-1-0-rc-2-2024-09-20"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* Renamed component `.icon` to `.heroicon` to make it explicit that it's rendering Heroicons and also to avoid future conflicts\n  * Require minimum Gettext v0.26 to use the new backend module\n  * Default `:sort` option value in `Content.list_pages/2` changed from `:title` to `:path`","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Fixes - Changelog","doc":"* [Components] Bring back the `.icon` (heroicon) component using https://hex.pm/packages/heroicons instead of Tailwind config that depends on the fs module that's not available\n  * [Media Library] Guard against invalid values for `:sort` option in `MediaLibrary.list_assets/2`\n  * [Content] Guard against invalid values for `:sort` option in `Content.list_layouts/2`\n  * [Content] Guard against invalid values for `:sort` option in `Content.list_pages/2`\n  * [HEEx Decoder] Handle attr values with `nil` values, for example the `defer` in script tags","ref":"changelog.html#fixes"},{"type":"extras","title":"Documentation - Changelog","doc":"* Updated Heroicons recipes to reflect changes on configuration and naming","ref":"changelog.html#documentation"},{"type":"extras","title":"0.1.0-rc.1 (2024-08-27) - Changelog","doc":"","ref":"changelog.html#0-1-0-rc-1-2024-08-27"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added Shared Event Handlers which are global event handlers shared among all pages.\n    That's a simple model to work with where a layout, component, or multiple pages may share the same event handler,\n    for example a newsletter subscription form in a component called in a layout doesn't need to duplicate the same\n    event handler in all pages.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* Removed Page Event Handlers in favor of Shared Event Handlers.\n    With Shared Event Handlers, it doesn't make sense to have page event handlers unless overriding becomes a neccessity.\n    The data is automatically migrated in a best-effort way, duplicated event handler names (from multiple pages) are\n    consolidated into a single shared event handler. See the migration `V002` for more info.\n  * Removed \"page event handlers\" in `Content` API in favor of \"event handlers\" (removed the prefix `page`),\n    for example: `update_event_handler_for_page -> create_event_handler` and `change_page_event_handler -> change_event_handler`.","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Fixes - Changelog","doc":"* Display parsed page title on live renders","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.0-rc.0 (2024-08-02) - Changelog","doc":"","ref":"changelog.html#0-1-0-rc-0-2024-08-02"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Loader to fetch resources from DB and compile modules\n  * Media Library to upload and serve images and other media\n    * Built-in Repo (DB) and S3 storage\n    * Post-process images to optimized .webp format\n  * Error Page to handle failures and display custom pages\n    * Pre-defined 404 and 500 pages\n  * Components\n    * Pre-defined set of default components\n    * Support attrs and slots\n    * Support for Elixir and HEEx parts\n  * Layouts\n    * Pre-defined default layout\n    * Meta tags\n    * Resource links\n    * Revisions\n  * Pages\n    * Pre-defined default home page\n    * Meta tags\n    * Schema.org support\n    * Events (handle_event)\n    * Revisions\n  * Snippets (liquid template)\n    * Page title\n    * Meta tags\n  * Stylesheets\n  * Live Data to define and manage assigns at runtime\n    * Support Elixir and text content\n  * Custom Page fields to extend the Page schema\n  * Router helper `~p` to generate paths with site prefixes\n  * Content management through the `Beacon.Content` API\n  * A/B Variants\n  * TailwindCSS compiler\n  * `@beacon` read-only assign\n  * mix task `beacon.install` to bootstrap a new Beacon site\n  * Lifecycle hooks to inject custom logic into multiple layers of the process","ref":"changelog.html#enhancements"},{"type":"extras","title":"Installation","doc":"# Installation","ref":"installation.html"},{"type":"extras","title":"Objective - Installation","doc":"Install Beacon and Beacon LiveAdmin in a new Phoenix LiveView application to enable running and managing sites.","ref":"installation.html#objective"},{"type":"extras","title":"Notes - Installation","doc":"- If you already have a Phoenix LiveView application that meets the minimum requirements for Beacon and Beacon LiveAdmin, you can skip to step 6.\n- Beacon LiveAdmin can be installed in a separated application in a cluster environment but such advanced setup is not covered in this guide.","ref":"installation.html#notes"},{"type":"extras","title":"Steps - Installation","doc":"1. Install Elixir v1.13 or later\n\nCheck out the official [Elixir install guide](https://elixir-lang.org/install.html) for more info.\n\n2. Update Hex\n\n  ```sh\n  mix local.hex\n  ```\n\nIf that command fails or Elixir version is outdated, please follow the [Elixir Install guide](https://elixir-lang.org/install.html) to set up your environment correctly.\n\n3. Install Phoenix v1.7 or later\n\n  ```sh\n  mix archive.install hex phx_new\n  ```\n\nCheck out the official [Phoenix install guide](https://hexdocs.pm/phoenix/installation.html) for more info.\n\n4. Setup a PostgreSQL database\n\nWe recommend using PostgreSQL that's officially supported, make sure it's [installed and running](https://wiki.postgresql.org/wiki/Detailed_installation_guides).\n\n5. Generate a new Phoenix application\n\n  ```sh\n  mix phx.new --install my_app\n  ```\n\nNote that Beacon supports Umbrella applications as well.\n\n6. Change the existing `:floki` dependency to make it available in all environments\n\n  ```diff\n  - {:floki, \">= 0.30.0\", only: :test},\n  + {:floki, \">= 0.30.0\"},\n  ```\n\n7. Add `:beacon` and `:beacon_live_admin` dependencies to `mix.exs`\n\n  ```diff\n  + {:beacon, \"~> 0.1.0-rc.2\", override: true},\n  + {:beacon_live_admin, \"~> 0.1.0\"},\n  ```\n\n8. Add `:beacon` and `:beacon_live_admin` into `:import_deps` in file `.formatter.exs`\n\n  ```diff\n  - import_deps: [:ecto, :ecto_sql, :phoenix],\n  + import_deps: [:ecto, :ecto_sql, :phoenix, :beacon, :beacon_live_admin],\n  ```\n\n9. Install deps\n\n  ```sh\n  mix deps.get\n  ```","ref":"installation.html#steps"},{"type":"extras","title":"Next Steps - Installation","doc":"Beacon is installed but you have no sites yet. Follow the [Your First Site](your-first-site.md) guide to setup one and get familiar with Beacon.","ref":"installation.html#next-steps"},{"type":"extras","title":"Tailwind Setup","doc":"# Tailwind Setup\n\nBeacon has built-in TailwindCSS support, any page can use its classes out of the box and a stylesheet will be automatically generated and served.\n\nA default and simple configuration that works with Phoenix and Beacon is already bundled in the Beacon package, so you can skip this guide if that suits your needs.\n\nOtherwise, keep reading to learn how to set up a custom configuration with more advanced features.\n\n**Note** that the Tailwind configuration must respect some constraints to work properly with Beacon,\nso if you want to reuse an existing configuration, make sure to follow the steps below and make the necessary adjustments.","ref":"tailwind-setup.html"},{"type":"extras","title":"Objective - Tailwind Setup","doc":"Make sure the proper Tailwind version is installed, create a valid Tailwind config in the ESM format, and if you intend to use plugins, then bundle everything together in a single module.","ref":"tailwind-setup.html#objective"},{"type":"extras","title":"Constraints - Tailwind Setup","doc":"Since Beacon uses the same configuration to generate stylesheets for your sites and also to preview pages on the Visual Editor in the browser,\nthat configuration must respect some constraints to work properly in both environments:\n\n  - Use the ESM format\n  - Can't call node APIs\n\nIn the steps below you'll learn how to make the neccessary adjustments.","ref":"tailwind-setup.html#constraints"},{"type":"extras","title":"Steps - Tailwind Setup","doc":"* Install Tailwind v3.3.0 or higher\n* Install Esbuild\n* ESM format\n* Remove node APIs\n* Heroicons\n* Install plugins\n* Bundle the config\n* Use the config in your site configuration\n\nLet's go through each one to set up Tailwind properly for your sites.","ref":"tailwind-setup.html#steps"},{"type":"extras","title":"Tailwind v3.3.0 or higher - Tailwind Setup","doc":"Any recent Phoenix application should have the [tailwind](https://hex.pm/packages/tailwind) library already installed and updated but let's double check by executing:\n\n```sh\nmix run -e \"IO.inspect Tailwind.bin_version()\"\n```\n\nIf it fails or the version is lower than 3.3.0 then follow the [tailwind install guide](https://github.com/phoenixframework/tailwind?tab=readme-ov-file#installation)\nto get it installed or updated. It's important to install a recent Tailwind version higher than 3.3.0","ref":"tailwind-setup.html#tailwind-v3-3-0-or-higher"},{"type":"extras","title":"Esbuild - Tailwind Setup","doc":"Similar to Tailwind, any recent Phoenix application should have it installed already but let's check by executing:\n\n```sh\nmix run -e \"IO.inspect Esbuild.bin_version()\"\n```\n\nIf it fails then follow the [esbuild install guide](https://github.com/phoenixframework/esbuild?tab=readme-ov-file#installation) to get it installed.\nAny recent version that is installed should work just fine.","ref":"tailwind-setup.html#esbuild"},{"type":"extras","title":"ESM format - Tailwind Setup","doc":"Beacon expects a config file in the ESM format, ie: one that has `default export` instead of `module.exports`.\n\nMost likely the existing config `assets/tailwind.config.js` was created in the CommonJS format, so given a file like this:\n\n```js\nmodule.exports = {\n  theme: {\n    colors: {\n      'blue': '#1fb6ff'\n    }\n  }\n}\n```\n\nReplace how the module is exported to have a valid ESM config:\n\n```js\nexport default {\n  theme: {\n    colors: {\n      'blue': '#1fb6ff'\n    }\n  }\n}\n```\n\nMore info at https://tailwindcss.com/blog/tailwindcss-v3-3#esm-and-type-script-support","ref":"tailwind-setup.html#esm-format"},{"type":"extras","title":"Remove node APIs - Tailwind Setup","doc":"The default `tailwind.config.js` created by the Phoenix installer will require the `fs` and `path` modules to load Heroicons in your application,\nthe problem is that those modules are not available in the browser, so we can't use them.\n\nYou have 2 options. Either remove those requires and the code using that module if you're not using Heroicons or not planning to use them,\nor the other option is to create a new config file target to Beacon pages only, that doesn't include those requires.\n\nSee the Heroicons sections below for more information regarding loading icons for Beacon pages.","ref":"tailwind-setup.html#remove-node-apis"},{"type":"extras","title":"Heroicons - Tailwind Setup","doc":"Heroicons are bundled by default in the `.heroicon` component, see the [Heroicons guide](../recipes/heroicons.md) for more information.","ref":"tailwind-setup.html#heroicons"},{"type":"extras","title":"Install plugins - Tailwind Setup","doc":"The default config generated by Phoenix requires the `@tailwindcss/froms` plugin so we need to install it first. Execute in the root of your project:\n\n```sh\nnpm install --prefix assets --include=dev @tailwindcss/forms\n```","ref":"tailwind-setup.html#install-plugins"},{"type":"extras","title":"Bundled config - Tailwind Setup","doc":"We'll change 3 files to make it work:\n\n1. `config/config.exs`\n\nOpen the file `config/config.exs`, find the `:esbuild` config, and add a new `tailwind_bundle` that will look like this:\n\n```elixir\nconfig :esbuild,\n  version: \"0.23.0\",\n  my_app: [\n    # omitted for brevity\n  ],\n  # add this block\n  tailwind_bundle: [\n    args: ~w(tailwind.config.js --bundle --platform=node --format=esm --target=es2020 --outfile=../priv/tailwind.config.bundle.js),\n    cd: Path.expand(\"../assets\", __DIR__),\n    env: %{\"NODE_PATH\" => Path.expand(\"../deps\", __DIR__)}\n  ]\n```\n\n2. `config/dev.exs`\n\nOpen the file `config/dev.exs`, find the `:watchers` key in the endpoint config, and add a new `tailwind_bundle` that will look like this:\n\n```elixir\nconfig :my_app, MyAppWeb.Endpoint,\n  # omitted for brevity\n  watchers: [\n    esbuild: {Esbuild, :install_and_run, [:my_app, ~w(--sourcemap=inline --watch)]},\n    esbuild: {Esbuild, :install_and_run, [:tailwind_bundle, ~w(--watch)]}, # add this line\n    tailwind: {Tailwind, :install_and_run, [:my_app, ~w(--watch)]}\n  ]\n```\n\n3. `mix.exs`\n\nIn the list of aliases, add the following command in both `\"assets.build\"` and `\"assets.deploy\"`:\n\n```elixir\n\"esbuild tailwind_bundle\"\n```\n\nIt will look like this:\n\n```elixir\ndefp aliases do\n  [\n    # omitted for brevity\n    \"assets.build\": [\"tailwind my_app\", \"esbuild my_app\", \"esbuild tailwind_bundle\"],\n    \"assets.deploy\": [\n      \"tailwind my_app --minify\",\n      \"esbuild my_app --minify\",\n      \"esbuild tailwind_bundle\",\n      \"phx.digest\"\n    ]\n  ]\nend\n```","ref":"tailwind-setup.html#bundled-config"},{"type":"extras","title":"Site Configuration - Tailwind Setup","doc":"**Note** that if you're setting up the environment for the first time and have no site created yet, for example if you're following the \"Your first site\" or the \"Create a blog\" guide,\nyou won't have any site configuration to update. In this case, you can skip this step and come back to it later after executing the `beacon.install` command.\n\nOpen the file `lib/my_app/application.ex` (replace my_app with your actual application name), find the configuration of the site you'll be using\nthis Tailwind config and add the `tailwind_config` key pointing to the bundled file:\n\n```elixir\ntailwind_config: Path.join(Application.app_dir(:my_app, \"priv\"), \"tailwind.config.bundle.js\"),\n```\n\nIt will look somewhat like this:\n\n```elixir\n@impl true\ndef start(_type, _args) do\n  children = [\n    # omitted for brevity\n    {Beacon,\n     sites: [\n       [\n         site: :my_site,\n         repo: MyApp.Repo,\n         endpoint: MyAppWeb.Endpoint,\n         router: MyAppWeb.Router,\n         tailwind_config: Path.join(Application.app_dir(:my_app, \"priv\"), \"tailwind.config.bundle.js\") # add this line\n       ]\n     ]},\n    MyAppWeb.Endpoint\n  ]\n\n  # omitted for brevity\nend\n```\n\n**Remember** to replace _my_app_ with the actual name of your application.","ref":"tailwind-setup.html#site-configuration"},{"type":"extras","title":"Your First Site","doc":"# Your First Site","ref":"your-first-site.html"},{"type":"extras","title":"Objective - Your First Site","doc":"Create your first site to get familiar with the install command and the most common operations to manage your site.","ref":"your-first-site.html#objective"},{"type":"extras","title":"Prerequisites - Your First Site","doc":"In order to create and serve sites, you'll need a Phoenix LiveView application with both Beacon and Beacon LiveAdmin installed.\n\nFollow the [Beacon installation guide](installation.md) to set up the environment before proceeding with this guide.","ref":"your-first-site.html#prerequisites"},{"type":"extras","title":"Setup the database schema - Your First Site","doc":"Site data is stored in the database so we need to create the necessary tables first. Let's use a Ecto migration to perform this task. Execute:\n\n```sh\nmix ecto.gen.migration create_beacon_tables\n```\n\nThen go to the generated migration (usually in `/priv/repo/migrations`) and change the migration to look like this:\n\n```elixir\ndefmodule MyApp.Repo.Migrations.CreateBeaconTables do\n  use Ecto.Migration\n  def up, do: Beacon.Migration.up()\n  def down, do: Beacon.Migration.down()\nend\n```","ref":"your-first-site.html#setup-the-database-schema"},{"type":"extras","title":"Generating the site - Your First Site","doc":"Now it's time to create your first site. You need to change some files in your application but Beacon provides a generator to help you with that.\n\nIn the root of your application, execute:\n\n```sh\nmix beacon.install --site my_site --path /\n```","ref":"your-first-site.html#generating-the-site"},{"type":"extras","title":"Configuring the routes - Your First Site","doc":"To access the admin interface and the site we just created, both needs to be mounted in your application router. Open the file `router.ex` and change it to look like this:\n\n```elixir\ndefmodule MyAppWeb.Router do\n  use MyAppWeb, :router\n\n  pipeline :browser do\n    plug :accepts, [\"html\"]\n    plug :fetch_session\n    plug :fetch_live_flash\n    plug :put_root_layout, html: {MyAppWeb.Layouts, :root}\n    plug :protect_from_forgery\n    plug :put_secure_browser_headers\n    plug Beacon.LiveAdmin.Plug # <- add this line\n  end\n\n  use Beacon.Router           # <- add this line\n  use Beacon.LiveAdmin.Router # <- add this line\n\n  # add this scope\n  scope \"/admin\" do\n    pipe_through :browser\n    beacon_live_admin \"/\"\n  end\n\n  # add this scope\n  scope \"/\" do\n    pipe_through :browser\n    beacon_site \"/\", site: :my_site\n  end\nend\n```\n\nReplace `MyApp` with your application name.\n\nFor the sake of simplicity of this guide we're assuming that no other route is available, but if you intend to have more routes in your application,\nyou have to pay attention to the order in which the routes are defined, see the `Beacon.Router` module for more information.","ref":"your-first-site.html#configuring-the-routes"},{"type":"extras","title":"Starting the application - Your First Site","doc":"We're done configuring your site, let's run the project to make sure it's working.\n\nFirstly execute the following to install dependencies:\n\n```sh\nmix setup\n```\n\nAnd now start your Phoenix app:\n\n```sh\nmix phx.server\n```\n\nVisit http://localhost:4000 to see the default home page created by Beacon.","ref":"your-first-site.html#starting-the-application"},{"type":"extras","title":"Accessing LiveAdmin to manage your site - Your First Site","doc":"Let's customize the home page. Visit http://localhost:4000/admin and you should see the `my_site` that you just created listed on the admin interface.\n\nNow let's create the resources for our first site, and we'll starting by creating the resources used by the home page before we customize its template.","ref":"your-first-site.html#accessing-liveadmin-to-manage-your-site"},{"type":"extras","title":"Live Data - Your First Site","doc":"We want to display the current year at the footer of the home page as the assign `<%= @current_year %>`. In Beacon we use Live Data to create and modify assigns at runtime, let's do it.\n\nGo to http://localhost:4000/admin/my_site/live_data to create a new path `/` and then create a new assign named `current_year` using the `elixir` format with the following value:\n\n```elixir\nDate.utc_today().year\n```\n\nSave the changes.","ref":"your-first-site.html#live-data"},{"type":"extras","title":"Handle the form submission event - Your First Site","doc":"Besides displaying some data, we will have a form to subscribe people to our newsletter, so we need to react to that event. Let's create an event handler for that.\n\nGo to http://localhost:4000/admin/my_site/pages, click on the Home Page, and click on the Events tab on the top of the page. Then create a new event handler `join` with the following content:\n\n```elixir\n%{\"waitlist\" => %{\"email\" => email}} = event_params\nIO.puts(\"#{email} joined the waitlist\")\n{:noreply, assign(socket, :joined, true)}\n```","ref":"your-first-site.html#handle-the-form-submission-event"},{"type":"extras","title":"Upload an image - Your First Site","doc":"The last resource we want in our home is an image. Beacon provides a Media Library to upload and serve images, so first find an image and rename it to `image.jpg` (or the extension you prefer). Or use one of the images in https://github.com/BeaconCMS/beacon/tree/main/assets/images\n\nGo to http://localhost:4000/admin/my_site/media_library and upload that image.","ref":"your-first-site.html#upload-an-image"},{"type":"extras","title":"Update the home page template - Your First Site","doc":"Finally, let's update the home page template to make use of the live data, the event handler, and the image we just uploaded.\n\nGo to http://localhost:4000/admin/my_site/pages and you should see a page already created for the `/` path. We're going to change it.\n\nEdit the template to replace with this content:\n\n```heex\n \n    \n   \n     \n      <.link patch=\"/\" class=\"flex items-center gap-2\">\n         \n            \n            \n         \n         CMS Platform \n      </.link>\n     \n     \n      <.link patch=\"/blog\" class=\"hidden md:inline-flex text-sm font-medium hover:underline\">\n        Blog\n      </.link>\n       \n        Sign In\n       \n     \n   \n   \n     \n       \n         \n           \n             \n              Unlock the power\n             \n            of your content with our CMS platform\n           \n           \n            Streamline your content management with our intuitive, high-performance CMS built on Phoenix LiveView.\n           \n           \n             \n               \n               \n                Join Waitlist\n               \n             \n           \n           \n            Congrats! You joined the watchlist.\n           \n         \n         \n          <.image\n            site={@beacon.site}\n            name=\"image.webp\"\n            alt=\"My Page Image\"\n            width=\"600\"\n            height=\"600\"\n            style=\"aspect-ratio: 600 / 600; object-fit: cover;\"\n          />\n         \n       \n     \n   \n   \n     \n       © <%= @current_year %> CMS Platform. All rights reserved. \n       \n         \n           \n              \n           \n           Facebook \n         \n         \n           \n             \n             \n           \n           Twitter \n         \n         \n           \n              \n              \n              \n           \n           Instagram \n         \n         \n           \n             \n             \n              \n              \n           \n           LinkedIn \n         \n         \n          Privacy\n         \n         \n          Terms\n         \n         \n          Contact\n         \n       \n     \n   \n \n```\n\nSave the changes and Publish the page. Go to http://localhost:4000 to check the final result!\n\nYou should see the image you uploaded, the current year on the footer, and a message after joining the waitlist.\n\n-----------------------\n\nCongratulations! You have a site up and running.\n\nCheck out all available recipes to learn how to deploy your site, customize it even further, and more.","ref":"your-first-site.html#update-the-home-page-template"},{"type":"extras","title":"Access Page Info","doc":"# Access Page Info\n\nIn order to build pages you might need to access the current site or page information, as query params, path, and so on.\n\nBeacon provides a read-only assign `@beacon` that is available on all templates and also on Elixir code blocks as event handlers.\n\nFor example, to access the current page title in a template:\n\n```heex\n <%= @beacon.page.title %> \n```\n\nSee the module `Beacon.Web.BeaconAssigns` for more info.","ref":"access-page-info.html"},{"type":"extras","title":"Add Custom Page Fields","doc":"# Add Custom Page Fields\n\nEvery Beacon page contains a set of pre-defined fields which behave the same way across all pages. For example, the Title and Description fields are used to fill meta tags for SEO purposes;  that's the same behavior regardless of whether the page is your homepage, a blog post, or something else.\n\nHowever, you often need to store custom data, perform some logic on that data, or display extra information on the page. Some examples include tags for blog posts, authors, links, and so on.\n\nIn this recipe we'll add a custom page field `Type` to allow users identify the type of the page on the admin interface and use that data to list recent blog posts.","ref":"add-custom-page-fields.html"},{"type":"extras","title":"Add a module that implements the `Beacon.Content.PageField` behavior - Add Custom Page Fields","doc":"In this module we'll define how the data is stored and validated, and how the field is displayed on the admin interface. Create a file with this content:\n\n```elixir\ndefmodule MyApp.Beacon.PageFields.Type do\n  @moduledoc false\n  @behaviour Beacon.Content.PageField\n\n  use Phoenix.Component\n  import Beacon.Web.CoreComponents\n  import Ecto.Changeset\n\n  @impl true\n  def name, do: :type\n\n  @impl true\n  def type, do: :string\n\n  @impl true\n  def default, do: \"page\"\n\n  @impl true\n  def changeset(data, attrs, %{page_changeset: _page_changeset}) do\n    cast(data, attrs, [:type])\n  end\n\n  @impl true\n  def render(assigns) do\n    assigns = Map.put(assigns, :opts, [{\"Page\", \"page\"}, {\"Blog Post\", \"blog_post\"}])\n\n    ~H\"\"\"\n    <.input type=\"select\" label=\"Type\" prompt=\"Choose type\" options={@opts} field={@field} />\n    \"\"\"\n  end\nend\n```\n\nLet's break down each part of the module:\n\n* `name/0` - can be any atom that represents the field name, for example `:tags` for a lists of tags or `:author_id` to store a reference to the page author.\n* `type/0` - any valid [Ecto Schema type](https://hexdocs.pm/ecto/Ecto.Schema.html#module-types-and-casting)\n* `default/0` - the value with which to pre-populate the field\n* `changeset/3` - this is where you can add your own validation logic to that field (note: `page_changeset` is the changeset for the `%Beacon.Content.Page{}` itself)\n* `render/1` - the template to display the field on the page editor in Beacon LiveAdmin","ref":"add-custom-page-fields.html#add-a-module-that-implements-the-beacon-content-pagefield-behavior"},{"type":"extras","title":"Add the field to Beacon.Config - Add Custom Page Fields","doc":"Next we'll configure Beacon to include this type for your pages.  In `application.ex` add to your\nexisting Beacon config:\n\n```elixir\nsites: [\n  [\n    name: :my_site,\n    ...\n    extra_page_fields: [\n      ...\n      MyApp.Beacon.PageFields.Type\n    ]\n  ]\n]\n```","ref":"add-custom-page-fields.html#add-the-field-to-beacon-config"},{"type":"extras","title":"Access the field content - Add Custom Page Fields","doc":"Now, when a page is created or updated with your custom field, the content will be stored in the `:extra` field of the `%Beacon.Content.Page{}` record, under the name of the custom field.\n\nWith the example code above, a page with type `blog_post` will look like this:\n\n```elixir\n%Beacon.Content.Page{\n  # ...\n  extra: %{\"type\" => \"blog_post\"},\n}\n```\n\nYou can make use of this field to filter pages on the backend or display that extra information in the page template!","ref":"add-custom-page-fields.html#access-the-field-content"},{"type":"extras","title":"Create a Blog","doc":"# Create a Blog","ref":"create-a-blog.html"},{"type":"extras","title":"Objective - Create a Blog","doc":"Create blog posts with custom fields (type and tags), render each one using the tailwind typography plugin, and list the most recent posts in an index page.","ref":"create-a-blog.html#objective"},{"type":"extras","title":"Prerequisites - Create a Blog","doc":"This guide will skip initial setup steps that are already covered in the [your first site guide](../introduction/your-first-site.md),\nso if that's the first site in your application, or you're not familiar with Beacon, please follow that guide first to make sure the environment is set up correctly:\n\n- Beacon and Beacon LiveAdmin are installed\n- A database migration exists to create the Beacon tables\n- Router is already setup","ref":"create-a-blog.html#prerequisites"},{"type":"extras","title":"Create the blog site - Create a Blog","doc":"Now that we have fullfilled the requirements, let's create the blog site mounted at `/blog`. Go ahead and execute:\n\n```sh\nmix beacon.install --site blog --path /blog\n```\n\nA basic site was just created but we have some work to do before executing the Phoenix server.\n\n**Note** that if you've already execute `beacon.install` before to install another site, then it won't append the new `blog` site to your application,\nso edit the `application.ex` and `router.ex` files to include the configuration manually:\n\n```elixir\n# application.ex\n[site: :blog, repo: MyApp.Repo, endpoint: MyAppWeb.Endpoint, router: MyAppWeb.Router]\n\n# router.ex\nbeacon_site \"/blog\", site: :blog\n```\n\nJust make sure to add `beacon_site \"/blog\", site: :blog` before any `beacon_site \"/\"` otherwise the latter will match all paths, including `/blog`\nand Beacon won't be able to find and render pages of the blog site.","ref":"create-a-blog.html#create-the-blog-site"},{"type":"extras","title":"Tailwind Setup - Create a Blog","doc":"Since we'll be using a tailwind plugin, you need to follow the [Tailwind setup guide](../introduction/tailwind-setup.md)\nto setup and bundle the tailwind configuration.","ref":"create-a-blog.html#tailwind-setup"},{"type":"extras","title":"Tailwind Typography Plugin - Create a Blog","doc":"A blog is useless if it looks ugly and is hard to read but lucky us that Tailwind provides a [plugin](https://tailwindcss.com/blog/tailwindcss-typography) that turns blocks of HTML into beautiful documents.\n\nLet's install that plugin. Execute in the root of your project:\n\n```sh\nnpm install --prefix assets --include=dev @tailwindcss/typography\n```\n\nAnd edit the file `assets/tailwind.config.js` to require that plugin. Add the following line in the `plugins` list:\n\n```js\nrequire(\"@tailwindcss/typography\"),\n```","ref":"create-a-blog.html#tailwind-typography-plugin"},{"type":"extras","title":"Custom Fields - Create a Blog","doc":"Every Beacon page has some essential fields like title, path, description, and others. But since Beacon can be used to build any kind of site, from small to big,\nwe can't include all possible fields to accomodate all kinds of page that might exist. The solution to this problem is allowing users to create their own custom field,\nwhich are displayed in the Beacon LiveAdmin editor, stored in the page record in the database, and can be used in queries and templates.\n\nFor our blog we'll create 2 custom fields: type and tags. Type to allow us to distinguish between a regular page and a blog post, and tags to allow us to categorize our posts.\n\nThose custom fields are modules that implements the `Beacon.Content.PageField` behaviour. Let's create them.","ref":"create-a-blog.html#custom-fields"},{"type":"extras","title":"Custom field `type` - Create a Blog","doc":"Create a new file `lib/my_app/beacon/page_fields/type.ex` with the following content:\n\n```elixir\ndefmodule MyApp.Beacon.PageFields.Type do\n  @moduledoc \"\"\"\n  Custom beacon page field to distinguish between a regular page and a blog post.\n  \"\"\"\n\n  use Phoenix.Component\n  import Beacon.Web.CoreComponents\n  import Ecto.Changeset\n\n  @behaviour Beacon.Content.PageField\n\n  @impl true\n  def name, do: :type\n\n  @impl true\n  def type, do: :string\n\n  @impl true\n  def default, do: \"page\"\n\n  @impl true\n  def render(assigns) do\n    assigns = Map.put(assigns, :opts, [{\"Page\", \"page\"}, {\"Blog Post\", \"blog_post\"}])\n\n    ~H\"\"\"\n    <.input type=\"select\" label=\"Type\" prompt=\"Choose type\" options={@opts} field={@field} />\n    \"\"\"\n  end\n\n  @impl true\n  def changeset(data, attrs, %{page_changeset: _page_changeset}) do\n    cast(data, attrs, [:type])\n  end\nend\n```\n\nNote that the file location and the module name doesn't need to follow any special convention, it's up to you to organize your code as you see fit.","ref":"create-a-blog.html#custom-field-type"},{"type":"extras","title":"Custom field `tags` - Create a Blog","doc":"A blog post without tags is like a cake without icing, so let's create a custom field to store list of tags for each post.\n\n```elixir\ndefmodule MyApp.Beacon.PageFields.Tags do\n  @moduledoc \"\"\"\n  Custom beacon page field to store tags for a blog post.\n\n  Tags are separated by commas.\n  \"\"\"\n\n  use Phoenix.Component\n  import Beacon.Web.CoreComponents\n  import Ecto.Changeset\n\n  @behaviour Beacon.Content.PageField\n\n  @impl true\n  def name, do: :tags\n\n  @impl true\n  def type, do: :string\n\n  @impl true\n  def default, do: \"2024\"\n\n  @impl true\n  def render(assigns) do\n    ~H\"\"\"\n    <.input type=\"text\" label=\"Tags\" field={@field} />\n    \"\"\"\n  end\n\n  @impl true\n  def changeset(data, attrs, _metadata) do\n    cast(data, attrs, [:tags])\n  end\nend\n```\n\nGreat, now we need to tell Beacon to use those custom page fields. Open the file `lib/my_app/application.ex` and add the following into your site configuration:\n\n```elixir\nextra_page_fields: [\n  MyApp.Beacon.PageFields.Type,\n  MyApp.Beacon.PageFields.Tags\n]\n```","ref":"create-a-blog.html#custom-field-tags"},{"type":"extras","title":"Create the layout - Create a Blog","doc":"It's time to spin up the server, access the admin interface, and create the resources of our site. Execute:\n\n```sh\nmix phx.server\n```\n\nVisit http://localhost:4000/admin/blog/layouts, edit the Default layout, and change the template to:\n\n```heex\n \n   \n     \n      <.page_link path={~p\"/\"} class=\"text-2xl font-bold\">My Blog</.page_link>\n       \n        <.page_link path={~p\"/\"} class=\"text-muted-foreground hover:text-foreground transition-colors\">Blog</.page_link>\n        <.page_link path={~p\"/about\"} class=\"text-muted-foreground hover:text-foreground transition-colors\">About</.page_link>\n        <.page_link path={~p\"/contact\"} class=\"text-muted-foreground hover:text-foreground transition-colors\">Contact</.page_link>\n       \n     \n   \n   \n    <%= @inner_content %>\n   \n\n   \n    <%= @inner_content %>\n   \n \n```\n\nSave and publish the changes.\n\nSome notes about this layout:\n- The `prose` classes are defined by the tailwind typography plugin and is responsible for making our blog look good.\n- Conditionally apply the `prose` classes only to the blog posts, not to the home page.","ref":"create-a-blog.html#create-the-layout"},{"type":"extras","title":"Create the first blog post - Create a Blog","doc":"Visit http://localhost:4000/admin/blog/pages and create a new page with the following data:\n\n- Path: /the-elixir-language\n- Title: The Elixir language\n- Description: What's Elixir, how and where it can be used.\n- Format: Markdown\n- Type: Blog Post\n- Tags: 2024,eng,elixir\n\nAnd the following template:\n\n````markdown\n# The Elixir language\n\nIn the ever-evolving world of web development, Elixir has emerged as a powerful and innovative language that is transforming the way we build web applications. This blog post explores the unique features and benefits of Elixir, and how it can revolutionize your web development workflow.","ref":"create-a-blog.html#create-the-first-blog-post"},{"type":"extras","title":"The Rise of Elixir - Create a Blog","doc":"Elixir is a dynamic, functional programming language that runs on the Erlang Virtual Machine (BEAM). Inspired by Erlang, Elixir inherits its robust concurrency model, fault-tolerance, and scalability, making it an excellent choice for building highly available and scalable web applications.\n\nOne of the key features of Elixir is its focus on functional programming principles. By embracing immutable data structures and a concise syntax, Elixir enables developers to write more expressive and maintainable code. This, combined with Elixir's powerful metaprogramming capabilities, allows for the creation of domain-specific languages (DSLs) that can greatly enhance developer productivity.","ref":"create-a-blog.html#the-rise-of-elixir"},{"type":"extras","title":"Elixir and Web Development - Create a Blog","doc":"Elixir's strengths make it an excellent choice for web development. The Phoenix framework, which is often compared to Ruby on Rails, provides a robust and scalable foundation for building web applications. With its focus on real-time communication and fault-tolerance, Elixir and Phoenix are well-suited for building applications that require high availability and low latency, such as chat applications, real-time dashboards, and IoT platforms.\n\nHere's an example of a simple Elixir web application using the Phoenix framework:\n\n```elixir\n# lib/my_app_web/controllers/page_controller.ex\ndefmodule MyAppWeb.PageController do\n  use MyAppWeb, :controller\n\n  def index(conn, _params) do\n    render(conn, \"index.html\", message: \"Welcome to Elixir!\")\n  end\n```","ref":"create-a-blog.html#elixir-and-web-development"},{"type":"extras","title":"The Future of Elixir in Web Development - Create a Blog","doc":"As Elixir and the Phoenix framework continue to evolve, we can expect to see even more exciting developments in the world of web development. Advancements in areas like real-time data processing, distributed systems, and seamless integration with other technologies will further enhance the capabilities of Elixir-based web applications.\n\nBy embracing Elixir, web developers can unlock new levels of scalability, fault-tolerance, and developer productivity, paving the way for a future where the focus is on building innovative and user-centric web experiences, rather than managing complex infrastructure.\n````\n\nSave and publish this page. Now visit http://localhost:4000/blog/the-elixir-language to see the result. There is your first blog post!","ref":"create-a-blog.html#the-future-of-elixir-in-web-development"},{"type":"extras","title":"Create the blog index - Create a Blog","doc":"Now that we have a blog post, let's create an index page to list published posts.\n\nFirst we need to fetch published posts, so let's create a live data assign that exposes data to pages. Visit http://localhost:4000/admin/blog/live_data,\ncreate a new live data for the path `/`, and then create a new assign `most_recent_posts` with the following code:\n\n```elixir\nimport Ecto.Query\n\nBeacon.Content.list_published_pages(\n  :blog,\n  search: fn -> dynamic([q], fragment(\"extra->>'type' = 'blog_post'\"))\nend)\n```\n\nVisit http://localhost:4000/admin/blog/pages and edit the \"My Home Page\" with the following data:\n\n- Title: My Blog\n- Type: Page\n- Tags: leave empty (no tags)\n\nAnd the following template:\n\n```heex\n \n   \n    Welcome to My Blog\n   \n   \n    Discover the latest insights and trends in web development, design, and technology.\n   \n \n\n Latest Blog Posts \n\n \n   \n     \n      <.page_link path={~p\"/#{post}\"} class=\"text-xl font-bold mb-2 block text-primary\">\n        <%= post.title %>\n      </.page_link>\n       \n         \n          <%= tag %>\n         \n       \n       \n        <%= post.description %>\n       \n     \n   \n \n```\n\nSave the changes and publish the page. Visist http://localhost:4000/blog to see the result!","ref":"create-a-blog.html#create-the-blog-index"},{"type":"extras","title":"Custom Repo","doc":"# Custom Repo\n\nRepo is the layer of communication with databases and Beacon requires one to store and fetch data.\n\nBy default, the Beacon installer will infer the repo name and add it to your site configuration. But you may use a custom repo that connects\nto a different database and/or is fine-tuned for your sites.\n\nOpen the file `application.ex`, find the `:repo` option in the site configuration and replace the default repo with your custom repo:\n\n```elixir\nchildren = [\n  ...\n  {Beacon: sites: [[... repo: YourCustomRepo, ...]]}\n]\n```","ref":"custom-repo.html"},{"type":"extras","title":"Deploying on Fly.io","doc":"# Deploying on Fly.io\n\nOnce you have a [Beacon site up and running](../introduction/your-first-site.md) locally, you can deploy it on [Fly.io](https://fly.io) by following this guide.","ref":"deploy-to-flyio.html"},{"type":"extras","title":"Fly.io CLI - Deploying on Fly.io","doc":"First, install the fly cli tool, as described at [Install flyctl](https://fly.io/docs/hands-on/install-flyctl). You'll need it to deploy your site.","ref":"deploy-to-flyio.html#fly-io-cli"},{"type":"extras","title":"Sign in or sign up - Deploying on Fly.io","doc":"Don't have an account yet? Sign up by running:\n\n```sh\nfly auth signup\n```\n\nOr sign in to your existing account:\n\n```sh\nfly auth login\n```","ref":"deploy-to-flyio.html#sign-in-or-sign-up"},{"type":"extras","title":"Dockerfile - Deploying on Fly.io","doc":"Applications on Fly run in containers. Let's generate a Dockerfile and make a couple of changes to that file:\n\nRun:\n\n```sh\nmix phx.gen.release --docker\n```\n\nEdit the generated `Dockerfile` and make two changes:\n\n1. Add the following code before `RUN mix assets.deploy`:\n\n```\nRUN mix tailwind.install --no-assets\n```\n\n2. Add the following code before `USER nobody`:\n\n```dockerfile\n# Copy the tailwind-cli binary used to compile stylesheets for pages\nRUN mkdir -p ./bin/_build\nCOPY --from=builder --chown=nobody:root /app/_build/tailwind-* ./bin/_build/\n\n# Copy heroicons svg files to used on the icon component\nRUN mkdir -p ./vendor\nCOPY --from=builder --chown=nobody:root /app/deps/heroicons ./vendor/heroicons\n```","ref":"deploy-to-flyio.html#dockerfile"},{"type":"extras","title":"Launch - Deploying on Fly.io","doc":"With your account in place and all files updated, it's time to launch your application. Run:\n\n```sh\nfly launch\n```\n\nWhen asked if you would like to set up a PostgreSQL database, answer YES and choose the most appropriate configuration for your site.\n\nWhen asked if you would like to deploy, answer YES or run `fly deploy` afterwards when you're ready to deploy.","ref":"deploy-to-flyio.html#launch"},{"type":"extras","title":"Deploy - Deploying on Fly.io","doc":"Beacon is designed to minimize deployments as much as possible, but eventually you can trigger new deployments by running:\n\n```sh\nfly deploy\n```","ref":"deploy-to-flyio.html#deploy"},{"type":"extras","title":"Open - Deploying on Fly.io","doc":"Finally, if you followed the guides to setup your site, run the following command to see it live:\n\n```sh\nfly open /\n```\n\nIf you have created a custom page, simply replace `/` in the above command to match its path","ref":"deploy-to-flyio.html#open"},{"type":"extras","title":"More commands - Deploying on Fly.io","doc":"You can find all available commands in the [Fly.io docs](https://fly.io/docs/flyctl) and also find more tips on the official [Phoenix Deploying on Fly.io guide](https://fly.io/docs/elixir/getting-started/).","ref":"deploy-to-flyio.html#more-commands"},{"type":"extras","title":"Heroicons","doc":"# Heroicons\n\n[Heroicons](https://heroicons.com/) is a popular icon library added by default in new Phoenix applications and also available in Beacon as a component.\n\nThe component `heroicon` is added by default in new Beacon sites without extra configuration to let you render icons in your pages:\n\n```heex\n<.heroicon name=\"light-bulb\" solid />\n```\n\nIn this example, the `light-bulb` icon is rendered in solid style, which is provided by the [Heroicons](https://hex.pm/packages/heroicons) package.","ref":"heroicons.html"},{"type":"extras","title":"Multiple Domains/Tenants","doc":"# Multiple Domains/Tenants\n\nYou can host multiple domains or subdomains with Phoenix by using the `:host` option of the scope function in your router:\n\n`:host` - a string or list of strings containing the host scope, or prefix host scope (e.g. `\"foo.bar.com\"`, `\"foo.\"`)\n\n```elixir\n# match admin. subdomain\nscope \"/\", MyAppWeb, host: \"admin.\" do\n  live \"/\", AdminLive, :new\nend\n\n# match example.com, and \"example2.com\"\nscope \"/\", MyAppWeb, host: [\"example.com\", \"example2.com\"] do\n  live \"/\", LandingLive, :new\nend\n\n# match my-example.org\nscope \"/\", MyAppWeb, host: \"my-example.org\" do\n  live \"/\", HomeLive, :new\nend\n```","ref":"multiple-domains-hosting.html"},{"type":"extras","title":"Multiple Domains/Tenants hosting with BeaconCMS - Multiple Domains/Tenants","doc":"If you need to host multiple domains or subdomains with Beacon, you can still use the same `:host` option described above!\n\nHere's another example, but now using Beacon:\n\n```elixir\n# serve the `:demo` site at demo.org/demo\nscope \"/\", host: \"demo.org\" do\n  pipe_through :browser\n\n  beacon_site \"/demo\", site: :demo\nend\n\n# serve the `:blog` site at blog.com\nscope \"/\", host: \"blog.com\" do\n  pipe_through :browser\n\n  beacon_site \"/\", site: :blog\nend\n\n# serve the admin interface at the prefix /admin on the root domain\nscope \"/admin\" do\n  pipe_through :browser\n  beacon_live_admin \"/\"\nend\n```\n\nYou also need to pass the `:check_origin` option when configuring your endpoint, in order to explicitly outline which origins are allowed.\n\nIn `config/runtime.exs` edit the following config to include your domains:\n\n```elixir\nconfig :my_app, MyAppWeb.Endpoint,\n  ...\n  check_origin: [\n    \"https://beacon-demo.com/\",\n    \"https://demo.org\",\n    \"https://blog.com\"\n  ],\n  ...\n```","ref":"multiple-domains-hosting.html#multiple-domains-tenants-hosting-with-beaconcms"},{"type":"extras","title":"Notify Page Published","doc":"# Notify Page Published\n\nLet's suppose you want to notify a group of people via email when a page is published and your Phoenix application is already integrated with a mailer.\n\nBeacon provides some lifecycle hooks that you can use to inject custom logic when something happens, in this case, when a page is published the hook `:after_publish_page` is triggered.\n\nYou can check out the full documentation and the list of available in the `Beacon.Config` module. This is the spec for the `:after_publish_page` hook:\n\n```elixir\n{:after_publish_page, [{identifier :: atom(), fun :: (Content.Page.t() -> {:cont, Content.Page.t()} | {:halt, Exception.t()})}]}\n```\n\nIt may look a bit complex, but it's quite simple. You need to define a function that receives a `Content.Page.t()` struct and returns either\n`{:cont, Content.Page.t()}` to continue the process or `{:halt, Exception.t()}` to stop it. And the identifier is just a unique name for your custom logic.\n\nFor our example, the site config would look like:\n\n```elixir\nlifecycle: [\n  after_publish_page: [\n    notify_page_published: &MyApp.CMS.notify_page_published/1\n  ]\n]\n```\n\nAnd the corresponding function in `MyApp.CMS` module:\n\n```elixir\ndefmodule MyApp.CMS do\n  def notify_page_published(%Beacon.Content.Page{path: path} = page) do\n    email =  MyApp.CMSEmail.notify(%{path: path})\n\n    case MyApp.Mailer.deliver(email) do\n      {:ok, _} ->\n        {:cont, page}\n\n      {:error, reason} ->\n        message = \"\"\"\n        failed to notify that page #{path} was published\n\n        Got:\n\n          #{inspect(reason)}\n        \"\"\"\n\n        # or use a custom exception\n        {:halt, %RuntimeError{message: message}}\n    end\n  end\nend\n```","ref":"notify-page-published.html"},{"type":"extras","title":"Upgrading to v0.1.0-rc.1","doc":"# Upgrading to v0.1.0-rc.1","ref":"v0-1-0-rc-1.html"},{"type":"extras","title":"Bump your deps - Upgrading to v0.1.0-rc.1","doc":"Update Beacon to the specific release candidate version:\n\n```elixir\n[\n  {:beacon, \"~> 0.1.0-rc.1\"}\n]\n```\n\nRemember to keep the option `override: true` if running BeaconLiveAdmin in the same project.","ref":"v0-1-0-rc-1.html#bump-your-deps"},{"type":"extras","title":"Update Beacon tables - Upgrading to v0.1.0-rc.1","doc":"```sh\nmix ecto.gen.migration update_beacon_v002\n```\n\nWithin the migration module:\n\n```elixir\nuse Ecto.Migration\ndef up, do: Beacon.Migration.up()\ndef down, do: Beacon.Migration.down()\n```","ref":"v0-1-0-rc-1.html#update-beacon-tables"},{"type":"extras","title":"Upgrading to v0.1.0-rc.2","doc":"# Upgrading to v0.1.0-rc.2","ref":"v0-1-0-rc-2.html"},{"type":"extras","title":"Bump your deps - Upgrading to v0.1.0-rc.2","doc":"Update Beacon to the specific release candidate version:\n\n```elixir\n[\n  {:beacon, \"~> 0.1.0-rc.2\"}\n]\n```\n\nRemember to keep the option `override: true` if running BeaconLiveAdmin in the same project.","ref":"v0-1-0-rc-2.html#bump-your-deps"},{"type":"extras","title":"Update Gettext - Upgrading to v0.1.0-rc.2","doc":"[Gettext](https://hex.pm/packages/gettext) has been updated to `~> 0.26` which requires a change,\nbut fortunately it's a small and beneficial one.\n\nIn your `mix.exs` file, update the `:gettext` dependency to at least `~> 0.26`:\n\n```elixir\n[\n  {:gettext, \"~> 0.26\"}\n]\n```\n\nThen change your application's `Gettext` module to use the new `Gettext.Backend` module:\n\n```elixir\ndefmodule MyAppWeb.Gettext do\n  use Gettext.Backend, otp_app: :my_app_web\nend\n```\n\n_Change the names accordingly, the only change needed here is adding the `.Backend` suffix._\n\nAnd now in every place you used to `import MyAppWeb.Gettext`, just replace with `use Gettext, backend: MyAppWeb.Gettext`\n\nFor more info see https://github.com/elixir-gettext/gettext/blob/main/CHANGELOG.md#v0260","ref":"v0-1-0-rc-2.html#update-gettext"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}